@@ -22,8 +22,9 @@ for line in sys.stdin.readlines():
         """Test the 3sfd example"""
         if sys.platform == 'win32':
             self.skipTest("does not work on Windows")
-        input_file_dir = self.get_input_file_name('')
-        cmds = self.read_shell_commands('../3sfd.dox')
+        input_file_dir = os.path.dirname(self.get_input_file_name('3sfdA.pdb'))
+        cmds = self.read_shell_commands(
+                        '../../../doc/tutorial/emagefit_3sfd.dox')
         d = IMP.test.RunInTempDir()
         self.make_dummy_hex(input_file_dir)
         for c in cmds:
