@@ -7,7 +7,7 @@ class Tests(IMP.test.ApplicationTestCase):
 
     def test_nup133(self):
         """Test the Nup133 example"""
-        cmds = self.read_shell_commands('../nup133.dox')
+        cmds = self.read_shell_commands('../../../doc/tutorial/foxs_nup133.dox')
         d = IMP.test.RunInTempDir()
         # Skip running gnuplot on machines that don't have it
         have_gnuplot = os.path.exists('/usr/bin/gnuplot')
