@@ -4,7 +4,7 @@
 #include <IMP/atom/pdb.h>
 #include <IMP/base/flags.h>
 #include <IMP/atom/force_fields.h>
-#include <IMP/exception.h>
+#include <IMP/base/exception.h>
 
 int main(int argc, char **argv) {
   try {
@@ -14,10 +14,10 @@ int main(int argc, char **argv) {
                                      "input.pdb",
                                      -1);
 
-    IMP::set_log_level(IMP::WARNING);
+    IMP::base::set_log_level(IMP::base::WARNING);
     for (unsigned int i=0; i< argcs.size(); ++i) {
-      IMP_NEW(IMP::Model, m, ());
-      m->set_log_level(IMP::SILENT);
+      IMP_NEW(IMP::kernel::Model, m, ());
+      m->set_log_level(IMP::base::SILENT);
       IMP::atom::Hierarchies inhs;
       IMP_CATCH_AND_TERMINATE(inhs= IMP::atom::read_multimodel_pdb(argcs[i],
                                                                    m));
@@ -26,7 +26,7 @@ int main(int argc, char **argv) {
       }
     }
     return 0;
-  } catch (const IMP::Exception &e) {
+  } catch (const IMP::base::Exception &e) {
     std::cerr << "Error: " << e.what() << std::endl;
     return 1;
   } catch (const std::exception &e) {
