@@ -6,10 +6,12 @@ import IMP.saxs
 import os
 import sys
 import shutil
+import tempfile
 import itertools
 try:
     import numpy
     import scipy
+    import scipy.linalg
 except:
     numpy = None
     scipy = None
@@ -50,13 +52,14 @@ class SAXSApplicationTest(IMP.test.ApplicationTestCase):
         if os.path.isdir(destname):
             return
         args.append('--destdir='+destname)
-        args.append('--blimit_fitting=80')
-        args.append('--elimit_fitting=80')
+        #args.append('--blimit_fitting=80')
+        #args.append('--elimit_fitting=80')
         args.append('--allfiles')
         args.append('--outlevel=full')
-        args.extend(['--blimit_hessian=80', '--elimit_hessian=80',
+        args.extend([#'--blimit_hessian=80', '--elimit_hessian=80',
                  '--berror','--eerror'])
-        #print ' '.join(args)
+        print "### run_app"
+        print ' '.join(args)
         #sys.exit()
         p = self.run_python_application('saxs_merge.py',args)
         out, err = p.communicate()
@@ -77,7 +80,7 @@ class SAXSApplicationTest(IMP.test.ApplicationTestCase):
         seen_add = seen.add
         return [ x for x in seq if x not in seen and not seen_add(x)]
 
-    def plot_data_overlaid(self, name, d1, d2, datarange, title=None):
+    def plot_data_overlaid(self, name, d1, d2, datarange, chi, title=None):
         # data overlaid in log scale
         fl=open('Cpgnuplot'+name,'w')
         fl.write('set term png font "Lenka"\n')
@@ -86,7 +89,9 @@ class SAXSApplicationTest(IMP.test.ApplicationTestCase):
         fl.write('set xrange [%s:%s]\n' % (datarange[0], datarange[1]))
         fl.write('set yrange [%s:%s]\n' % (datarange[2], datarange[3]))
         if title:
-            fl.write('set title "%s"\n' % title)
+            fl.write('set title "%s (chi=%s)"\n' % (title, fitchi))
+        else:
+            fl.write('set title "chi=%s"\n' % (chi))
         fl.write('p "%s" u 1:2 w p t "automatic", "%s" u 1:2 w p t "manual"\n' %
             (d1,d2))
         fl.close()
@@ -98,7 +103,9 @@ class SAXSApplicationTest(IMP.test.ApplicationTestCase):
         fl.write('set xrange [%s:%s]\n' % (datarange[0], datarange[1]))
         fl.write('set yrange [0:%s]\n' % datarange[3])
         if title:
-            fl.write('set title "%s"\n' % title)
+            fl.write('set title "%s (chi=%s)"\n' % (title, fitchi))
+        else:
+            fl.write('set title "chi=%s"\n' % (chi))
         fl.write('p "%s" u 1:2 w p t "automatic", "%s" u 1:2 w p t "manual"\n' %
             (d1,d2))
         fl.close()
@@ -111,7 +118,7 @@ class SAXSApplicationTest(IMP.test.ApplicationTestCase):
         fl.write('set xrange [%s:%s]\n' % (datarange[0], datarange[1]))
         fl.write('set yrange [0:%s]\n' % datarange[3])
         fl.write('set output "%s_data_lin_colored.png"\n' % name)
-        fl.write('p "%s" u 1:(%s*($2+%s)):5 w p lc var t "automatic"\n' %
+        fl.write('p "%s" u 1:(%s*($2+%s)):7 w p lc var t "automatic"\n' %
                    (d1, transform[0], transform[1]))
         fl.close()
         os.system('GDFONTPATH="input/" gnuplot Cpgnuplot'+name)
@@ -122,18 +129,19 @@ class SAXSApplicationTest(IMP.test.ApplicationTestCase):
         fl.write('set log y\n')
         fl.write('set xrange [%s:%s]\n' % (datarange[0], datarange[1]))
         fl.write('set yrange [%s:%s]\n' % (datarange[2], datarange[3]))
-        fl.write('p "%s" u 1:(%s*($2+%s)):5 w p lc var t "automatic"\n' %
+        fl.write('p "%s" u 1:(%s*($2+%s)):7 w p lc var t "automatic"\n' %
                 (d1, transform[0],transform[1]))
         fl.close()
         os.system('GDFONTPATH="input/" gnuplot Cpgnuplot'+name)
 
-    def plot_means(self, name, d1, d2, datarange):
+    def plot_means(self, name, d1, d2, datarange, chi):
         #linear scale
         fl=open('Cpgnuplot'+name,'w')
         fl.write('set term png font "Lenka"\n')
         fl.write('set output "%s_means_lin.png"\n' % name)
         fl.write('set xrange [%s:%s]\n' % (datarange[0], datarange[1]))
         fl.write('set yrange [0:%s]\n' % datarange[3])
+        fl.write('set title "chi=%s"\n' % (chi))
         fl.write('p "%s" u 1:2 w l lt 1 t "automatic", '
                  '"" u 1:($2+$3) w l lt 1 not, "" u 1:($2-$3) w l lt 1 not, '
                  '"%s" u 1:2 w l lt 2 t "manual", '
@@ -146,6 +154,7 @@ class SAXSApplicationTest(IMP.test.ApplicationTestCase):
         fl.write('set term png font "Lenka"\n')
         fl.write('set output "%s_means_log.png"\n' % name)
         fl.write('set log y\n')
+        fl.write('set title "chi=%s"\n' % (chi))
         fl.write('set xrange [%s:%s]\n' % (datarange[0], datarange[1]))
         fl.write('set yrange [%s:%s]\n' % (datarange[2], datarange[3]))
         fl.write('p "%s" u 1:2 w l lt 1 t "automatic", '
@@ -287,6 +296,67 @@ class SAXSApplicationTest(IMP.test.ApplicationTestCase):
         fl.close()
         os.system('GDFONTPATH="input/" gnuplot Cpgnuplot'+name)
 
+    def plot_inputs_overlaid(self, name, inpnames, inputs, minputs):
+        #linear scale
+        fl=open('Cpgnuplot'+name,'w')
+        fl.write('set term png font "Lenka"\n')
+        fl.write('set output "%s_inputs_lin_overlaid.png"\n' % name)
+        #get xmax
+        maximums = [[i.split() for i in open(inp).readlines()]
+                        for inp in inputs]
+        maximums = [ filter(lambda a:int(a[3])==1 ,inp) for inp in maximums ]
+        xmax = 1.1*max([max(map(lambda a:float(a[0]),inp)) for inp in maximums])
+        fl.write('set xrange [0:%s]\n' % xmax)
+        fl.write('p ')
+        for i,(inam,idat,imean) in enumerate(zip(inpnames, inputs, minputs)):
+            fl.write('"%s" u 1:($4==1?$2:1/0):3 w yerr t "%s"'
+                        % (idat,inam))
+            fl.write(', \\\n   ')
+            fl.write('"%s" u 1:2 w l lt %d not' % (imean, i+2))
+            fl.write(', \\\n   ')
+            fl.write('"%s" u 1:($2+$3) w l lt %d not' % (imean, i+2))
+            fl.write(', \\\n   ')
+            fl.write('"%s" u 1:($2-$3) w l lt %d not' % (imean, i+2))
+            if i < len(inputs)-1:
+                fl.write(', \\\n')
+            else:
+                fl.write('\n')
+        fl.close()
+        os.system('GDFONTPATH="input/" gnuplot Cpgnuplot'+name)
+        #log scale
+        fl=open('Cpgnuplot'+name,'w')
+        fl.write('set term png font "Lenka"\n')
+        fl.write('set output "%s_inputs_log_overlaid.png"\n' % name)
+        fl.write('set xrange [0:%s]\n' % xmax)
+        fl.write('set log y\n')
+        fl.write('p ')
+        for i,(inam,idat,imean) in enumerate(zip(inpnames, inputs, minputs)):
+            fl.write('"%s" u 1:($4==1?$2:1/0):3 w yerr t "%s"'
+                        % (idat, inam))
+            fl.write(', \\\n   ')
+            fl.write('"%s" u 1:2 w l lt %d not' % (imean, i+2))
+            fl.write(', \\\n   ')
+            fl.write('"%s" u 1:($2+$3) w l lt %d not' %
+                            (imean, i+2))
+            fl.write(', \\\n   ')
+            fl.write('"%s" u 1:($2-$3) w l lt %d not' %
+                    (imean, i+2))
+            if i < len(inputs)-1:
+                fl.write(', \\\n')
+            else:
+                fl.write('\n')
+        fl.close()
+        os.system('GDFONTPATH="input/" gnuplot Cpgnuplot'+name)
+
+    def cleanup_data(self, qvals, data, precision=5):
+        tbd=[]
+        for i,d in enumerate(data):
+            if int(d[0]*10**precision) not in qvals:
+                tbd.append(i)
+        tbd.reverse()
+        for i in tbd:
+            data.pop(i)
+
     def chisquare(self, fla, flb, weighted=True, qmax=None, lognormal=False,
             factor=(1,1)):
         #read first 3 columns
@@ -294,99 +364,38 @@ class SAXSApplicationTest(IMP.test.ApplicationTestCase):
                 i.startswith('#')]
         db=[map(float, i.split()[:3]) for i in open(flb).readlines() if not
                 i.startswith('#')]
-        #check that data has common q values, removing the first ones if different
-        qa = self.uniqify(map(lambda a:a[0], da))
-        qb = self.uniqify(map(lambda a:a[0], db))
-        #print qa[0],qb[0]
-        if qa[0] < qb[0]:
-            i=0
-            while i+1 < len(qa) and abs(qa[i] - qb[0]) > 1e-5:
-                #print "   qa[%d]=%f" % (i,qa[i])
-                i += 1
-            qa = qa[i:]
-            #print "qa[0] -> %f (%d)" % (qa[0],len(qa))
-        else:
-            i=0
-            while i+1 < len(qb) and abs(qa[0] - qb[i]) > 1e-5:
-                #print "   qb[%d]=%f" % (i,qb[i])
-                i += 1
-            qb = qb[i:]
-            #print "qb[0] -> %f (%d)" % (qb[0],len(qb))
-        if len(qa) == 0 or len(qb) == 0:
-            self.fail("datasets do not have common q values!")
-        #project back to data
-        qa.reverse()
-        qb.reverse()
+        #get common q values up to 1e-5 in precision
+        qa = set(map(lambda a:int(a[0]*10**5), da))
+        qb = set(map(lambda a:int(a[0]*10**5), db))
+        qvals = qa.intersection(qb)
+        if len(qvals) < 10:
+            self.fail("datasets do not have more than 10 common q values!")
+        #keep only data at these q values
+        self.cleanup_data(qvals, da, precision=5)
+        self.cleanup_data(qvals, db, precision=5)
         da.reverse()
         db.reverse()
-        nda = []
-        ndb = []
-        while qa and qb:
-            #find next q value that is common in both datasets
-            qva = qa.pop()
-            qvb = qb.pop()
-            while qa and qb:
-                #print qva,qvb,
-                if abs(qva-qvb) < 1e-5:
-                    #print "equal"
-                    break
-                elif qva < qvb:
-                    qva = qa.pop()
-                else:
-                    qvb = qb.pop()
-                #print "different"
-            if abs(qva-qvb)>1e-5:
-                break
-            #find it in the datasets
-            qval = qva
-            #print "new qval",qval
-            while da:
-                if da[-1][0] < qval - 1e-5:
-                    da.pop()
-                    #print "  skipped da",da.pop()
-                else:
-                    break
-            while da:
-                if da[-1][0] > qval + 1e-5:
-                    break
-                else:
-                    nda.append(da.pop())
-                    #print "  appended",nda[-1]
-            #same for db
-            while db:
-                if db[-1][0] < qval - 1e-5:
-                    db.pop()
-                    #print "  skipped db",db.pop()
-                else:
-                    break
-            while db:
-                if db[-1][0] > qval + 1e-5:
-                    break
-                else:
-                    ndb.append(db.pop())
-                    #print "  appended",ndb[-1]
-            #same for db
         #compute normalized chisquare.
         #need to find better statistic
         #Multiple datapoints at same q value are downweighted.
         #each chunk is a set of values at the same q
         chi = []
-        while nda and ndb:
+        while da and db:
             #get chunk
-            qval = nda[-1][0]
+            qval = da[-1][0]
             chunka = []
-            while nda and abs(nda[-1][0] - qval) < 1e-5:
-                chunka.append(nda.pop()[1:])
+            while da and abs(da[-1][0] - qval) < 1e-5:
+                chunka.append(da.pop()[1:])
             chunkb = []
-            while ndb and abs(ndb[-1][0] - qval) < 1e-5:
-                chunkb.append(ndb.pop()[1:])
+            while db and abs(db[-1][0] - qval) < 1e-5:
+                chunkb.append(db.pop()[1:])
             #compute contributions
             if qmax and qval > qmax:
                 continue
             contribs = []
             for ia,sa in chunka:
                 for ib,sb in chunkb:
-                    #factor is a multiplicative factor for the standard devs
+                    #factor is a multiplicative factor for the stadard devs
                     if lognormal:
                         ira,irb = numpy.log(ia), numpy.log(ib)
                         sra, srb = factor[0]*sa/ia, factor[1]*sb/ib
@@ -401,7 +410,7 @@ class SAXSApplicationTest(IMP.test.ApplicationTestCase):
             chi.append(sum(contribs)/float(len(contribs)))
         if len(chi) < 50:
             print "warning: chisquare computed on only %d points!" % len(chi)
-        print "chisquare",fla,flb,sum(chi)/len(chi)
+        #print "chisquare",fla,flb,sum(chi)/len(chi)
         return sum(chi)/len(chi)
 
     def get_transform(self, fname):
@@ -414,11 +423,50 @@ class SAXSApplicationTest(IMP.test.ApplicationTestCase):
         else:
             return gamma,0
 
-    def get_guinier_Rg(self, profile):
+    def _get_guinier_fit_fixed(self, qs,Is,errs):
+        X=numpy.array([numpy.ones(len(qs)),qs**2]).transpose()
+        W=numpy.diagflat(errs/Is)
+        y=numpy.atleast_2d(numpy.log(Is)).transpose()
+        #weighted least squares estimator
+        #beta = (X^T W X )^(-1) X^T W y
+        XW=numpy.dot(X.transpose(),W)
+        beta = scipy.linalg.solve( numpy.dot(XW,X), numpy.dot(XW,y),
+                sym_pos=True)
+        if beta[1,0]>0:
+            rg=0
+        else:
+            rg=numpy.sqrt(-3*beta[1,0])
+        izero = numpy.exp(beta[0,0])
+        return rg,izero
+
+    def get_guinier_fit(self, qs, Is, errs, end_q_rg=1.3):
+        #fit the whole range up to q_rg, take median values for robustness
+        cut=5 #drop first 5 points, and take at least 5 points to estimate
+        vals = []
+        for i in xrange(cut+5,len(qs)):
+            rg,izero = self._get_guinier_fit_fixed(
+                    qs[cut:i],Is[cut:i],errs[cut:i])
+            if rg >0:
+                vals.append((rg,izero,qs[i-1]*rg))
+                if qs[i-1]*rg > end_q_rg:
+                    break
+        vals=numpy.array(vals).transpose()
+        rg = numpy.median(vals[0])
+        izero = numpy.median(vals[1])
+        return rg,izero
+
+    def get_guinier_Rg(self, profile, weighted=True):
+        if weighted:
+            data=numpy.array([map(float, i.split()[:3])
+                for i in open(profile).readlines() if not i.startswith('#')])
+            qs,Is,errs = data.transpose()
+        else:
+            data=numpy.array([map(float, i.split()[:2])
+                for i in open(profile).readlines() if not i.startswith('#')])
+            qs,Is = data.transpose()
+            errs = numpy.ones(len(qs))
         #guinier fit, weighted by errors
-        exp_profile = IMP.saxs.Profile(profile)
-        gRg = exp_profile.radius_of_gyration()
-        return gRg
+        return self.get_guinier_fit(qs, Is, errs)[0]
 
     def get_GPI_sigma(self, summary):
         lines=open(summary).readlines()
@@ -436,7 +484,7 @@ class SAXSApplicationTest(IMP.test.ApplicationTestCase):
     def get_foxs_data(self, destdir, pdb, automerge, manualmerge,
             factor=1, chi_wt=True, chi_qmax=None, chi_ln=False):
         """get chi and radius of gyration of pdb using foxs"""
-        m = IMP.Model()
+        m = IMP.kernel.Model()
         mp =IMP.atom.read_pdb(pdb, m,
                       IMP.atom.NonWaterNonHydrogenPDBSelector())
         particles = IMP.atom.get_by_type(mp, IMP.atom.ATOM_TYPE)
@@ -449,8 +497,22 @@ class SAXSApplicationTest(IMP.test.ApplicationTestCase):
         model_profile = IMP.saxs.Profile()
         model_profile.calculate_profile_partial(particles, surface_area)
 
+        # rewrite profile in 3 col format
+        tmpfl,tmpnam=tempfile.mkstemp()
+        tmpfl=os.fdopen(tmpfl,'w')
+        for line in open(automerge):
+            if line.startswith('#'):
+                continue
+            tokens=line.split()
+            if len(tokens)<3:
+                continue
+            tmpfl.write('\t'.join(tokens[:3]))
+            tmpfl.write('\n')
+        tmpfl.close()
         # fit the data
-        exp_profile = IMP.saxs.Profile(automerge)
+        exp_profile = IMP.saxs.Profile(tmpnam)
+        os.unlink(tmpnam)
+        print exp_profile.size(),model_profile.size()
         saxs_score = IMP.saxs.ProfileFitterChi(exp_profile)
         #passing default params, want to write log
         fitfile = os.path.join(destdir, 'foxs.dat')
@@ -468,10 +530,23 @@ class SAXSApplicationTest(IMP.test.ApplicationTestCase):
         chi = self.chisquare(automerge, fitfile, weighted=chi_wt,
                                 qmax=chi_qmax, lognormal=chi_ln,
                                 factor=(factor,0))
-        Rg = model_profile.radius_of_gyration()
+        Rg = self.get_guinier_Rg(fitfile, weighted=False)
 
+        # rewrite profile in 3 col format
+        tmpfl,tmpnam=tempfile.mkstemp()
+        tmpfl=os.fdopen(tmpfl,'w')
+        for line in open(manualmerge):
+            if line.startswith('#'):
+                continue
+            tokens=line.split()
+            if len(tokens)<3:
+                continue
+            tmpfl.write('\t'.join(tokens[:3]))
+            tmpfl.write('\n')
+        tmpfl.close()
         # fit manual merge
-        exp_profile = IMP.saxs.Profile(manualmerge)
+        exp_profile = IMP.saxs.Profile(tmpnam)
+        os.unlink(tmpnam)
         saxs_score = IMP.saxs.ProfileFitterChi(exp_profile)
         mfitori = os.path.join(destdir, 'foxsm.ori')
         mfitfile = os.path.join(destdir, 'foxsm.dat')
@@ -488,7 +563,10 @@ class SAXSApplicationTest(IMP.test.ApplicationTestCase):
         mchi = self.chisquare(automerge, mfitfile, weighted=chi_wt,
                                 qmax=chi_qmax, lognormal=chi_ln,
                                 factor=(factor,0))
-        mRg = model_profile.radius_of_gyration()
+        try:
+            mRg = self.get_guinier_Rg(mfitfile, weighted=False)
+        except:
+            mRg=-1
         #return chi(auto-foxs) chi(manual-foxs) Rg(pdb)
         return chi,mchi,Rg,mRg
 
@@ -512,7 +590,7 @@ class SAXSApplicationTest(IMP.test.ApplicationTestCase):
         chi = self.chisquare(os.path.join(destdir, automerge),
                 fitfile, weighted=chi_wt, qmax=chi_qmax, lognormal=chi_ln,
                 factor=(factor,0))
-        Rg = self.get_guinier_Rg(fitfile)
+        Rg = self.get_guinier_Rg(fitfile, weighted=False)
         return chi, Rg
 
     def rescale_curves(self, adata, amean, mmean, qmax=0.2):
@@ -550,23 +628,25 @@ class SAXSApplicationTest(IMP.test.ApplicationTestCase):
         fl.close()
         return dret,mret
 
-    def run_results(self, name, manual_merge, inputs, pdb=None,
+    def run_results(self, name, manual_merge, inputs, pdb=None, plot_data=False,
             extra_args=None):
         #rescale and fit the two curves
         destdir='compapp_'+name
         if not os.path.isdir(destdir):
             args = ['--destdir='+destdir,
-                 '--blimit_fitting=80', '--elimit_fitting=80',
+                 '--blimit_fitting=240', '--elimit_fitting=240',
                  '--blimit_hessian=80', '--elimit_hessian=80',
                  '--berror','--eerror',
                  '--cmodel=normal',
-                 '--bcomp', '--boptimize=Full',
+                 '--bmean=Full',
                  '--stop=rescaling', '--postpone_cleanup',
-                 '--npoints=-1', '--allfiles', '--outlevel=full',
+                 #'--npoints=-1',
+                 '--allfiles', '--outlevel=full',
                  'runapp_'+name+'/data_merged.dat', manual_merge]
             if extra_args:
                 args.append(extra_args)
-            #print ' '.join(args)
+            print "### run_results"
+            print ' '.join(args)
             #sys.exit()
             p = self.run_python_application('saxs_merge.py', args)
             out, err = p.communicate()
@@ -585,6 +665,7 @@ class SAXSApplicationTest(IMP.test.ApplicationTestCase):
         #compute chi2 of data
         datachi = self.chisquare(automergedata, manmergedata,
                         lognormal=False, qmax=None, factor=(autos,manuals))
+        print datachi
         #compute chi2 of fits
         fitchi = self.chisquare(automergemean, manmergemean,
                         lognormal=False, qmax=None)
@@ -608,42 +689,49 @@ class SAXSApplicationTest(IMP.test.ApplicationTestCase):
             crychi = None
             cryRg = None
         #radius of gyration
+        print automergemean
         guinierRg = self.get_guinier_Rg(automergemean)
-        mguinierRg = self.get_guinier_Rg(manmergemean)
+        try:
+            mguinierRg = self.get_guinier_Rg(manmergemean)
+        except:
+            mguinierRg=-1
         Rg, mRg = guinierRg, mguinierRg
         #Rg, mRg = self.get_GPI_Rg(destdir+'/summary.txt')
-        #get proper bounds
-        points=map(lambda a:map(float,a.split()[:2]),
-                open(manmergedata).readlines())
-        xmin = 0
-        xmax = max([i[0] for i in points if len(i) >= 2])*1.2
-        ymin = min([abs(i[1]) for i in points if len(i) >= 2])*0.8
-        ymax = max([i[1] for i in points if len(i) >= 2])*1.2
-        datarange = (xmin,xmax,ymin,ymax)
-        #plot data
-        self.plot_data_overlaid(name, automergedata,
-                manmergedata, datarange)
-        self.plot_data_colored(name,
-                'runapp_'+name+'/data_merged.dat', datarange)
-        #plot mean
-        self.plot_means(name, automergemean,
-                manmergemean, datarange)
-        self.plot_data_mean(name, automergedata, automergemean,
-                manmergedata, manmergemean, datarange)
-        #guinier plot
-        self.plot_guinier(name, automergedata,
-                automergemean, Rg)
-        #plot all those curves that were kept after cleanup
-        inpnames = map(os.path.basename, inputs)
-        inpnames = filter(lambda a: os.path.isfile(os.path.join(
-            'runapp_'+name,'data_'+a)), inpnames)
-        curves = ['runapp_'+name+'/data_'+i for i in inpnames]
-        mcurves = ['runapp_'+name+'/mean_'+i for i in inpnames]
-        self.plot_inputs(name, inpnames, curves, mcurves)
-        #plot pdb data
-        if pdb:
-            self.plot_pdb(name, destdir, os.path.basename(automergedata),
-                    'crysol.dat', 'foxs.dat', datarange, pdbchi, crychi)
+        #### plot data
+        if plot_data:
+            #get proper bounds
+            points=map(lambda a:map(float,a.split()[:2]),
+                    open(manmergedata).readlines())
+            xmin = 0
+            xmax = max([i[0] for i in points if len(i) >= 2])*1.2
+            ymin = min([abs(i[1]) for i in points if len(i) >= 2])*0.8
+            ymax = max([i[1] for i in points if len(i) >= 2])*1.2
+            datarange = (xmin,xmax,ymin,ymax)
+            #plot data
+            self.plot_data_overlaid(name, automergedata,
+                    manmergedata, datarange, datachi)
+            self.plot_data_colored(name,
+                    'runapp_'+name+'/data_merged.dat', datarange)
+            #plot mean
+            self.plot_means(name, automergemean,
+                    manmergemean, datarange, fitchi)
+            self.plot_data_mean(name, automergedata, automergemean,
+                    manmergedata, manmergemean, datarange)
+            #guinier plot
+            self.plot_guinier(name, automergedata,
+                    automergemean, Rg)
+            #plot all those curves that were kept after cleanup
+            inpnames = map(os.path.basename, inputs)
+            inpnames = filter(lambda a: os.path.isfile(os.path.join(
+                'runapp_'+name,'data_'+a)), inpnames)
+            curves = ['runapp_'+name+'/data_'+i for i in inpnames]
+            mcurves = ['runapp_'+name+'/mean_'+i for i in inpnames]
+            self.plot_inputs(name, inpnames, curves, mcurves)
+            self.plot_inputs_overlaid(name, inpnames, curves, mcurves)
+            #plot pdb data
+            if pdb:
+                self.plot_pdb(name, destdir, os.path.basename(automergedata),
+                        'crysol.dat', 'foxs.dat', datarange, pdbchi, crychi)
         return name,datachi,fitchi,Rg,guinierRg,mRg,mguinierRg,\
                 pdbRg,pdbchi,mpdbchi,crychi,cryRg,autos,manuals
 
@@ -654,7 +742,7 @@ class SAXSApplicationTest(IMP.test.ApplicationTestCase):
         return ' '.join(['%s' % i for i in ret])
 
 def create_test(paramnum, paramname, params, inputnum, inputname, inputs,
-        mergename, pdb=None):
+        mergename, pdb=None, plot_data=False):
     """params and inputs are lists of strings
        paramname and inputname are strings
        mergename is the path to manual merge file
@@ -662,6 +750,7 @@ def create_test(paramnum, paramname, params, inputnum, inputname, inputs,
     """
     outname=inputname+'_'+paramname
     def testcase(self):
+        print "Test case %d %d %s" % (inputnum, paramnum, outname)
         inp=map(self.get_input_file_name, inputs)
         merge = self.get_input_file_name(mergename)
         if pdb:
@@ -669,8 +758,12 @@ def create_test(paramnum, paramname, params, inputnum, inputname, inputs,
         else:
             pdbname = None
         self.run_app(outname, params+inp)
-        ret = self.run_results(outname, merge, inp, pdb=pdbname)
-        print self.make_stats(paramnum, inputnum, ret)
+        ret = self.run_results(outname, merge, inp, pdb=pdbname,
+                plot_data=plot_data)
+        data = self.make_stats(paramnum, inputnum, ret)
+        with open('bench_%d_%d.dat' % (inputnum, paramnum), 'w') as fl:
+            fl.write(data)
+            fl.write('\n')
     return testcase
 
 def create_datasets():
@@ -720,7 +813,7 @@ def create_datasets():
     d=dataset()
     d.name = 'Nup133'
     d.inputs = ['Nup133/23922_G4_2.mccd.dat',
-                'Nup133/23922_G2_2.mccd.dat',
+                #'Nup133/23922_G2_2.mccd.dat',
                 'Nup133/23922_G3_2.mccd.dat',
                 'Nup133/23922_G5_2.mccd.dat']
     d.mergename = 'Nup133/23922_merge.dat'
@@ -864,26 +957,19 @@ def create_params_list():
     params.append(['--aalpha=1e-4', '--cmodel=normal'])
     params.append(['--postpone_cleanup', '--cmodel=normal'])
     params.append(['--cmodel=normal-offset'])
-    params.append(['--cmodel=normal', '--bcomp', '--blimit_hessian=100',
+    params.append(['--cmodel=normal', '--blimit_hessian=100',
                 '--boptimize=Full'])
     return params
 
 def create_params_shuffle():
     items=[]
-    items.append(['--aalpha=1e-1',
-                  '--aalpha=1e-2',
-                  '--aalpha=1e-3',
-                  '--aalpha=1e-4',
-                  '--aalpha=1e-5',
-                  '--aalpha=1e-6',
-                  '--aalpha=1e-7',
-                  '--aalpha=1e-8',
-                  '--aalpha=1e-9'])
-    items.append(['--bcomp --ecomp --boptimize=Full --eoptimize=Full',
-                   '--boptimize=Flat --eoptimize=Generalized',
-                   '--boptimize=Simple --eoptimize=Generalized' ])
-    items.append(['--cmodel=normal','--cmodel=lognormal',
-                  '--cmodel=normal-offset'])
+    items.append(['--aalpha=0.05'])
+    items.append(['--auto'])
+    items.append([#'--remove_redundant', '--remove_noisy',
+        '--remove_redundant --remove_noisy'])
+    items.append(['--blimit_hessian=80 --elimit_hessian=80'])
+    items.append([
+        '--blimit_fitting=240 --elimit_fitting=240'])
     params = []
     for i in itertools.product(*items):
         tmp=[]
@@ -900,7 +986,7 @@ for k, param in enumerate(params):
     for l, dset in enumerate(datasets):
         test_method = create_test(k, str(k), param,
                                   l, dset.name, dset.inputs,
-                                  dset.mergename, dset.pdb)
+                                  dset.mergename, dset.pdb, plot_data=True)
         test_method.__name__ = 'test_case_%d_%d' % (l,k)
         setattr(SAXSApplicationTest, test_method.__name__, test_method)
 
