@@ -11,6 +11,8 @@ try:
 except ImportError:
     numpy = None
 
+IMP.set_log_level(0)
+
 class MockGP:
     def __init__(self,a,b):
         self.a=a
@@ -426,24 +428,24 @@ class SAXSProfileTest(IMP.test.ApplicationTestCase):
     def test_set_interpolant(self):
         gp=MockGP(1,2)
         p=self.SAXSProfile()
-        m=IMP.Model()
-        s=IMP.isd.Scale.setup_particle(IMP.Particle(m),3.0)
+        m=IMP.kernel.Model()
+        s=IMP.isd.Scale.setup_particle(IMP.kernel.Particle(m),3.0)
         self.assertRaises(TypeError, p.set_interpolant, gp)
         self.assertRaises(TypeError, p.set_interpolant, gp, [])
         self.assertRaises(TypeError, p.set_interpolant, gp, {'test':1.0})
         self.assertEqual(p.set_interpolant(gp,{'sigma':s},
-            {'mean':None,'covariance':None},'test',IMP.Model(), None), None)
+            {'mean':None,'covariance':None},'test',IMP.kernel.Model(), None), None)
 
     def test_get_params(self):
         "get_params should return a dict"
         gp=MockGP(1,2)
         p=self.SAXSProfile()
-        m=IMP.Model()
-        s=IMP.isd.Scale.setup_particle(IMP.Particle(m),3.0)
+        m=IMP.kernel.Model()
+        s=IMP.isd.Scale.setup_particle(IMP.kernel.Particle(m),3.0)
         functions={}
         functions['mean']=MockFunction()
         functions['covariance']=MockFunction()
-        p.set_interpolant(gp,{'sigma':s}, functions, 'test', IMP.Model(), None)
+        p.set_interpolant(gp,{'sigma':s}, functions, 'test', IMP.kernel.Model(), None)
         self.assertEqual(p.get_params(),{'sigma':3.0})
 
     def test_get_mean_defaults(self):
@@ -452,12 +454,12 @@ class SAXSProfileTest(IMP.test.ApplicationTestCase):
         p=self.SAXSProfile()
         p.add_data(data)
         gp = MockGP(1,2)
-        m=IMP.Model()
-        s=IMP.isd.Scale.setup_particle(IMP.Particle(m),3.0)
+        m=IMP.kernel.Model()
+        s=IMP.isd.Scale.setup_particle(IMP.kernel.Particle(m),3.0)
         functions={}
         functions['mean']=MockFunction()
         functions['covariance']=MockFunction()
-        p.set_interpolant(gp,{'sigma':s}, functions, 'test', IMP.Model(), None)
+        p.set_interpolant(gp,{'sigma':s}, functions, 'test', IMP.kernel.Model(), None)
         test = p.get_mean()
         expected_q = numpy.linspace(0,0.02,num=200)
         expected_I = map(gp.get_posterior_mean,[[i] for i in expected_q])
@@ -480,12 +482,12 @@ class SAXSProfileTest(IMP.test.ApplicationTestCase):
         p=self.SAXSProfile()
         p.add_data(data)
         gp = MockGP(1,2)
-        m=IMP.Model()
-        s=IMP.isd.Scale.setup_particle(IMP.Particle(m),3.0)
+        m=IMP.kernel.Model()
+        s=IMP.isd.Scale.setup_particle(IMP.kernel.Particle(m),3.0)
         functions={}
         functions['mean']=MockFunction()
         functions['covariance']=MockFunction()
-        p.set_interpolant(gp,{'sigma':s}, functions, 'test', IMP.Model(), None)
+        p.set_interpolant(gp,{'sigma':s}, functions, 'test', IMP.kernel.Model(), None)
         test = p.get_mean(colwise=True)
         expected_q = numpy.linspace(0,0.02,num=200)
         expected_I = numpy.array(map(gp.get_posterior_mean,
@@ -510,12 +512,12 @@ class SAXSProfileTest(IMP.test.ApplicationTestCase):
         gamma = 21.5
         p.set_gamma(gamma)
         gp = MockGP(1,2)
-        m=IMP.Model()
-        s=IMP.isd.Scale.setup_particle(IMP.Particle(m),3.0)
+        m=IMP.kernel.Model()
+        s=IMP.isd.Scale.setup_particle(IMP.kernel.Particle(m),3.0)
         functions={}
         functions['mean']=MockFunction()
         functions['covariance']=MockFunction()
-        p.set_interpolant(gp,{'sigma':s}, functions, 'test', IMP.Model(), None)
+        p.set_interpolant(gp,{'sigma':s}, functions, 'test', IMP.kernel.Model(), None)
         test = p.get_mean()
         expected_q = numpy.linspace(0,0.02,num=200)
         expected_I = map(lambda a:
@@ -540,12 +542,12 @@ class SAXSProfileTest(IMP.test.ApplicationTestCase):
         p=self.SAXSProfile()
         p.add_data(data)
         gp = MockGP(1,2)
-        m=IMP.Model()
-        s=IMP.isd.Scale.setup_particle(IMP.Particle(m),3.0)
+        m=IMP.kernel.Model()
+        s=IMP.isd.Scale.setup_particle(IMP.kernel.Particle(m),3.0)
         functions={}
         functions['mean']=MockFunction()
         functions['covariance']=MockFunction()
-        p.set_interpolant(gp,{'sigma':s}, functions, 'test', IMP.Model(), None)
+        p.set_interpolant(gp,{'sigma':s}, functions, 'test', IMP.kernel.Model(), None)
         test = p.get_mean(num=100)
         expected_q = numpy.linspace(0,0.02,num=100)
         expected_I = map(gp.get_posterior_mean,[[i] for i in expected_q])
@@ -563,12 +565,12 @@ class SAXSProfileTest(IMP.test.ApplicationTestCase):
         p=self.SAXSProfile()
         p.add_data(data)
         gp = MockGP(1,2)
-        m=IMP.Model()
-        s=IMP.isd.Scale.setup_particle(IMP.Particle(m),3.0)
+        m=IMP.kernel.Model()
+        s=IMP.isd.Scale.setup_particle(IMP.kernel.Particle(m),3.0)
         functions={}
         functions['mean']=MockFunction()
         functions['covariance']=MockFunction()
-        p.set_interpolant(gp,{'sigma':s}, functions, 'test', IMP.Model(), None)
+        p.set_interpolant(gp,{'sigma':s}, functions, 'test', IMP.kernel.Model(), None)
         test = p.get_mean(num=100,qmin=1.5,qmax=1.67)
         expected_q = numpy.linspace(1.5,1.67,num=100)
         expected_I = map(gp.get_posterior_mean,[[i] for i in expected_q])
@@ -586,12 +588,12 @@ class SAXSProfileTest(IMP.test.ApplicationTestCase):
         p=self.SAXSProfile()
         p.add_data(data)
         gp = MockGP(1,2)
-        m=IMP.Model()
-        s=IMP.isd.Scale.setup_particle(IMP.Particle(m),3.0)
+        m=IMP.kernel.Model()
+        s=IMP.isd.Scale.setup_particle(IMP.kernel.Particle(m),3.0)
         functions={}
         functions['mean']=MockFunction()
         functions['covariance']=MockFunction()
-        p.set_interpolant(gp,{'sigma':s}, functions, 'test', IMP.Model(), None)
+        p.set_interpolant(gp,{'sigma':s}, functions, 'test', IMP.kernel.Model(), None)
         expected_q=numpy.random.uniform(0,[1]*10)
         expected_q.sort()
         test = p.get_mean(qvalues=expected_q)
@@ -619,12 +621,12 @@ class SAXSProfileTest(IMP.test.ApplicationTestCase):
         p=self.SAXSProfile()
         p.add_data(data)
         gp = MockGP(1,2)
-        m=IMP.Model()
-        s=IMP.isd.Scale.setup_particle(IMP.Particle(m),3.0)
+        m=IMP.kernel.Model()
+        s=IMP.isd.Scale.setup_particle(IMP.kernel.Particle(m),3.0)
         functions={}
         functions['mean']=MockFunction()
         functions['covariance']=MockFunction()
-        p.set_interpolant(gp,{'sigma':s}, functions, 'test', IMP.Model(), None)
+        p.set_interpolant(gp,{'sigma':s}, functions, 'test', IMP.kernel.Model(), None)
         expected_q=numpy.random.uniform(0,[1]*10)
         expected_q.sort()
         p.new_flag("test",bool)
@@ -650,12 +652,12 @@ class SAXSProfileTest(IMP.test.ApplicationTestCase):
         p=self.SAXSProfile()
         p.add_data(data)
         gp = MockGP(1,2)
-        m=IMP.Model()
-        s=IMP.isd.Scale.setup_particle(IMP.Particle(m),3.0)
+        m=IMP.kernel.Model()
+        s=IMP.isd.Scale.setup_particle(IMP.kernel.Particle(m),3.0)
         functions={}
         functions['mean']=MockFunction()
         functions['covariance']=MockFunction()
-        p.set_interpolant(gp,{'sigma':s}, functions, 'test', IMP.Model(), None)
+        p.set_interpolant(gp,{'sigma':s}, functions, 'test', IMP.kernel.Model(), None)
         expected_q=numpy.random.uniform(0,[1]*10)
         expected_q.sort()
         p.new_flag("test",bool)
@@ -681,12 +683,12 @@ class SAXSProfileTest(IMP.test.ApplicationTestCase):
         p=self.SAXSProfile()
         p.add_data(data)
         gp = MockGP(1,2)
-        m=IMP.Model()
-        s=IMP.isd.Scale.setup_particle(IMP.Particle(m),3.0)
+        m=IMP.kernel.Model()
+        s=IMP.isd.Scale.setup_particle(IMP.kernel.Particle(m),3.0)
         functions={}
         functions['mean']=MockFunction()
         functions['covariance']=MockFunction()
-        p.set_interpolant(gp,{'sigma':s}, functions, 'test', IMP.Model(), None)
+        p.set_interpolant(gp,{'sigma':s}, functions, 'test', IMP.kernel.Model(), None)
         expected_q=numpy.random.uniform(0,[1]*10)
         expected_q.sort()
         p.new_flag("test",bool)
@@ -712,12 +714,12 @@ class SAXSProfileTest(IMP.test.ApplicationTestCase):
         p=self.SAXSProfile()
         p.add_data(data)
         gp = MockGP(1,2)
-        m=IMP.Model()
-        s=IMP.isd.Scale.setup_particle(IMP.Particle(m),3.0)
+        m=IMP.kernel.Model()
+        s=IMP.isd.Scale.setup_particle(IMP.kernel.Particle(m),3.0)
         functions={}
         functions['mean']=MockFunction()
         functions['covariance']=MockFunction()
-        p.set_interpolant(gp,{'sigma':s}, functions, 'test', IMP.Model(), None)
+        p.set_interpolant(gp,{'sigma':s}, functions, 'test', IMP.kernel.Model(), None)
         expected_q=numpy.random.uniform(0,[1]*10)
         expected_q.sort()
         p.new_flag("test",bool)
@@ -744,12 +746,12 @@ class SAXSProfileTest(IMP.test.ApplicationTestCase):
         p=self.SAXSProfile()
         p.add_data(data)
         gp = MockGP(1,2)
-        m=IMP.Model()
-        s=IMP.isd.Scale.setup_particle(IMP.Particle(m),3.0)
+        m=IMP.kernel.Model()
+        s=IMP.isd.Scale.setup_particle(IMP.kernel.Particle(m),3.0)
         functions={}
         functions['mean']=MockFunction()
         functions['covariance']=MockFunction()
-        p.set_interpolant(gp,{'sigma':s}, functions, 'test', IMP.Model(), None)
+        p.set_interpolant(gp,{'sigma':s}, functions, 'test', IMP.kernel.Model(), None)
         expected_q=numpy.random.uniform(0,[1]*10)
         expected_q.sort()
         p.new_flag("test",bool)
@@ -828,12 +830,12 @@ class SAXSProfileTest(IMP.test.ApplicationTestCase):
         p=self.SAXSProfile()
         p.add_data(data)
         gp = MockGP(1,2)
-        m=IMP.Model()
-        s=IMP.isd.Scale.setup_particle(IMP.Particle(m),3.0)
+        m=IMP.kernel.Model()
+        s=IMP.isd.Scale.setup_particle(IMP.kernel.Particle(m),3.0)
         functions={}
         functions['mean']=MockFunction()
         functions['covariance']=MockFunction()
-        p.set_interpolant(gp,{'sigma':s}, functions, 'test', IMP.Model(), None)
+        p.set_interpolant(gp,{'sigma':s}, functions, 'test', IMP.kernel.Model(), None)
         expected_q=numpy.random.uniform(0,[1]*10)
         expected_q.sort()
         p.new_flag("test",bool)
@@ -854,12 +856,12 @@ class SAXSProfileTest(IMP.test.ApplicationTestCase):
         p=self.SAXSProfile()
         p.add_data(data)
         gp = MockGP(1,2)
-        m=IMP.Model()
-        s=IMP.isd.Scale.setup_particle(IMP.Particle(m),3.0)
+        m=IMP.kernel.Model()
+        s=IMP.isd.Scale.setup_particle(IMP.kernel.Particle(m),3.0)
         functions={}
         functions['mean']=MockFunction()
         functions['covariance']=MockFunction()
-        p.set_interpolant(gp,{'sigma':s}, functions, 'test', IMP.Model(), None)
+        p.set_interpolant(gp,{'sigma':s}, functions, 'test', IMP.kernel.Model(), None)
         expected_q=numpy.random.uniform(0,[1]*10)
         expected_q.sort()
         p.new_flag("test",bool)
@@ -880,12 +882,12 @@ class SAXSProfileTest(IMP.test.ApplicationTestCase):
         p=self.SAXSProfile()
         p.add_data(data)
         gp = MockGP(1,2)
-        m=IMP.Model()
-        s=IMP.isd.Scale.setup_particle(IMP.Particle(m),3.0)
+        m=IMP.kernel.Model()
+        s=IMP.isd.Scale.setup_particle(IMP.kernel.Particle(m),3.0)
         functions={}
         functions['mean']=MockFunction()
         functions['covariance']=MockFunction()
-        p.set_interpolant(gp,{'sigma':s}, functions, 'test', IMP.Model(), None)
+        p.set_interpolant(gp,{'sigma':s}, functions, 'test', IMP.kernel.Model(), None)
         expected_q=numpy.random.uniform(0,[1]*10)
         expected_q.sort()
         p.new_flag("test",bool)
@@ -908,12 +910,12 @@ class SAXSProfileTest(IMP.test.ApplicationTestCase):
         p=self.SAXSProfile()
         p.add_data(data)
         gp = MockGP(1,2)
-        m=IMP.Model()
-        s=IMP.isd.Scale.setup_particle(IMP.Particle(m),3.0)
+        m=IMP.kernel.Model()
+        s=IMP.isd.Scale.setup_particle(IMP.kernel.Particle(m),3.0)
         functions={}
         functions['mean']=MockFunction()
         functions['covariance']=MockFunction()
-        p.set_interpolant(gp,{'sigma':s}, functions, 'test', IMP.Model(), None)
+        p.set_interpolant(gp,{'sigma':s}, functions, 'test', IMP.kernel.Model(), None)
         expected_q=numpy.random.uniform(0,[1]*10)
         expected_q.sort()
         p.new_flag("test",bool)
