@@ -19,8 +19,7 @@ IMPALGEBRA_BEGIN_NAMESPACE
 
 #if !defined(IMP_DOXYGEN) && !defined(SWIG)
 class Transformation3D;
-Transformation3D compose(const Transformation3D &a,
-                         const Transformation3D &b);
+Transformation3D compose(const Transformation3D &a, const Transformation3D &b);
 #endif
 
 //! Simple 3D transformation class
@@ -28,34 +27,31 @@ Transformation3D compose(const Transformation3D &a,
     \see IMP::core::Transform
     \geometry
 */
-class IMPALGEBRAEXPORT Transformation3D: public GeometricPrimitiveD<3>
-{
-public:
+class IMPALGEBRAEXPORT Transformation3D : public GeometricPrimitiveD<3> {
+ public:
+  IMP_CXX11_DEFAULT_COPY_CONSTRUCTOR(Transformation3D);
   //! construct an invalid transformation
-  Transformation3D(){}
+  Transformation3D() {}
   /** basic constructor*/
-  Transformation3D(const Rotation3D& r,
-                   const Vector3D& t=Vector3D(0,0,0)):
-    trans_(t), rot_(r){}
+  Transformation3D(const Rotation3D &r, const Vector3D &t = Vector3D(0, 0, 0))
+      : trans_(t), rot_(r) {}
   /** Construct a transformation with an identity rotation.*/
-  Transformation3D(const Vector3D& t):
-    trans_(t), rot_(get_identity_rotation_3d()){}
+  Transformation3D(const Vector3D &t)
+      : trans_(t), rot_(get_identity_rotation_3d()) {}
   ~Transformation3D();
   //! transform
   Vector3D get_transformed(const Vector3D &o) const {
     return rot_.get_rotated(o) + trans_;
   }
   //! apply transformation (rotate and then translate)
-  Vector3D operator*(const Vector3D &v) const {
-    return get_transformed(v);
-  }
+  Vector3D operator*(const Vector3D &v) const { return get_transformed(v); }
   /** compose two rigid transformation such that for any vector v
       (rt1*rt2)*v = rt1*(rt2*v) */
   Transformation3D operator*(const Transformation3D &tr) const {
     return compose(*this, tr);
   }
-  const Transformation3D& operator*=(const Transformation3D &o) {
-    *this=compose(*this, o);
+  const Transformation3D &operator*=(const Transformation3D &o) {
+    *this = compose(*this, o);
     return *this;
   }
   /** Compute the transformation which, when composed with b, gives *this.
@@ -65,36 +61,33 @@ public:
       I don't know what name to give it.
   */
   Transformation3D operator/(const Transformation3D &b) const {
-    Transformation3D ret= compose(*this, b.get_inverse());
+    Transformation3D ret = compose(*this, b.get_inverse());
     return ret;
   }
-  const Transformation3D& operator/=(const Transformation3D &o) {
-    *this= *this/o;
+  const Transformation3D &operator/=(const Transformation3D &o) {
+    *this = *this / o;
     return *this;
   }
-  const Rotation3D& get_rotation() const {
-    return rot_;
-  }
-  const Vector3D& get_translation()const{return trans_;}
+  const Rotation3D &get_rotation() const { return rot_; }
+  const Vector3D &get_translation() const { return trans_; }
 
   IMP_SHOWABLE_INLINE(Transformation3D, {
-      rot_.show(out);
-      out<<" || "<<trans_;
-    }
-    );
+    rot_.show(out);
+    out << " || " << trans_;
+  });
   Transformation3D get_inverse() const;
-private:
-  Vector3D trans_; //translation
-  Rotation3D rot_;  //rotation
+
+ private:
+  Vector3D trans_;  // translation
+  Rotation3D rot_;  // rotation
 };
 
 IMP_VALUES(Transformation3D, Transformation3Ds);
 
-
 //! Return a transformation that does not do anything
-/** \relatesalso Transformation3D */
+/** See Transformation3D */
 inline Transformation3D get_identity_transformation_3d() {
-  return Transformation3D(get_identity_rotation_3d(),Vector3D(0.0,0.0,0.0));
+  return Transformation3D(get_identity_rotation_3d(), Vector3D(0.0, 0.0, 0.0));
 }
 
 //! Generate a Transformation3D object from a rotation around a point
@@ -102,20 +95,19 @@ inline Transformation3D get_identity_transformation_3d() {
   \param[in] point Center to rotate about
   \param[in] rotation The rotation to perform
 
-  \relatesalso Transformation3D
+  See Transformation3D
 */
-inline Transformation3D
-get_rotation_about_point(const Vector3D &point,
-                     const Rotation3D &rotation) {
-  return Transformation3D(rotation, (rotation*(-point)+point));
+inline Transformation3D get_rotation_about_point(const Vector3D &point,
+                                                 const Rotation3D &rotation) {
+  return Transformation3D(rotation, (rotation * (-point) + point));
 }
 
 //! compose two transformations
-  /** For any vector v (a*b)*v = a*(b*v).
-      \relatesalso Transformation3D
-   */
+/** For any vector v (a*b)*v = a*(b*v).
+    See Transformation3D
+ */
 inline Transformation3D compose(const Transformation3D &a,
-                                const Transformation3D &b){
+                                const Transformation3D &b) {
   return Transformation3D(compose(a.get_rotation(), b.get_rotation()),
                           a.get_transformed(b.get_translation()));
 }
@@ -127,8 +119,8 @@ class Transformation2D;
   \note The 3D transformation is built with the 2D rotation becoming a rotation
   around the z axis.
   **/
-IMPALGEBRAEXPORT Transformation3D get_transformation_3d(
-                                  const Transformation2D &t2d);
+IMPALGEBRAEXPORT Transformation3D
+    get_transformation_3d(const Transformation2D &t2d);
 
 //! Get a local transformation
 /**
@@ -138,25 +130,21 @@ IMPALGEBRAEXPORT Transformation3D get_transformation_3d(
   \param[in] max_translation detault value is 5
   \param[in] max_angle_in_rad default value is 15 degree in radians
   **/
-IMPALGEBRAEXPORT Transformation3D get_random_local_transformation(
-   Vector3D origin,
-   double max_translation=5.,
-   double max_angle_in_rad=0.26);
-
-
-
+IMPALGEBRAEXPORT Transformation3D
+    get_random_local_transformation(Vector3D origin,
+                                    double max_translation = 5.,
+                                    double max_angle_in_rad = 0.26);
 
 //! Return a bounding box containing the transformed box
 inline BoundingBoxD<3> get_transformed(const BoundingBoxD<3> &bb,
                                        const Transformation3D &tr) {
   BoundingBoxD<3> nbb;
-  for (unsigned int i=0; i< 2; ++i) {
-    for (unsigned int j=0; j< 2; ++j) {
-      for (unsigned int k=0; k< 2; ++k) {
-        algebra::Vector3D v(bb.get_corner(i)[0],
-                            bb.get_corner(j)[1],
+  for (unsigned int i = 0; i < 2; ++i) {
+    for (unsigned int j = 0; j < 2; ++j) {
+      for (unsigned int k = 0; k < 2; ++k) {
+        algebra::Vector3D v(bb.get_corner(i)[0], bb.get_corner(j)[1],
                             bb.get_corner(k)[2]);
-        nbb+= tr.get_transformed(v);
+        nbb += tr.get_transformed(v);
       }
     }
   }
@@ -165,4 +153,4 @@ inline BoundingBoxD<3> get_transformed(const BoundingBoxD<3> &bb,
 
 IMPALGEBRA_END_NAMESPACE
 
-#endif  /* IMPALGEBRA_TRANSFORMATION_3D_H */
+#endif /* IMPALGEBRA_TRANSFORMATION_3D_H */
