@@ -31,216 +31,171 @@
 #include "tnt_array1d.h"
 
 IMPALGEBRA_BEGIN_INTERNAL_NAMESPACE
-namespace TNT
-{
+namespace TNT {
 using namespace std;
 
 template <class T>
-class Array2D
-{
+class Array2D {
 
+ private:
 
-  private:
-
-
-
-    Array1D<T> data_;
-  Array1D<T*> v_;
+  Array1D<T> data_;
+  Array1D<T *> v_;
   int m_;
-    int n_;
+  int n_;
 
-  public:
+ public:
 
-    typedef         T   value_type;
-         Array2D();
-         Array2D(int m, int n);
-         Array2D(int m, int n,  T *a);
-         Array2D(int m, int n, const T &a);
-    inline Array2D(const Array2D &A);
+  typedef T value_type;
+  Array2D();
+  Array2D(int m, int n);
+  Array2D(int m, int n, T *a);
+  Array2D(int m, int n, const T &a);
+  inline Array2D(const Array2D &A);
   /*explicit inline operator T**();
   explicit inline operator const T**();*/
-  inline Array2D & operator=(const T &a);
-  inline Array2D & operator=(const Array2D &A);
-  inline Array2D & ref(const Array2D &A);
-         Array2D copy() const;
-       Array2D & inject(const Array2D & A);
-  inline T* operator[](int i);
-  inline const T* operator[](int i) const;
+  inline Array2D &operator=(const T &a);
+  inline Array2D &operator=(const Array2D &A);
+  inline Array2D &ref(const Array2D &A);
+  Array2D copy() const;
+  Array2D &inject(const Array2D &A);
+  inline T *operator[](int i);
+  inline const T *operator[](int i) const;
   inline int dim1() const;
   inline int dim2() const;
-     ~Array2D();
+  ~Array2D();
 
   /* extended interface (not part of the standard) */
 
-
   inline int ref_count();
   inline int ref_count_data();
   inline int ref_count_dim1();
   Array2D subarray(int i0, int i1, int j0, int j1);
-
 };
 
+template <class T>
+Array2D<T>::Array2D()
+    : data_(), v_(), m_(0), n_(0) {}
 
 template <class T>
-Array2D<T>::Array2D() : data_(), v_(), m_(0), n_(0) {}
+Array2D<T>::Array2D(const Array2D<T> &A)
+    : data_(A.data_), v_(A.v_), m_(A.m_), n_(A.n_) {}
 
 template <class T>
-Array2D<T>::Array2D(const Array2D<T> &A) : data_(A.data_), v_(A.v_),
-  m_(A.m_), n_(A.n_) {}
-
-
-
-
-template <class T>
-Array2D<T>::Array2D(int m, int n) : data_(m*n), v_(m), m_(m), n_(n)
-{
-  if (m>0 && n>0)
-  {
-    T* p = &(data_[0]);
-    for (int i=0; i<m; i++)
-    {
+Array2D<T>::Array2D(int m, int n)
+    : data_(m * n), v_(m), m_(m), n_(n) {
+  if (m > 0 && n > 0) {
+    T *p = &(data_[0]);
+    for (int i = 0; i < m; i++) {
       v_[i] = p;
       p += n;
     }
   }
 }
 
-
-
 template <class T>
-Array2D<T>::Array2D(int m, int n, const T &val) : data_(m*n), v_(m),
-                          m_(m), n_(n)
-{
-  if (m>0 && n>0)
-  {
-  data_ = val;
-  T* p  = &(data_[0]);
-  for (int i=0; i<m; i++)
-  {
+Array2D<T>::Array2D(int m, int n, const T &val)
+    : data_(m * n), v_(m), m_(m), n_(n) {
+  if (m > 0 && n > 0) {
+    data_ = val;
+    T *p = &(data_[0]);
+    for (int i = 0; i < m; i++) {
       v_[i] = p;
       p += n;
-  }
+    }
   }
 }
 
 template <class T>
-Array2D<T>::Array2D(int m, int n, T *a) : data_(m*n, a), v_(m), m_(m), n_(n)
-{
-  if (m>0 && n>0)
-  {
-  T* p = &(data_[0]);
+Array2D<T>::Array2D(int m, int n, T *a)
+    : data_(m * n, a), v_(m), m_(m), n_(n) {
+  if (m > 0 && n > 0) {
+    T *p = &(data_[0]);
 
-  for (int i=0; i<m; i++)
-  {
+    for (int i = 0; i < m; i++) {
       v_[i] = p;
       p += n;
-  }
+    }
   }
 }
 
-
 template <class T>
-inline T* Array2D<T>::operator[](int i)
-{
+inline T *Array2D<T>::operator[](int i) {
 #ifdef TNT_BOUNDS_CHECK
   assert(i >= 0);
   assert(i < m_);
 #endif
 
-return v_[i];
-
+  return v_[i];
 }
 
-
 template <class T>
-inline const T* Array2D<T>::operator[](int i) const
-{
+inline const T *Array2D<T>::operator[](int i) const {
 #ifdef TNT_BOUNDS_CHECK
   assert(i >= 0);
   assert(i < m_);
 #endif
 
-return v_[i];
-
+  return v_[i];
 }
 
 template <class T>
-Array2D<T> & Array2D<T>::operator=(const T &a)
-{
+Array2D<T> &Array2D<T>::operator=(const T &a) {
   /* non-optimzied, but will work with subarrays in future verions */
 
-  for (int i=0; i<m_; i++)
-    for (int j=0; j<n_; j++)
-    v_[i][j] = a;
+  for (int i = 0; i < m_; i++)
+    for (int j = 0; j < n_; j++) v_[i][j] = a;
   return *this;
 }
 
-
-
-
 template <class T>
-Array2D<T> Array2D<T>::copy() const
-{
+Array2D<T> Array2D<T>::copy() const {
   Array2D A(m_, n_);
 
-  for (int i=0; i<m_; i++)
-    for (int j=0; j<n_; j++)
-      A[i][j] = v_[i][j];
-
+  for (int i = 0; i < m_; i++)
+    for (int j = 0; j < n_; j++) A[i][j] = v_[i][j];
 
   return A;
 }
 
-
 template <class T>
-Array2D<T> & Array2D<T>::inject(const Array2D &A)
-{
-  if (A.m_ == m_ &&  A.n_ == n_)
-  {
-    for (int i=0; i<m_; i++)
-      for (int j=0; j<n_; j++)
-        v_[i][j] = A[i][j];
+Array2D<T> &Array2D<T>::inject(const Array2D &A) {
+  if (A.m_ == m_ && A.n_ == n_) {
+    for (int i = 0; i < m_; i++)
+      for (int j = 0; j < n_; j++) v_[i][j] = A[i][j];
   }
   return *this;
 }
 
-
-
-
 template <class T>
-Array2D<T> & Array2D<T>::ref(const Array2D<T> &A)
-{
-  if (this != &A)
-  {
+Array2D<T> &Array2D<T>::ref(const Array2D<T> &A) {
+  if (this != &A) {
     v_ = A.v_;
     data_ = A.data_;
     m_ = A.m_;
     n_ = A.n_;
-
   }
   return *this;
 }
 
-
-
 template <class T>
-Array2D<T> & Array2D<T>::operator=(const Array2D<T> &A)
-{
+Array2D<T> &Array2D<T>::operator=(const Array2D<T> &A) {
   return ref(A);
 }
 
 template <class T>
-inline int Array2D<T>::dim1() const { return m_; }
+inline int Array2D<T>::dim1() const {
+  return m_;
+}
 
 template <class T>
-inline int Array2D<T>::dim2() const { return n_; }
-
+inline int Array2D<T>::dim2() const {
+  return n_;
+}
 
 template <class T>
 Array2D<T>::~Array2D() {}
 
-
-
 /*
 template <class T>
 inline Array2D<T>::operator T**()
@@ -262,54 +217,42 @@ inline Array2D<T>::operator const T**()
 
 */
 template <class T>
-Array2D<T> Array2D<T>::subarray(int i0, int i1, int j0, int j1)
-{
+Array2D<T> Array2D<T>::subarray(int i0, int i1, int j0, int j1) {
   Array2D<T> A;
-  int m = i1-i0+1;
-  int n = j1-j0+1;
+  int m = i1 - i0 + 1;
+  int n = j1 - j0 + 1;
 
   /* if either length is zero or negative, this is an invalide
     subarray. return a null view.
   */
-  if (m<1 || n<1)
-    return A;
+  if (m < 1 || n < 1) return A;
 
   A.data_ = data_;
   A.m_ = m;
   A.n_ = n;
-  A.v_ = Array1D<T*>(m);
-  T* p = &(data_[0]) + i0 *  n_ + j0;
-  for (int i=0; i<m; i++)
-  {
-    A.v_[i] = p + i*n_;
-
+  A.v_ = Array1D<T *>(m);
+  T *p = &(data_[0]) + i0 * n_ + j0;
+  for (int i = 0; i < m; i++) {
+    A.v_[i] = p + i * n_;
   }
   return A;
 }
 
 template <class T>
-inline int Array2D<T>::ref_count()
-{
+inline int Array2D<T>::ref_count() {
   return ref_count_data();
 }
 
-
-
 template <class T>
-inline int Array2D<T>::ref_count_data()
-{
+inline int Array2D<T>::ref_count_data() {
   return data_.ref_count();
 }
 
 template <class T>
-inline int Array2D<T>::ref_count_dim1()
-{
+inline int Array2D<T>::ref_count_dim1() {
   return v_.ref_count();
 }
 
-
-
-
 } /* namespace TNT */
 
 IMPALGEBRA_END_INTERNAL_NAMESPACE
