@@ -28,10 +28,8 @@
 #include <assert.h>
 #endif
 
-
 IMPALGEBRA_BEGIN_INTERNAL_NAMESPACE
-namespace TNT
-{
+namespace TNT {
 using namespace std;
 /*
   Internal representation of ref-counted array.  The TNT
@@ -50,55 +48,49 @@ using namespace std;
 
 */
 template <class T>
-class i_refvec
-{
+class i_refvec {
 
+ private:
+  T* data_;
+  int* ref_count_;
 
-  private:
-    T* data_;
-    int *ref_count_;
+ public:
 
-
-  public:
-
-       i_refvec();
+  i_refvec();
   explicit i_refvec(int n);
-  inline   i_refvec(T* data);
-  inline   i_refvec(const i_refvec &v);
-  inline   T*     begin();
+  inline i_refvec(T* data);
+  inline i_refvec(const i_refvec& v);
+  inline T* begin();
   inline const T* begin() const;
-  inline  T& operator[](int i);
+  inline T& operator[](int i);
   inline const T& operator[](int i) const;
-  inline  i_refvec<T> & operator=(const i_refvec<T> &V);
-        void copy_(T* p, const T* q, const T* e);
-        void set_(T* p, const T* b, const T* e);
-  inline   int   ref_count() const;
-  inline  int is_null() const;
-  inline  void destroy();
-       ~i_refvec();
-
+  inline i_refvec<T>& operator=(const i_refvec<T>& V);
+  void copy_(T* p, const T* q, const T* e);
+  void set_(T* p, const T* b, const T* e);
+  inline int ref_count() const;
+  inline int is_null() const;
+  inline void destroy();
+  ~i_refvec();
 };
 
 template <class T>
-void i_refvec<T>::copy_(T* p, const T* q, const T* e)
-{
-  for (T* t=p; q<e; t++, q++)
-    *t= *q;
+void i_refvec<T>::copy_(T* p, const T* q, const T* e) {
+  for (T* t = p; q < e; t++, q++) *t = *q;
 }
 
 template <class T>
-i_refvec<T>::i_refvec() : data_(nullptr), ref_count_(nullptr) {}
+i_refvec<T>::i_refvec()
+    : data_(nullptr), ref_count_(nullptr) {}
 
 /**
   In case n is 0 or negative, it does NOT call new.
 */
 template <class T>
-i_refvec<T>::i_refvec(int n) : data_(nullptr), ref_count_(nullptr)
-{
-  if (n >= 1)
-  {
+i_refvec<T>::i_refvec(int n)
+    : data_(nullptr), ref_count_(nullptr) {
+  if (n >= 1) {
 #ifdef TNT_DEBUG
-    std::cout  << "new data storage.\n";
+    std::cout << "new data storage.\n";
 #endif
     data_ = new T[n];
     ref_count_ = new int;
@@ -107,72 +99,55 @@ i_refvec<T>::i_refvec(int n) : data_(nullptr), ref_count_(nullptr)
 }
 
 template <class T>
-inline   i_refvec<T>::i_refvec(const i_refvec<T> &V): data_(V.data_),
-  ref_count_(V.ref_count_)
-{
-  if (V.ref_count_ != nullptr)
-      (*(V.ref_count_))++;
+inline i_refvec<T>::i_refvec(const i_refvec<T>& V)
+    : data_(V.data_), ref_count_(V.ref_count_) {
+  if (V.ref_count_ != nullptr) (*(V.ref_count_))++;
 }
 
+template <class T>
+i_refvec<T>::i_refvec(T* data)
+    : data_(data), ref_count_(nullptr) {}
 
 template <class T>
-i_refvec<T>::i_refvec(T* data) : data_(data), ref_count_(nullptr) {}
-
-template <class T>
-inline T* i_refvec<T>::begin()
-{
+inline T* i_refvec<T>::begin() {
   return data_;
 }
 
 template <class T>
-inline const T& i_refvec<T>::operator[](int i) const
-{
+inline const T& i_refvec<T>::operator[](int i) const {
   return data_[i];
 }
 
 template <class T>
-inline T& i_refvec<T>::operator[](int i)
-{
+inline T& i_refvec<T>::operator[](int i) {
   return data_[i];
 }
 
-
 template <class T>
-inline const T* i_refvec<T>::begin() const
-{
+inline const T* i_refvec<T>::begin() const {
   return data_;
 }
 
-
-
 template <class T>
-i_refvec<T> & i_refvec<T>::operator=(const i_refvec<T> &V)
-{
-  if (this == &V)
-    return *this;
+i_refvec<T>& i_refvec<T>::operator=(const i_refvec<T>& V) {
+  if (this == &V) return *this;
 
-
-  if (ref_count_ != nullptr)
-  {
-    (*ref_count_) --;
-    if ((*ref_count_) == 0)
-      destroy();
+  if (ref_count_ != nullptr) {
+    (*ref_count_)--;
+    if ((*ref_count_) == 0) destroy();
   }
 
   data_ = V.data_;
   ref_count_ = V.ref_count_;
 
-  if (V.ref_count_ != nullptr)
-      (*(V.ref_count_))++;
+  if (V.ref_count_ != nullptr) (*(V.ref_count_))++;
 
   return *this;
 }
 
 template <class T>
-void i_refvec<T>::destroy()
-{
-  if (ref_count_ != nullptr)
-  {
+void i_refvec<T>::destroy() {
+  if (ref_count_ != nullptr) {
 #ifdef TNT_DEBUG
     std::cout << "destorying data... \n";
 #endif
@@ -181,8 +156,7 @@ void i_refvec<T>::destroy()
 #ifdef TNT_DEBUG
     std::cout << "deleted ref_count_ ...\n";
 #endif
-    if (data_ != nullptr)
-      delete []data_;
+    if (data_ != nullptr) delete[] data_;
 #ifdef TNT_DEBUG
     std::cout << "deleted data_[] ...\n";
 #endif
@@ -196,9 +170,8 @@ void i_refvec<T>::destroy()
 * if is_null() is false and ref_count() is 0, then
 *
 */
-template<class T>
-int i_refvec<T>::is_null() const
-{
+template <class T>
+int i_refvec<T>::is_null() const {
   return (data_ == nullptr ? 1 : 0);
 }
 
@@ -209,31 +182,24 @@ int i_refvec<T>::is_null() const
 *      this data space.
 */
 template <class T>
-int i_refvec<T>::ref_count() const
-{
+int i_refvec<T>::ref_count() const {
   if (data_ == nullptr)
     return 0;
   else
-    return (ref_count_ != nullptr ? *ref_count_ : -1) ;
+    return (ref_count_ != nullptr ? *ref_count_ : -1);
 }
 
 template <class T>
-i_refvec<T>::~i_refvec()
-{
-  if (ref_count_ != nullptr)
-  {
+i_refvec<T>::~i_refvec() {
+  if (ref_count_ != nullptr) {
     (*ref_count_)--;
 
-    if (*ref_count_ == 0)
-    destroy();
+    if (*ref_count_ == 0) destroy();
   }
 }
 
-
 } /* namespace TNT */
 
-
-
 IMPALGEBRA_END_INTERNAL_NAMESPACE
 
 #endif /* IMPALGEBRA_TNT_I_REFVEC_H */
