@@ -15,7 +15,6 @@
 
 IMPALGEBRA_BEGIN_NAMESPACE
 
-
 /** @name Simple geometric IO
     These functions write geometry to text files, one line per
     geometric primitive. Each line has the form \quote{x y z} for points or
@@ -27,27 +26,25 @@ IMPALGEBRA_BEGIN_NAMESPACE
  */
 //! Write a set of 3D vectors to a file
 /** \see read_pts
-    \relatesalso VectorD
+    See VectorD
 */
-IMPALGEBRAEXPORT void write_pts(const Vector3Ds &vs,
-                                base::TextOutput out);
+IMPALGEBRAEXPORT void write_pts(const Vector3Ds &vs, base::TextOutput out);
 
 //! Read a set of 3D vectors from a file
 /** \see write_pts
-    \relatesalso VectorD
+    See VectorD
 */
 IMPALGEBRAEXPORT Vector3Ds read_pts(base::TextInput input);
 
 //! Write a set of 3d spheres to a file
 /** \see read_pts
-    \relatesalso SphereD
+    See SphereD
 */
-IMPALGEBRAEXPORT void write_spheres(const Sphere3Ds &vs,
-                                    base::TextOutput out);
+IMPALGEBRAEXPORT void write_spheres(const Sphere3Ds &vs, base::TextOutput out);
 
 //! Read a set of 3d spheres from a file
 /** \see write_pts
-    \relatesalso SphereD
+    See SphereD
 */
 IMPALGEBRAEXPORT Sphere3Ds read_spheres(base::TextInput input);
 
@@ -55,4 +52,4 @@ IMPALGEBRAEXPORT Sphere3Ds read_spheres(base::TextInput input);
 
 IMPALGEBRA_END_NAMESPACE
 
-#endif  /* IMPALGEBRA_IO_H */
+#endif /* IMPALGEBRA_IO_H */
