@@ -21,19 +21,17 @@ IMPALGEBRA_BEGIN_NAMESPACE
     the segment is in the first passed object and the 1 point is in
     the second.
 */
-/** \relatesalso Segment3D
-    \relatesalso Vector3D
+/** See Segment3D
+    See Vector3D
 */
-IMPALGEBRAEXPORT
-Segment3D get_shortest_segment(const Segment3D &s,
-                               const Vector3D &p);
+IMPALGEBRAEXPORT Segment3D
+    get_shortest_segment(const Segment3D &s, const Vector3D &p);
 
-/** \relatesalso Segment3D
+/** See Segment3D
  */
-IMPALGEBRAEXPORT
-Segment3D get_shortest_segment(const Segment3D &sa,
-                               const Segment3D &sb);
+IMPALGEBRAEXPORT Segment3D
+    get_shortest_segment(const Segment3D &sa, const Segment3D &sb);
 
 IMPALGEBRA_END_NAMESPACE
 
-#endif  /* IMPALGEBRA_SHORTEST_SEGMENT_H */
+#endif /* IMPALGEBRA_SHORTEST_SEGMENT_H */
