@@ -1,10 +1,9 @@
-import unittest
 import IMP
 import IMP.test
 import IMP.algebra
 import math
 
-class ConeTests(IMP.test.TestCase):
+class Tests(IMP.test.TestCase):
 
     def test_cone_construction(self):
         """Check that cones on Z are constructed correctly"""
@@ -33,4 +32,4 @@ class ConeTests(IMP.test.TestCase):
             self.assertEqual(bs.get_contains(v),True)
 
 if __name__ == '__main__':
-    unittest.main()
+    IMP.test.main()
