@@ -1,4 +1,3 @@
-import unittest
 import IMP.test
 import IMP.algebra
 import math
@@ -11,7 +10,7 @@ def in_box(lb, ub, pt):
             return False
     return True
 
-class Vector3DTests(IMP.test.TestCase):
+class Tests(IMP.test.TestCase):
     def test_magnitude(self):
         """Testing the distribution of vectors on a box"""
         lb= IMP.algebra.Vector3D(10,8, 12)
@@ -29,8 +28,8 @@ class Vector3DTests(IMP.test.TestCase):
             rv= IMP.algebra.get_random_vector_on(IMP.algebra.BoundingBox3D(lb, ub))
             print ".dotat "+str(rv[0])+" "+str(rv[1])+" "+str(rv[2])
             for i in range(0, 3):
-                self.assert_(in_box(olb, oub, rv))
-                self.assert_(not in_box(ilb, iub, rv))
+                self.assertTrue(in_box(olb, oub, rv))
+                self.assertFalse(in_box(ilb, iub, rv))
 
 if __name__ == '__main__':
-    unittest.main()
+    IMP.test.main()
