@@ -21,16 +21,23 @@ IMPATOM_BEGIN_NAMESPACE
 /** This is a version of core::CoverRefined optimized for bonds. It is
     about 4x faster than the general purpose one.
  */
-class IMPATOMEXPORT CoverBond: public SingletonModifier
-{
-public:
+class IMPATOMEXPORT CoverBond : public SingletonModifier {
+ public:
   CoverBond();
 
-  IMP_SINGLETON_MODIFIER(CoverBond);
+  virtual void apply_index(kernel::Model *m, kernel::ParticleIndex p) const
+      IMP_OVERRIDE;
+  virtual kernel::ModelObjectsTemp do_get_inputs(
+      kernel::Model *m, const kernel::ParticleIndexes &pis) const IMP_OVERRIDE;
+  virtual kernel::ModelObjectsTemp do_get_outputs(
+      kernel::Model *m, const kernel::ParticleIndexes &pis) const IMP_OVERRIDE;
+  IMP_SINGLETON_MODIFIER_METHODS(CoverBond);
+  IMP_OBJECT_METHODS(CoverBond);
+  ;
 };
 
-IMP_OBJECTS(CoverBond,CoverBonds);
+IMP_OBJECTS(CoverBond, CoverBonds);
 
 IMPATOM_END_NAMESPACE
 
-#endif  /* IMPATOM_COVER_BOND_H */
+#endif /* IMPATOM_COVER_BOND_H */
