@@ -14,31 +14,29 @@
 #include "atom_macros.h"
 #include "internal/mol2.h"
 
-#include <IMP/Model.h>
-#include <IMP/Particle.h>
-#include <IMP/file.h>
+#include <IMP/kernel/Model.h>
+#include <IMP/kernel/Particle.h>
+#include <IMP/base/file.h>
 
 IMPATOM_BEGIN_NAMESPACE
 
 //! A base class for choosing which Mol2 atoms to read
 /**
  */
-class IMPATOMEXPORT Mol2Selector: public IMP::base::Object {
+class IMPATOMEXPORT Mol2Selector : public IMP::base::Object {
  public:
-  Mol2Selector():Object("Mol2Selector%1%"){}
-  virtual bool get_is_selected(const std::string& atom_line) const=0;
+  Mol2Selector() : Object("Mol2Selector%1%") {}
+  virtual bool get_is_selected(const std::string& atom_line) const = 0;
   virtual ~Mol2Selector();
 };
 
 //! Read all atoms
-class AllMol2Selector: public Mol2Selector {
-public:
-  IMP_MOL2_SELECTOR(AllMol2Selector,
-                    return (true || mol2_line.empty()),
+class AllMol2Selector : public Mol2Selector {
+ public:
+  IMP_MOL2_SELECTOR(AllMol2Selector, return (true || mol2_line.empty()),
                     out << "");
 };
 
-
 //! Defines a selector that will pick only non-hydrogen atoms
 class IMPATOMEXPORT NonHydrogenMol2Selector : public Mol2Selector {
  public:
@@ -56,13 +54,15 @@ class IMPATOMEXPORT NonHydrogenMol2Selector : public Mol2Selector {
     hierarchy writes all the Residue types in the hierarchy to the file.
     @{
 */
+//! Create a hierarchy from a Mol2 file.
 IMPATOMEXPORT Hierarchy read_mol2(base::TextInput mol2_file,
-                                  Model* model,
-                                  Mol2Selector* mol2sel
-                                  = nullptr);
+                                  kernel::Model* model,
+                                  Mol2Selector* mol2sel = nullptr);
 
-IMPATOMEXPORT void write_mol2(Hierarchy rhd,
-                              base::TextOutput file_name);
+//! Write a lignand hierarchy as a mol2 file
+/** For now, this has to be a hierarchy created by read_mol2()
+ */
+IMPATOMEXPORT void write_mol2(Hierarchy rhd, base::TextOutput file_name);
 
 /** @} */
 
