@@ -13,7 +13,7 @@
 #include <IMP/core/XYZ.h>
 #include <IMP/atom/Mass.h>
 
-#include <IMP/log.h>
+#include <IMP/base/log.h>
 
 #include <sstream>
 #include <vector>
@@ -22,15 +22,15 @@
 IMPATOM_BEGIN_NAMESPACE
 
 namespace {
-  base::Vector<Element> added_atom_names;
+base::Vector<Element> added_atom_names;
 }
 
-#define NAME_DEF(NAME, ELEMENT) const AtomType AT_##NAME\
-  = add_atom_type(#NAME, ELEMENT)
-#define NAME_DEF2(NAME, STR, ELEMENT) const AtomType AT_##NAME\
-  = add_atom_type(STR, ELEMENT)
-#define NAME_ALIAS(OLD_NAME, NAME) const AtomType AT_##NAME\
-  (AtomType::add_alias(AT_##OLD_NAME, #NAME))
+#define NAME_DEF(NAME, ELEMENT) \
+  const AtomType AT_##NAME = add_atom_type(#NAME, ELEMENT)
+#define NAME_DEF2(NAME, STR, ELEMENT) \
+  const AtomType AT_##NAME = add_atom_type(STR, ELEMENT)
+#define NAME_ALIAS(OLD_NAME, NAME) \
+  const AtomType AT_##NAME(AtomType::add_alias(AT_##OLD_NAME, #NAME))
 
 NAME_DEF(N, N);
 NAME_DEF(H, H);
@@ -139,13 +139,13 @@ NAME_DEF(HH22, H);
 NAME_DEF(HH23, H);
 NAME_DEF(HH33, H);
 NAME_DEF(HH13, H);
-//NAME_ALIAS(1HH3, HH31);
+// NAME_ALIAS(1HH3, HH31);
 NAME_DEF(P, P);
 NAME_DEF(OP1, O);
 NAME_DEF(OP2, O);
 NAME_DEF(OP3, O);
 NAME_DEF2(O5p, "O5'", O);
-NAME_DEF2(C5p,"C5'", C);
+NAME_DEF2(C5p, "C5'", C);
 NAME_DEF2(H5pp, "H5''", H);
 NAME_DEF2(C4p, "C4'", C);
 NAME_DEF2(H4p, "H4'", H);
@@ -206,47 +206,39 @@ NAME_DEF(NO2, N);
 
 NAME_DEF(UNKNOWN, UNKNOWN_ELEMENT);
 
-Atom Atom::setup_particle(Model *m,
-                          ParticleIndex pi, AtomType t) {
-  Particle *p= m->get_particle(pi);
-  p->add_attribute(get_atom_type_key(), t.get_index());
-  if (!Hierarchy::particle_is_instance(p)) {
-    Hierarchy::setup_particle(p);
+void Atom::do_setup_particle(kernel::Model *m, kernel::ParticleIndex pi,
+                             AtomType t) {
+  m->add_attribute(get_atom_type_key(), pi, t.get_index());
+  if (!Hierarchy::get_is_setup(m, pi)) {
+    Hierarchy::setup_particle(m, pi);
   }
-  p->add_attribute(get_element_key(), UNKNOWN_ELEMENT);
-  //p->add_attribute(get_occupancy_key(), 1.00);
-  //p->add_attribute(get_tempFactor_key(), 0.00);
+  m->add_attribute(get_element_key(), pi, UNKNOWN_ELEMENT);
+  // p->add_attribute(get_occupancy_key(), 1.00);
+  // p->add_attribute(get_tempFactor_key(), 0.00);
 
-  Atom ret(p);
-  if (!Mass::particle_is_instance(p)) {
-    Mass::setup_particle(p, 0);
+  Atom ret(m, pi);
+  if (!Mass::get_is_setup(m, pi)) {
+    Mass::setup_particle(m, pi, 0);
   }
   ret.set_atom_type(t);
-  return ret;
 }
 
-Atom Atom::setup_particle(Particle *p, Atom o) {
-  Atom ret=setup_particle(p, o.get_atom_type());
-  return ret;
+void Atom::do_setup_particle(kernel::Model *m, kernel::ParticleIndex pi,
+                             Atom o) {
+  do_setup_particle(m, pi, o.get_atom_type());
 }
 
-void Atom::show(std::ostream &out) const
-{
-  out << "  element:"<< get_element_table().get_name(get_element());
-  out << " type: "<< get_atom_type();
+void Atom::show(std::ostream &out) const {
   if (get_input_index() != -1) {
-    out << " input index: " << get_input_index();
-  }
-  if (core::XYZ::particle_is_instance(get_particle())) {
-    out << " coords: " << core::XYZ(get_particle());
+    out << "#" << get_input_index() << " ";
   }
+  out << get_atom_type();
+  out << " (" << get_element_table().get_name(get_element()) << ")";
 }
 
-
-void Atom::set_atom_type(AtomType t)
-{
+void Atom::set_atom_type(AtomType t) {
   get_particle()->set_value(get_atom_type_key(), t.get_index());
-  Element e= get_element_for_atom_type(t);
+  Element e = get_element_for_atom_type(t);
   if (e != UNKNOWN_ELEMENT) {
     set_element(e);
   }
@@ -280,26 +272,26 @@ FloatKey Atom::get_temperature_factor_key() {
 Residue get_residue(Atom d, bool nothrow) {
   Hierarchy mhd(d.get_particle());
   do {
-    mhd= mhd.get_parent();
-    if (mhd== Hierarchy()) {
-      if (nothrow) return Residue();
+    mhd = mhd.get_parent();
+    if (mhd == Hierarchy()) {
+      if (nothrow)
+        return Residue();
       else {
-        IMP_THROW("Atom is not the child of a residue "  << d,
-                  ValueException);
+        IMP_THROW("Atom is not the child of a residue " << d, ValueException);
       }
     }
-  } while (!Residue::particle_is_instance(mhd.get_particle()));
+  } while (!Residue::get_is_setup(mhd.get_particle()));
   Residue rd(mhd.get_particle());
   return rd;
 }
 
 Atom get_atom(Residue rd, AtomType at) {
   Hierarchy mhd(rd.get_particle());
-  for (unsigned int i=0; i< mhd.get_number_of_children(); ++i) {
+  for (unsigned int i = 0; i < mhd.get_number_of_children(); ++i) {
     Atom a(mhd.get_child(i));
     if (a.get_atom_type() == at) return a;
   }
-  IMP_LOG_VERBOSE( "Atom not found " << at << std::endl);
+  IMP_LOG_VERBOSE("Atom not found " << at << std::endl);
   return Atom();
 }
 
@@ -308,16 +300,15 @@ void Atom::set_element(Element e) {
   Mass(get_particle()).set_mass(get_element_table().get_mass(e));
 }
 
-
 AtomType add_atom_type(std::string name, Element e) {
   IMP_USAGE_CHECK(!AtomType::get_key_exists(name),
-            "An AtomType with that name already exists: "
-            << name);
+                  "An AtomType with that name already exists: " << name);
   AtomType ret(AtomType::add_key(name));
-  added_atom_names.resize(std::max(added_atom_names.size(),
-                                   static_cast<std::size_t>(ret.get_index()+1)),
-                          UNKNOWN_ELEMENT);
-  added_atom_names[ret.get_index()]=e;
+  added_atom_names.resize(
+      std::max(added_atom_names.size(),
+               static_cast<std::size_t>(ret.get_index() + 1)),
+      UNKNOWN_ELEMENT);
+  added_atom_names[ret.get_index()] = e;
   return ret;
 }
 
