@@ -8,24 +8,21 @@
 
 #include "IMP/atom/Mass.h"
 
-
 IMPATOM_BEGIN_NAMESPACE
 
-
 FloatKey Mass::get_mass_key() {
   static FloatKey k("mass");
   return k;
 }
 
 void Mass::show(std::ostream &out) const {
-  out << "Mass " << get_mass() <<  std::endl;
+  out << "Mass " << get_mass() << std::endl;
 }
 
 namespace {
-bool check_mass(Particle*p) {
-  if (p->get_value(Mass::get_mass_key()) < 0) {
-    IMP_THROW("Mass must be non-negative.",
-              ValueException);
+bool check_mass(kernel::Model *m, kernel::ParticleIndex pi) {
+  if (m->get_attribute(Mass::get_mass_key(), pi) < 0) {
+    IMP_THROW("Mass must be non-negative.", ValueException);
   }
   return true;
 }
