@@ -39,7 +39,7 @@ class Tests(IMP.test.TestCase):
         """Check add/get atom from CHARMM residues"""
         res = IMP.atom.CHARMMIdealResidueTopology(IMP.atom.ResidueType('FOO'))
         self.assertEqual(res.get_type(), 'FOO')
-        self.assertRaises(IMP.ValueException, res.get_atom, 'CA')
+        self.assertRaises(IMP.base.ValueException, res.get_atom, 'CA')
         at = _make_test_atom()
         res.add_atom(at)
         self.assertEqual(res.get_atom('CA').get_charmm_type(), 'CT1')
@@ -57,9 +57,9 @@ class Tests(IMP.test.TestCase):
         res = IMP.atom.CHARMMIdealResidueTopology(IMP.atom.ResidueType('FOO'))
         at = _make_test_atom()
         res.add_atom(at)
-        self.assertRaises(IMP.ValueException, res.remove_atom, 'CB')
+        self.assertRaises(IMP.base.ValueException, res.remove_atom, 'CB')
         res.remove_atom('CA')
-        self.assertRaises(IMP.ValueException, res.get_atom, 'CA')
+        self.assertRaises(IMP.base.ValueException, res.get_atom, 'CA')
 
     def test_default_patches(self):
         """Check default patches of CHARMM residues"""
@@ -130,8 +130,8 @@ class Tests(IMP.test.TestCase):
     def test_forcefield_add_get(self):
         """Test adding/getting patches and residues to/from forcefields"""
         ff = IMP.atom.CHARMMParameters(IMP.atom.get_data_path("top.lib"))
-        self.assertRaises(IMP.ValueException, ff.get_residue_topology, IMP.atom.ResidueType('FOO'))
-        self.assertRaises(IMP.ValueException, ff.get_patch, 'PFOO')
+        self.assertRaises(IMP.base.ValueException, ff.get_residue_topology, IMP.atom.ResidueType('FOO'))
+        self.assertRaises(IMP.base.ValueException, ff.get_patch, 'PFOO')
         patch = IMP.atom.CHARMMPatch('PFOO')
         res = IMP.atom.CHARMMIdealResidueTopology(IMP.atom.ResidueType('FOO'))
         ff.add_patch(patch)
@@ -212,7 +212,7 @@ class Tests(IMP.test.TestCase):
         self.assertEqual(ic.get_first_angle(), 0.)
         self.assertEqual(ic.get_dihedral(), 180.)
         # Repeated patching should not be possible
-        self.assertRaises(IMP.ValueException, patch.apply, res)
+        self.assertRaises(IMP.base.ValueException, patch.apply, res)
 
         # Patches should delete atoms
         patch = ff.get_patch('TP1A')
@@ -220,7 +220,7 @@ class Tests(IMP.test.TestCase):
                             ff.get_residue_topology(IMP.atom.TYR))
         self.assertEqual(res.get_atom('CB').get_charmm_type(), 'CT2')
         patch.apply(res)
-        self.assertRaises(IMP.ValueException, res.get_atom, 'CB')
+        self.assertRaises(IMP.base.ValueException, res.get_atom, 'CB')
 
     def test_double_patching(self):
         """Test application of two-residue patches"""
@@ -240,7 +240,7 @@ class Tests(IMP.test.TestCase):
             self.assertEqual(res2.get_number_of_impropers(), 3)
             # Single-residue patches cannot be applied to two residues
             badpatch = ff.get_patch('CTER')
-            self.assertRaises(IMP.ValueException, badpatch.apply, res1, res2)
+            self.assertRaises(IMP.base.ValueException, badpatch.apply, res1, res2)
             patch.apply(res1, res2)
             # Patch should change atom type of existing atoms
             self.assertEqual(res1.get_atom('SG').get_charmm_type(), 'SM')
@@ -249,8 +249,8 @@ class Tests(IMP.test.TestCase):
             self.assertEqual(res1.get_patched(), True)
             self.assertEqual(res2.get_patched(), True)
             # Patches should delete atoms
-            self.assertRaises(IMP.ValueException, res1.get_atom, 'HG')
-            self.assertRaises(IMP.ValueException, res2.get_atom, 'HG')
+            self.assertRaises(IMP.base.ValueException, res1.get_atom, 'HG')
+            self.assertRaises(IMP.base.ValueException, res2.get_atom, 'HG')
             # Should add/delete bonds/dihedrals
             self.assertEqual(res1.get_number_of_bonds(), 11)
             self.assertEqual(res1.get_number_of_impropers(), 3)
@@ -281,7 +281,7 @@ class Tests(IMP.test.TestCase):
 
     def test_add_coordinates_backbone(self):
         """Test adding coordinates to a backbone- or CA-only structure"""
-        m = IMP.Model()
+        m = IMP.kernel.Model()
         pdb = IMP.atom.read_pdb(self.get_input_file_name('backbone-ca.pdb'), m)
         ff = IMP.atom.CHARMMParameters(IMP.atom.get_data_path("top.lib"),
                                        IMP.atom.get_data_path("par.lib"))
@@ -294,11 +294,11 @@ class Tests(IMP.test.TestCase):
         topology.add_coordinates(pdb)
         # Every atom should now have XYZ coordinates
         for a in IMP.atom.get_by_type(pdb, IMP.atom.ATOM_TYPE):
-            self.assertTrue(IMP.core.XYZ.particle_is_instance(a))
+            self.assertTrue(IMP.core.XYZ.get_is_setup(a))
 
     def test_setup_hierarchy(self):
         """Test CHARMMTopology::setup_hierarchy() method"""
-        m = IMP.Model()
+        m = IMP.kernel.Model()
         pdb = IMP.atom.read_pdb(
                         self.get_input_file_name('charmm_type_test.pdb'), m)
         ff = IMP.atom.get_heavy_atom_CHARMM_parameters()
@@ -309,19 +309,19 @@ class Tests(IMP.test.TestCase):
         atoms = IMP.atom.get_by_type(pdb, IMP.atom.ATOM_TYPE)
         self.assertEqual(len(atoms), 11)
         for a in atoms:
-            self.assertTrue(IMP.core.XYZ.particle_is_instance(a))
-            self.assertTrue(IMP.atom.CHARMMAtom.particle_is_instance(a))
+            self.assertTrue(IMP.core.XYZ.get_is_setup(a))
+            self.assertTrue(IMP.atom.CHARMMAtom.get_is_setup(a))
 
     def test_heme(self):
         """Test CHARMM topology handling of HEME residues"""
-        m = IMP.Model()
+        m = IMP.kernel.Model()
         pdb = IMP.atom.read_pdb(
                         self.get_input_file_name('HEM_model.pdb'), m)
         residue = IMP.atom.get_by_type(pdb, IMP.atom.RESIDUE_TYPE)[0]
         # Add some dummy atoms, to make sure they get removed
-        a = IMP.atom.Atom.setup_particle(IMP.Particle(m), IMP.atom.AT_CA)
+        a = IMP.atom.Atom.setup_particle(IMP.kernel.Particle(m), IMP.atom.AT_CA)
         residue.add_child(a)
-        a = IMP.atom.Atom.setup_particle(IMP.Particle(m), IMP.atom.AT_CB)
+        a = IMP.atom.Atom.setup_particle(IMP.kernel.Particle(m), IMP.atom.AT_CB)
         residue.add_child(a)
         # Remove some needed atoms, to make sure they get added
         residue.remove_child(0)
@@ -348,13 +348,13 @@ class Tests(IMP.test.TestCase):
                                        IMP.atom.get_data_path("par.lib"))
         topology = IMP.atom.CHARMMTopology(ff)
         topology.add_sequence('ACY')
-        m = IMP.Model()
+        m = IMP.kernel.Model()
         topology.apply_default_patches()
         hierarchy = topology.create_hierarchy(m)
         topology.add_coordinates(hierarchy)
         # Every atom should now have XYZ coordinates
         for a in IMP.atom.get_by_type(hierarchy, IMP.atom.ATOM_TYPE):
-            self.assertTrue(IMP.core.XYZ.particle_is_instance(a))
+            self.assertTrue(IMP.core.XYZ.get_is_setup(a))
 
     def test_add_sequence(self):
         """Test CHARMMTopology::add_sequence()"""
@@ -381,7 +381,7 @@ class Tests(IMP.test.TestCase):
 
     def test_make_patched_topology(self):
         """Test construction of topology with manual patching"""
-        m = IMP.Model()
+        m = IMP.kernel.Model()
         pdb = IMP.atom.read_pdb(self.get_input_file_name('mini.pdb'), m)
         ff = IMP.atom.CHARMMParameters(IMP.atom.get_data_path("top.lib"),
                                        IMP.atom.get_data_path("par.lib"))
@@ -409,7 +409,7 @@ class Tests(IMP.test.TestCase):
                                       (['C', 'CA', 'N', 'O'], 1, 0.0),
                                       (['N', 'C', 'CA', 'SG'], 0, None),
                                       (['N', 'CA', 'C', '+N'], 0, None)]:
-            m = IMP.Model()
+            m = IMP.kernel.Model()
             ff = IMP.atom.CHARMMParameters(IMP.atom.get_data_path("top.lib"),
                                            IMP.atom.get_data_path("par.lib"))
             res = ff.get_residue_topology(IMP.atom.ResidueType('ALA'))
@@ -430,7 +430,7 @@ class Tests(IMP.test.TestCase):
 
     def test_dihedral_stiffness(self):
         """Make sure dihedrals can have negative stiffness"""
-        m = IMP.Model()
+        m = IMP.kernel.Model()
         ff = IMP.atom.CHARMMParameters(IMP.atom.get_data_path("top.lib"),
                                        IMP.atom.get_data_path("par.lib"))
         topology = IMP.atom.CHARMMTopology(ff)
@@ -456,14 +456,14 @@ class Tests(IMP.test.TestCase):
 
     def test_make_topology(self):
         """Test construction of topology"""
-        m = IMP.Model()
+        m = IMP.kernel.Model()
         pdb = IMP.atom.read_pdb(self.get_input_file_name('1z5s_C.pdb'), m)
         atoms = IMP.atom.get_by_type(pdb, IMP.atom.ATOM_TYPE)
         residues = IMP.atom.get_by_type(pdb, IMP.atom.RESIDUE_TYPE)
         last_atom = atoms[-1].get_particle()
         # PDB reader will have already set radii but not CHARMM type:
-        self.assertEqual(IMP.core.XYZR.particle_is_instance(last_atom), True)
-        self.assertEqual(IMP.atom.CHARMMAtom.particle_is_instance(last_atom),
+        self.assertEqual(IMP.core.XYZR.get_is_setup(last_atom), True)
+        self.assertEqual(IMP.atom.CHARMMAtom.get_is_setup(last_atom),
                          False)
         ff = IMP.atom.CHARMMParameters(IMP.atom.get_data_path("top.lib"),
                                        IMP.atom.get_data_path("par.lib"))
@@ -472,11 +472,11 @@ class Tests(IMP.test.TestCase):
         self.assertEqual(topology.get_number_of_segments(), 1)
         segment = topology.get_segment(0)
         self.assertEqual(segment.get_number_of_residues(), 156)
-        self.assertRaises(IMP.ValueException, segment.apply_default_patches, ff)
+        self.assertRaises(IMP.base.ValueException, segment.apply_default_patches, ff)
         for typ in (IMP.atom.Charged, IMP.atom.LennardJones):
-            self.assertEqual(typ.particle_is_instance(last_atom), False)
+            self.assertEqual(typ.get_is_setup(last_atom), False)
         topology.add_atom_types(pdb)
-        self.assertEqual(IMP.atom.CHARMMAtom.particle_is_instance(last_atom),
+        self.assertEqual(IMP.atom.CHARMMAtom.get_is_setup(last_atom),
                          True)
         self.assertEqual(IMP.atom.CHARMMAtom(last_atom).get_charmm_type(), 'OC')
         topology.add_charges(pdb)
@@ -523,7 +523,7 @@ class Tests(IMP.test.TestCase):
                                        IMP.atom.get_data_path("par.lib"))
         topology = IMP.atom.CHARMMTopology(ff)
         topology.add_sequence('ACY')
-        m = IMP.Model()
+        m = IMP.kernel.Model()
         hierarchy = topology.create_hierarchy(m)
         chains = IMP.atom.get_by_type(hierarchy, IMP.atom.CHAIN_TYPE)
         residues = IMP.atom.get_by_type(hierarchy, IMP.atom.RESIDUE_TYPE)
@@ -552,7 +552,7 @@ class Tests(IMP.test.TestCase):
             # thus it should contain no atoms
             restop = IMP.atom.CHARMMResidueTopology(IMP.atom.ResidueType(res))
             segment.add_residue(restop)
-        m = IMP.Model()
+        m = IMP.kernel.Model()
         hierarchy = topology.create_hierarchy(m)
         chains = IMP.atom.get_by_type(hierarchy, IMP.atom.CHAIN_TYPE)
         residues = IMP.atom.get_by_type(hierarchy, IMP.atom.RESIDUE_TYPE)
@@ -563,7 +563,7 @@ class Tests(IMP.test.TestCase):
 
     def test_get_remove_untyped_atoms(self):
         """Test get or removal of untyped atoms"""
-        m = IMP.Model()
+        m = IMP.kernel.Model()
         pdb = IMP.atom.read_pdb(
                  self.get_input_file_name('charmm_type_test.pdb'), m)
         ff = IMP.atom.CHARMMParameters(IMP.atom.get_data_path("top.lib"),
@@ -582,7 +582,7 @@ class Tests(IMP.test.TestCase):
 
     def test_add_missing_atoms(self):
         """Test adding missing atoms"""
-        m = IMP.Model()
+        m = IMP.kernel.Model()
         pdb = IMP.atom.read_pdb(
                  self.get_input_file_name('charmm_type_test.pdb'), m)
         ff = IMP.atom.CHARMMParameters(IMP.atom.get_data_path("top.lib"),
