@@ -6,8 +6,8 @@ import IMP.atom
 class Tests(IMP.test.TestCase):
     def test_conversion(self):
         """Test conversion from atom.hierarchy"""
-        m= IMP.Model()
-        p =IMP.Particle(m)
+        m= IMP.kernel.Model()
+        p =IMP.kernel.Particle(m)
         h= IMP.atom.Hierarchy.setup_particle(p)
         c= IMP.core.get_leaves(h)
 
