@@ -14,11 +14,12 @@ kcal2mod = 4.1868e-4
 # Mass of Carbon-12 (g/mol)
 cmass = 12.011
 
-class XTransRestraint(IMP.Restraint):
+class XTransRestraint(IMP.kernel.Restraint):
     """Attempt to move the whole system along the x axis"""
     def __init__(self, m, strength):
-        IMP.Restraint.__init__(self, m)
+        IMP.kernel.Restraint.__init__(self, m, "XTransRestraint %1%")
         self.strength = strength
+        self.set_log_level(IMP.base.SILENT)
 
     def unprotected_evaluate(self, accum):
         e = 0.
@@ -34,18 +35,16 @@ class XTransRestraint(IMP.Restraint):
         return IMP.VersionInfo("Daniel Russel", "0.5")
     def do_show(self, fh):
         fh.write("Test restraint")
-    def get_input_particles(self):
+    def do_get_inputs(self):
         return [x for x in self.get_model().get_particles()]
-    def get_input_containers(self):
-        return []
 
 
 class WriteTrajState(IMP.OptimizerState):
     """Write system coordinates (trajectory) into a Python list"""
-    def __init__(self, traj):
-        IMP.OptimizerState.__init__(self)
+    def __init__(self, m, traj):
+        IMP.OptimizerState.__init__(self, m, "WriteTrajState%1%")
         self.traj = traj
-    def update(self):
+    def do_update(self, call):
         model = self.get_optimizer().get_model()
         self.traj.append([(p.get_value(xkey), p.get_value(ykey),
                            p.get_value(zkey), p.get_value(vxkey)) \
@@ -59,7 +58,7 @@ class Tests(IMP.test.TestCase):
         """Set up particles and optimizer"""
         IMP.test.TestCase.setUp(self)
 
-        self.model = IMP.Model()
+        self.model = IMP.kernel.Model()
         self.particles = []
         self.particles.append(self.create_point_particle(self.model,
                                                          -43.0, 65.0, 93.0))
@@ -73,8 +72,9 @@ class Tests(IMP.test.TestCase):
               "for step %d, coordinate %d[%d]"
         velmsg = "Predicted velocity %.5f doesn't match generated %.5f, " + \
                  "for step %d, particle %d"
-        for (num, step) in enumerate(traj):
+        for (num, step) in enumerate(traj[:-1]):
             newvx = vxfunc(vx)
+            print num
             for n in range(len(coor)):
                 self.assertAlmostEqual(vx, step[n][3], delta=1e-3,
                                        msg=velmsg % (vx, step[n][3],
@@ -92,7 +92,7 @@ class Tests(IMP.test.TestCase):
                  for p in self.model.get_particles()]
         # Add starting (step 0) position to the trajectory, with zero velocity
         traj = [[x+[0] for x in start]]
-        state = WriteTrajState(traj)
+        state = WriteTrajState(self.model, traj)
         self.md.add_optimizer_state(state)
         self.md.set_maximum_time_step(timestep)
         self.md.optimize(50)
@@ -118,7 +118,7 @@ class Tests(IMP.test.TestCase):
         self.md.set_velocity_cap(0.3)
         (start, traj) = self._optimize_model(timestep)
         # Strength is so high that velocity should max out at the cap
-        for i in range(len(traj) - 1):
+        for i in range(49):
             oldx = traj[i][0][0]
             newx = traj[i+1][0][0]
             # Calculate velocity from change in position
@@ -126,7 +126,7 @@ class Tests(IMP.test.TestCase):
 
     def test_non_xyz(self):
         """Should skip particles without xyz attributes"""
-        p = IMP.Particle(self.model)
+        p = IMP.kernel.Particle(self.model)
         p.add_attribute(IMP.FloatKey("attr"), 0.0, True)
         self.md.optimize(100)
 
@@ -178,7 +178,7 @@ class Tests(IMP.test.TestCase):
 
     def test_get_optimizer_states(self):
         """Test get_optimizer_states() method"""
-        wrtraj = WriteTrajState([])
+        wrtraj = WriteTrajState(self.model, [])
         scaler = IMP.atom.VelocityScalingOptimizerState(
                              self.particles, 298.0, 10)
         self.md.add_optimizer_state(wrtraj)
