@@ -8,7 +8,7 @@ class Tests(IMP.test.TestCase):
 
     def test_read(self):
         """Check reading a mol2 file containing small molecules"""
-        m = IMP.Model()
+        m = IMP.kernel.Model()
 
         #! read Mol2
         root_d= IMP.atom.read_mol2(self.get_input_file_name("1d3d-ligands.mol2"),
@@ -28,7 +28,7 @@ class Tests(IMP.test.TestCase):
         return
     def test_write(self):
         """Check that a mol2-created hierarchy can be written to a PDB"""
-        m = IMP.Model()
+        m = IMP.kernel.Model()
 
         #! read Mol2
         root_d= IMP.atom.read_mol2(self.get_input_file_name("1d3d-ligands.mol2"),
@@ -43,7 +43,7 @@ class Tests(IMP.test.TestCase):
         print pdb.getvalue()
         return
 
-        m2 = IMP.Model()
+        m2 = IMP.kernel.Model()
         root_d2 = IMP.atom.read_mol2(self.get_input_file_name("1d3d-ligands.mol2"),
                                        m2, IMP.atom.NonhydrogenMol2Selector())
 
@@ -55,7 +55,7 @@ class Tests(IMP.test.TestCase):
 
     def test_hao(self):
         """Check that written mol2s look right"""
-        m = IMP.Model()
+        m = IMP.kernel.Model()
 
         #! read Mol2
         root_d= IMP.atom.read_mol2(self.get_input_file_name("1d3d-ligands.mol2"),
@@ -69,7 +69,7 @@ class Tests(IMP.test.TestCase):
         open(self.get_tmp_file_name("out1.mol2"), "w").write(out.getvalue())
         self.assertEqual(out.getvalue(), testout)
 
-        m = IMP.Model()
+        m = IMP.kernel.Model()
         root_d = IMP.atom.read_mol2(self.get_input_file_name("1d3d-ligands.mol2"),
                                        m, IMP.atom.NonHydrogenMol2Selector())
         print "test 2"
