@@ -7,5 +7,4 @@
  */
 
 #include <debug/vector>
-int main(void)
-{ return 0; }
+int main(void) { return 0; }
