@@ -12,14 +12,17 @@
 #include "utility_macros.h"
 
 IMPBASE_BEGIN_NAMESPACE
-/** Non-copyable classes cannot be copied, as the name implies. If you need
-    to do delayed initialization, either use an initialize method on them or
-    use a boost::scoped_ptr to allocate them on the heap.
-*/
+/** Non-copyable classes cannot be copied, as the name
+       implies. If you need
+       to do delayed initialization, either use an
+       initialize method on them or
+       use a boost::scoped_ptr to allocate them on the
+       heap.
+   */
 class NonCopyable {
  protected:
-  NonCopyable(){}
+  NonCopyable() {}
 };
 IMPBASE_END_NAMESPACE
 
-#endif  /* IMPBASE_NON_COPYABLE_H */
+#endif /* IMPBASE_NON_COPYABLE_H */
