@@ -20,25 +20,26 @@ IMP_CLANG_PRAGMA(diagnostic ignored "-Wmismatched-tags")
 IMP_CLANG_PRAGMA(diagnostic pop)
 #endif
 
+// evil hack to suppress warning on cluster
+// the expected pragmas don't work
+#ifdef __GNUC__
+#undef __DEPRECATED
+#endif
 // this specializes some hash methods
 #include <boost/graph/adjacency_list.hpp>
-
+#ifdef __GNUC__
+#define __DEPRECATED
+#endif
 
 IMPBASE_BEGIN_NAMESPACE
 template <class T>
 inline std::size_t hash_value(const T &t) {
   return t.__hash__();
 }
-inline std::size_t hash_value(double d) {
-  return boost::hash_value(d);
-}
-inline std::size_t hash_value(int d) {
-  return boost::hash_value(d);
-}
-inline std::size_t hash_value(bool d) {
-  return boost::hash_value(d);
-}
-inline std::size_t hash_value(const std::string& d) {
+inline std::size_t hash_value(double d) { return boost::hash_value(d); }
+inline std::size_t hash_value(int d) { return boost::hash_value(d); }
+inline std::size_t hash_value(bool d) { return boost::hash_value(d); }
+inline std::size_t hash_value(const std::string &d) {
   return boost::hash_value(d);
 }
 
@@ -49,4 +50,4 @@ inline std::size_t hash_value(const std::vector<T> &t) {
 }
 IMPBASE_END_NAMESPACE
 
-#endif  /* IMPBASE_HASH_H */
+#endif /* IMPBASE_HASH_H */
