@@ -15,18 +15,18 @@
 IMPBASE_BEGIN_INTERNAL_NAMESPACE
 template <bool ORDERED, class T>
 bool check_result(const T &t, const T &o) {
-  return o==t;
+  return o == t;
 }
 template <bool ORDERED, class T>
-bool check_result( Vector<T> t,
-                   Vector<T> o) {
+bool check_result(Vector<T> t, Vector<T> o) {
   if (!ORDERED) {
     std::sort(t.begin(), t.end());
     std::sort(o.begin(), o.end());
   }
-  if (o.size() != t.size()) return false;
+  if (o.size() != t.size())
+    return false;
   else {
-    for (unsigned int i=0; i< o.size(); ++i) {
+    for (unsigned int i = 0; i < o.size(); ++i) {
       if (t[i] != o[i]) return false;
     }
     return true;
@@ -35,4 +35,4 @@ bool check_result( Vector<T> t,
 
 IMPBASE_END_INTERNAL_NAMESPACE
 
-#endif  /* IMPBASE_INTERNAL_CACHE_H */
+#endif /* IMPBASE_INTERNAL_CACHE_H */
