@@ -14,24 +14,24 @@
 #include <boost/unordered_set.hpp>
 #include "hash.h"
 
-
 IMPBASE_BEGIN_NAMESPACE
-
-/** This class chooses the best of STL compatible non-ordered
-    set available. This will, in general, be a hash set if it
-    is available or std::set if it is not.
-*/
+/** This class chooses the best of STL compatible
+       non-ordered
+       set available. This will, in general, be a hash set
+       if it
+       is available or std::set if it is not.
+   */
 template <class Key>
-class set:
-  public boost::unordered_set<Key>
-{
+class set : public boost::unordered_set<Key> {
   typedef boost::unordered_set<Key> P;
-public:
-  set(){}
+
+ public:
+  set() {}
   template <class It>
-  set(It b, It e): P(b,e){}
+  set(It b, It e)
+      : P(b, e) {}
 };
 
 IMPBASE_END_NAMESPACE
 
-#endif  /* IMPBASE_SET_H */
+#endif /* IMPBASE_SET_H */
