@@ -8,7 +8,8 @@
 #include "IMP/base/nullptr.h"
 
 namespace IMP {
-#if defined(BOOST_NO_CXX11_NULLPTR) || defined(BOOST_NO_NULLPTR)
+#if (defined(BOOST_NO_CXX11_NULLPTR) || defined(BOOST_NO_NULLPTR)) && \
+    !defined(nullptr)
 const nullptr_t nullptr = nullptr_t();
 #endif
 }
