@@ -16,19 +16,19 @@
 IMPBENCHMARK_BEGIN_NAMESPACE
 
 /** One can use the
-    \external{http://http://gperftools.google.com/,
+    [GPerfTools](http://code.google.com/p/gperftools/)
     the GPerfTools profiler} to profile code. On a mac, you should
     use the Instruments program instead (part of the mac os developer tools).
 */
-class IMPBENCHMARKEXPORT Profiler: public base::RAII {
+class IMPBENCHMARKEXPORT Profiler : public base::RAII {
   void start(std::string name);
   void stop();
- public:
-  IMP_RAII(Profiler, (std::string name),,start(name), stop(),
-           out << "profiling");
 
+ public:
+  IMP_RAII(Profiler, (std::string name), , start(name), stop(),
+           out << "profiling");
 };
 
 IMPBENCHMARK_END_NAMESPACE
 
-#endif  /* IMPBENCHMARK_PROFILER_H */
+#endif /* IMPBENCHMARK_PROFILER_H */
