@@ -17,9 +17,9 @@ class Tests(IMP.test.TestCase):
 
     def test_allp(self):
         """Check AllPairContainer"""
-        m= IMP.Model()
+        m= IMP.kernel.Model()
         for i in range(0,50):
-            p= IMP.Particle(m)
+            p= IMP.kernel.Particle(m)
         lp= IMP.container.ListSingletonContainer(m.get_particles())
         apc= IMP.container.AllPairContainer(lp)
         #self.assertEqual(lp.get_ref_count(), 2)
