@@ -8,8 +8,8 @@ class Tests(IMP.test.TestCase):
     """Tests for tunnel scores"""
     def test_connectivity_zero_set(self):
         """Test consecutive pair container decomposition"""
-        m= IMP.Model()
-        ps=[IMP.Particle(m) for i in range(0,15)]
+        m= IMP.kernel.Model()
+        ps=[IMP.kernel.Particle(m) for i in range(0,15)]
         ds=[IMP.core.XYZR.setup_particle(p) for p in ps]
         bb= IMP.algebra.BoundingBox3D(IMP.algebra.Vector3D(0,0,0),
                                       IMP.algebra.Vector3D(10,10,10))
@@ -34,8 +34,8 @@ class Tests(IMP.test.TestCase):
 
     def test_pair_filter(self):
         """Test consecutive pair filter"""
-        m= IMP.Model()
-        ps=[IMP.Particle(m) for i in range(0,15)]
+        m= IMP.kernel.Model()
+        ps=[IMP.kernel.Particle(m) for i in range(0,15)]
         ecpc= IMP.container.ExclusiveConsecutivePairContainer(ps)
         ef= IMP.container.ExclusiveConsecutivePairFilter();
         for i in range(1,len(ps)):
