@@ -9,9 +9,9 @@ class Tests(IMP.test.TestCase):
 
     def test_allp(self):
         """Checking decomposition of plural restraints"""
-        m= IMP.Model()
+        m= IMP.kernel.Model()
         for i in range(0,10):
-            p= IMP.Particle(m)
+            p= IMP.kernel.Particle(m)
             IMP.core.XYZR.setup_particle(p)
         lp= IMP.container.ListSingletonContainer(m.get_particles())
         apc= IMP.container.AllPairContainer(lp)
@@ -20,8 +20,11 @@ class Tests(IMP.test.TestCase):
         r.set_model(m)
         dr= r.create_decomposition()
         print dr.evaluate(False)
-        cdr= IMP.RestraintSet.get_from(dr).get_restraints()
+        cdr= IMP.kernel.RestraintSet.get_from(dr).get_restraints()
+        #IMP.base.set_log_level(IMP.base.VERBOSE)
+        print "deling"
         del dr
+        print "eval single"
         for rc in cdr:
             print rc.evaluate(False)
 if __name__ == '__main__':
