@@ -12,22 +12,28 @@
 #include <IMP/generic.h>
 #include <IMP/TripletScore.h>
 #include <IMP/UnaryFunction.h>
-#include <IMP/Pointer.h>
+#include <IMP/base/Pointer.h>
 #include <IMP/triplet_macros.h>
 
 IMPCORE_BEGIN_NAMESPACE
 
 //! Apply a function to the angle between three particles.
 /** */
-class IMPCOREEXPORT AngleTripletScore : public TripletScore
-{
-  IMP::OwnerPointer<UnaryFunction> f_;
-public:
+class IMPCOREEXPORT AngleTripletScore : public TripletScore {
+  IMP::base::PointerMember<UnaryFunction> f_;
+
+ public:
   //! Score the angle (in radians) using f
   AngleTripletScore(UnaryFunction *f);
-  IMP_SIMPLE_TRIPLET_SCORE(AngleTripletScore);
+  virtual double evaluate_index(kernel::Model *m,
+                                const kernel::ParticleIndexTriplet &pi,
+                                DerivativeAccumulator *da) const IMP_OVERRIDE;
+  virtual kernel::ModelObjectsTemp do_get_inputs(
+      kernel::Model *m, const kernel::ParticleIndexes &pis) const IMP_OVERRIDE;
+  IMP_TRIPLET_SCORE_METHODS(AngleTripletScore);
+  IMP_OBJECT_METHODS(AngleTripletScore);
 };
 
 IMPCORE_END_NAMESPACE
 
-#endif  /* IMPCORE_ANGLE_TRIPLET_SCORE_H */
+#endif /* IMPCORE_ANGLE_TRIPLET_SCORE_H */
