@@ -20,17 +20,17 @@ IMPCORE_BEGIN_NAMESPACE
     input value. This is most commonly used for dihedral angle restraints,
     e.g. in the CHARMM force field.
  */
-class IMPCOREEXPORT Cosine : public UnaryFunction
-{
-public:
+class IMPCOREEXPORT Cosine : public UnaryFunction {
+ public:
   //! Constructor.
   /** \param[in] force_constant Force constant (score units)
       \param[in] periodicity Periodicity (generally 1-6)
       \param[in] phase Phase (radians)
    */
-  Cosine(Float force_constant, int periodicity, Float phase) :
-      force_constant_(force_constant), periodicity_(periodicity),
-      phase_(phase) {}
+  Cosine(Float force_constant, int periodicity, Float phase)
+      : force_constant_(force_constant),
+        periodicity_(periodicity),
+        phase_(phase) {}
 
   virtual DerivativePair evaluate_with_derivative(double feature) const;
 
@@ -48,4 +48,4 @@ public:
 
 IMPCORE_END_NAMESPACE
 
-#endif  /* IMPCORE_COSINE_H */
+#endif /* IMPCORE_COSINE_H */
