@@ -12,12 +12,11 @@
 
 #include "XYZR.h"
 #include <IMP/Refiner.h>
-#include <IMP/Pointer.h>
+#include <IMP/base/Pointer.h>
 #include <IMP/Decorator.h>
 #include <IMP/SingletonModifier.h>
 #include <IMP/SingletonDerivativeModifier.h>
 
-
 IMPCORE_BEGIN_NAMESPACE
 
 // for swig
@@ -35,27 +34,31 @@ class XYZR;
  listed by the particle refiner.
  An example showing a how to use such a score state to maintain a cover
  of the atoms of a protein by a sphere per residue.
- \htmlinclude cover_particles.py
+ \include cover_particles.py
 
  \note The particle passed must be an XYZR.
  \uses{class CoverRefined, CGAL}
  */
-class IMPCOREEXPORT CoverRefined: public SingletonModifier
-{
-  IMP::OwnerPointer<Refiner> refiner_;
+class IMPCOREEXPORT CoverRefined : public SingletonModifier {
+  IMP::base::PointerMember<Refiner> refiner_;
   Float slack_;
-public:
+
+ public:
   //! Create with the given refiner and radius key
   /** Slack is the amount added to the radius.*/
-  CoverRefined(Refiner *ref,
-               Float slack=0);
+  CoverRefined(Refiner *ref, Float slack = 0);
 
   //! Set how nmuch extra to add to the radius.
-  void set_slack(Float slack) {
-    slack_=slack;
-  }
+  void set_slack(Float slack) { slack_ = slack; }
 
-  IMP_INDEX_SINGLETON_MODIFIER(CoverRefined);
+  virtual void apply_index(kernel::Model *m, kernel::ParticleIndex a) const
+      IMP_OVERRIDE;
+  virtual kernel::ModelObjectsTemp do_get_inputs(
+      kernel::Model *m, const kernel::ParticleIndexes &pis) const IMP_OVERRIDE;
+  virtual kernel::ModelObjectsTemp do_get_outputs(
+      kernel::Model *m, const kernel::ParticleIndexes &pis) const IMP_OVERRIDE;
+  IMP_SINGLETON_MODIFIER_METHODS(CoverRefined);
+  IMP_OBJECT_METHODS(CoverRefined);
 };
 
 //! A particle which covers a set of other particles.
@@ -70,4 +73,4 @@ IMP_SUMMARY_DECORATOR_DECL(Cover, XYZR, XYZs);
 
 IMPCORE_END_NAMESPACE
 
-#endif  /* IMPCORE_COVER_REFINED_H */
+#endif /* IMPCORE_COVER_REFINED_H */
