@@ -17,21 +17,22 @@ IMPCORE_BEGIN_NAMESPACE
     \see HarmonicUpperBound
     \see TruncatedHarmonicLowerBound
 */
-class HarmonicLowerBound : public Harmonic
-{
-public:
+class HarmonicLowerBound : public Harmonic {
+ public:
   /** Create with the given mean and the spring constant k */
   HarmonicLowerBound(Float mean, Float k) : Harmonic(mean, k) {}
-  IMP_UNARY_FUNCTION_INLINE(HarmonicLowerBound,
-                            feature >= Harmonic::get_mean() ?
-                            0.0: Harmonic::evaluate(feature),
-                            feature >= Harmonic::get_mean() ?
-                            0.0:
-                            Harmonic::evaluate_with_derivative(feature).second,
-                            "HarmonicLB: " << Harmonic::get_mean()
-                            << " and " << Harmonic::get_k() << std::endl);
+  virtual double evaluate(double feature) const IMP_OVERRIDE {
+    return feature >= Harmonic::get_mean() ? 0.0 : Harmonic::evaluate(feature);
+  }
+  virtual DerivativePair evaluate_with_derivative(double feature) const
+      IMP_OVERRIDE {
+    return feature >= Harmonic::get_mean()
+               ? DerivativePair(0.0, 0.0)
+               : Harmonic::evaluate_with_derivative(feature);
+  }
+  IMP_OBJECT_METHODS(HarmonicLowerBound);
 };
 
 IMPCORE_END_NAMESPACE
 
-#endif  /* IMPCORE_HARMONIC_LOWER_BOUND_H */
+#endif /* IMPCORE_HARMONIC_LOWER_BOUND_H */
