@@ -10,7 +10,6 @@
 #define IMPCORE_INCREMENTAL_SCORING_FUNCTION_H
 
 #include <IMP/core/core_config.h>
-#include "internal/SingleParticleScoringFunction.h"
 #include <IMP/base/Pointer.h>
 #include <IMP/base_types.h>
 #include "RestraintsScoringFunction.h"
@@ -21,7 +20,7 @@ IMPCORE_BEGIN_NAMESPACE
 
 #if !defined(IMP_DOXYGEN) && !defined(SWIG)
 namespace internal {
-  class NBLScoring;
+class NBLScoring;
 }
 #endif
 
@@ -36,28 +35,42 @@ namespace internal {
     The ensure proper evaluation, the ScoringFunction is divided into a number
     of sub scoring functions, one per possibly moved particles. Each of
 */
-class IMPCOREEXPORT IncrementalScoringFunction: public ScoringFunction {
-  typedef base::map<ParticleIndex,
-      base::
-      OwnerPointer<internal::SingleParticleScoringFunction> >
-      ScoringFunctionsMap;
+class IMPCOREEXPORT IncrementalScoringFunction : public ScoringFunction {
+  struct Data {
+    base::PointerMember<IMP::internal::RestraintsScoringFunction> sf;
+    Ints indexes;
+  };
+  /* have to make sure that when the dependencies are reset on destruction,
+     the map is in a well defined state (and not in the middle of its
+     destructor.
+     Otherwise, ~IncrementalScoringFunction -> map destructor
+     -> kernel::Model::set_has_dependencies()
+     -> IncrementalScoringFunction::do_set_has_dependencies()
+     -> map destructor -> boom
+  */
+  struct ScoringFunctionsMap : public base::map<kernel::ParticleIndex, Data> {
+    ~ScoringFunctionsMap();
+  };
   ScoringFunctionsMap scoring_functions_;
-  ParticleIndexes all_;
-  ParticleIndexes last_move_;
-  ParticleIndexes dirty_;
-  Restraints flattened_restraints_;
+  kernel::ParticleIndexes all_;
+  kernel::ParticleIndexes last_move_;
+  kernel::ParticleIndexes dirty_;
+  kernel::Restraints flattened_restraints_;
   Floats flattened_restraints_scores_;
   double weight_, max_;
-  base::OwnerPointer<ScoringFunction> non_incremental_;
+  base::PointerMember<ScoringFunction> non_incremental_;
   // move the destructor out of the header
-  struct Wrapper: public
-    base::Vector<internal::NBLScoring*> {
+  struct Wrapper : public base::Vector<internal::NBLScoring *> {
     ~Wrapper();
   };
   Wrapper nbl_;
-  void create_flattened_restraints(const RestraintsTemp &rs);
+  void create_flattened_restraints(const kernel::RestraintsTemp &rs);
   void create_scoring_functions();
   void do_non_incremental_evaluate();
+  Data create_data(kernel::ParticleIndex pi,
+                   const base::map<kernel::Restraint *, int> &all,
+                   const kernel::Restraints &dummies) const;
+
  public:
   /** Pass the particles that will be individuall mode, and the list of
       restraints to evaluate on them.
@@ -70,34 +83,41 @@ class IMPCOREEXPORT IncrementalScoringFunction: public ScoringFunction {
                  can be ignored for most purposes
       @param name The name template to use for the scoring function.
 */
-  IncrementalScoringFunction(const ParticlesTemp &to_move,
-                             const RestraintsTemp &rs,
-                             double weight=1.0, double max= NO_MAX,
-                             std::string name="IncrementalScoringFunction%1%");
+  IncrementalScoringFunction(const kernel::ParticlesTemp &to_move,
+                             const kernel::RestraintsTemp &rs,
+                             double weight = 1.0, double max = NO_MAX,
+                             std::string name =
+                                 "IncrementalScoringFunction%1%");
   /** Undo the last moved particles. This is similar in effect to, but perhaps
       more efficient than, calling set_moved_particles() a second time with
       the same list.
   */
   void reset_moved_particles();
   /** Set which particles have moved since the last evaluate. */
-  void set_moved_particles(const ParticleIndexes &p);
+  void set_moved_particles(const kernel::ParticleIndexes &p);
   /** Close pairs scores can be handled separately for efficiency, to do that,
       add a pair score here to act on the list of particles.*/
   void add_close_pair_score(PairScore *ps, double distance,
-                            const ParticlesTemp &particles,
+                            const kernel::ParticlesTemp &particles,
                             const PairPredicates &filters);
   void add_close_pair_score(PairScore *ps, double distance,
-                            const ParticlesTemp &particles);
+                            const kernel::ParticlesTemp &particles);
   void clear_close_pair_scores();
-  ParticleIndexes get_movable_particles() const;
+  /** \deprecated_at{2.1} Use get_movable_indexes() instead. */
+  IMPCORE_DEPRECATED_FUNCTION_DECL(2.1)
+  kernel::ParticleIndexes get_movable_particles() const {
+    IMPCORE_DEPRECATED_FUNCTION_DEF(2.1, "Use get_movable_indexes()");
+    return get_movable_indexes();
+  }
+  kernel::ParticleIndexes get_movable_indexes() const;
   void do_add_score_and_derivatives(IMP::ScoreAccumulator sa,
                                     const ScoreStatesTemp &ss) IMP_OVERRIDE;
-  Restraints create_restraints() const IMP_OVERRIDE;
-  ScoreStatesTemp get_required_score_states() const IMP_OVERRIDE;
+  virtual kernel::Restraints create_restraints() const IMP_OVERRIDE;
+  virtual kernel::ModelObjectsTemp do_get_inputs() const IMP_OVERRIDE;
+  virtual void handle_set_has_required_score_states(bool) IMP_OVERRIDE;
   IMP_OBJECT_METHODS(IncrementalScoringFunction);
 };
 
-
 IMPCORE_END_NAMESPACE
 
-#endif  /* IMPCORE_INCREMENTAL_SCORING_FUNCTION_H */
+#endif /* IMPCORE_INCREMENTAL_SCORING_FUNCTION_H */
