@@ -9,13 +9,10 @@
 #include "IMP/core/RigidBodyDistancePairScore.h"
 #include "IMP/core/internal/rigid_body_tree.h"
 
-
 IMPCORE_BEGIN_NAMESPACE
 
 RigidBodyDistancePairScore::RigidBodyDistancePairScore(PairScore *ps,
-                                                       Refiner *r):
-  KClosePairsPairScore(ps, r, 1) {
-}
-
+                                                       Refiner *r)
+    : KClosePairsPairScore(ps, r, 1) {}
 
 IMPCORE_END_NAMESPACE
