@@ -24,7 +24,7 @@ class Tests(IMP.test.TestCase):
         print 'Distance is ' + str(dist)
         #cpf.set_radius_key(rk)
         cpf.set_distance(dist)
-        m=IMP.Model()
+        m=IMP.kernel.Model()
         ps= self.create_particles_in_box(m, num)
         for i in range(0, len(ps)):
             IMP.core.XYZR.setup_particle(ps[i], random.uniform(rmin, rmax))
@@ -41,7 +41,7 @@ class Tests(IMP.test.TestCase):
         print 'Distance is ' + str(dist)
         #cpf.set_radius_key(rk)
         cpf.set_distance(dist)
-        m=IMP.Model()
+        m=IMP.kernel.Model()
         ps= self.create_particles_in_box(m, num)
         for i in range(0, len(ps)):
             IMP.core.XYZR.setup_particle(ps[i], random.uniform(rmin, rmax))
@@ -138,7 +138,7 @@ class Tests(IMP.test.TestCase):
         #cpf.set_distance(dist)
         print 'Distance is ' + str(dist)
         #cpf.set_radius_key(rk)
-        m=IMP.Model()
+        m=IMP.kernel.Model()
         ps= IMP.core.create_xyzr_particles(m, nump, 1)
         rbpsa= []
         rbpsb= []
@@ -154,8 +154,8 @@ class Tests(IMP.test.TestCase):
             else:
                 fps.append(ps[i])
                 free_ps.append(ps[i])
-        rba= IMP.core.RigidBody.setup_particle(IMP.Particle(m), rbpsa)
-        rbb= IMP.core.RigidBody.setup_particle(IMP.Particle(m), rbpsb)
+        rba= IMP.core.RigidBody.setup_particle(IMP.kernel.Particle(m), rbpsa)
+        rbb= IMP.core.RigidBody.setup_particle(IMP.kernel.Particle(m), rbpsb)
         rba.get_particle().set_name("rba")
         rbb.get_particle().set_name("rbb")
         print "before", [IMP.core.XYZR(p) for p in rbpsa]
@@ -185,8 +185,8 @@ class Tests(IMP.test.TestCase):
                 rbpsb2.append(ps2[i])
             else:
                 fps2.append(ps2[i])
-        rba2= IMP.core.RigidBody.setup_particle(IMP.Particle(m), IMP.core.XYZs(rbpsa2))
-        rbb2= IMP.core.RigidBody.setup_particle(IMP.Particle(m), IMP.core.XYZs(rbpsb2))
+        rba2= IMP.core.RigidBody.setup_particle(IMP.kernel.Particle(m), IMP.core.XYZs(rbpsa2))
+        rbb2= IMP.core.RigidBody.setup_particle(IMP.kernel.Particle(m), IMP.core.XYZs(rbpsb2))
         fps.append(rba2.get_particle())
         fps.append(rbb2.get_particle())
         rba2.get_particle().set_name("rba2")
