@@ -5,12 +5,12 @@ import IMP.core
 class Tests(IMP.test.TestCase):
     def test_hierarchy(self):
         """Check that the hierarchy works fine"""
-        m = IMP.Model()
-        pp=IMP.Particle(m)
+        m = IMP.kernel.Model()
+        pp=IMP.kernel.Particle(m)
         ppd= IMP.core.Hierarchy.setup_particle(pp)
         pp.set_name("root")
         for i in range(0,10):
-            pc=IMP.Particle(m)
+            pc=IMP.kernel.Particle(m)
             pcd= IMP.core.Hierarchy.setup_particle(pc)
             ppd.add_child(pcd)
             pc.set_name(str("child "+str(i)))
@@ -20,12 +20,12 @@ class Tests(IMP.test.TestCase):
     def test_alt_hierarchy(self):
         """Check that an alternate hierarchy works fine"""
         t= IMP.core.HierarchyTraits("my_hierarchy")
-        m = IMP.Model()
-        pp=IMP.Particle(m)
+        m = IMP.kernel.Model()
+        pp=IMP.kernel.Particle(m)
         ppd= IMP.core.Hierarchy.setup_particle(pp, t)
         pp.set_name("root")
         for i in range(0,10):
-            pc=IMP.Particle(m)
+            pc=IMP.kernel.Particle(m)
             pcd= IMP.core.Hierarchy.setup_particle(pc, t)
             ppd.add_child(pcd)
             pc.set_name(str("child "+str(i)))
