@@ -11,12 +11,12 @@ class Tests(IMP.test.TestCase):
     def test_rops(self):
         """Checking refine pairs pair score"""
         IMP.base.set_log_level(IMP.base.VERBOSE)
-        m= IMP.Model()
-        pp= IMP.Particle(m)
+        m= IMP.kernel.Model()
+        pp= IMP.kernel.Particle(m)
         hpp= IMP.core.Hierarchy.setup_particle(pp)
         c=[]
         for i in range(0,10):
-            p= IMP.Particle(m)
+            p= IMP.kernel.Particle(m)
             hp= IMP.core.Hierarchy.setup_particle(p)
             hpp.add_child(hp)
             c.append(p)
