@@ -5,8 +5,8 @@ import IMP.core
 class Tests(IMP.test.TestCase):
     """Test RestraintSets"""
     def _make_stuff(self):
-        m= IMP.Model()
-        rs= IMP.RestraintSet(.5)
+        m= IMP.kernel.Model()
+        rs= IMP.kernel.RestraintSet(.5)
         r0= IMP.kernel._ConstRestraint(1)
         rs.add_restraint(r0)
         m.add_restraint(rs)
@@ -29,8 +29,8 @@ class Tests(IMP.test.TestCase):
         self.assertEqual(m.get_root_restraint_set().get_restraint(0).evaluate(False), 2)
     def test_weights(self):
         """Test that restraints decompose ok"""
-        m= IMP.Model()
-        p= IMP.Particle(m)
+        m= IMP.kernel.Model()
+        p= IMP.kernel.Particle(m)
         r= IMP.kernel._ConstRestraint(1, [p])
         m.add_restraint(r)
         rd= r.create_decomposition()
