@@ -15,24 +15,23 @@
 #include <IMP/SingletonContainer.h>
 #include <IMP/display/Writer.h>
 
+IMPDISPLAY_DEPRECATED_HEADER(2.1, "Use IMP.rmf")
+
 IMPDISPLAY_BEGIN_NAMESPACE
 
-#if IMP_HAS_DEPRECATED
 //! Write a Bild file with the geometry
 /** The bild file format is a simple format for displaying geometry in Chimera.
     The bild writer supports points, spheres, cyliners, and segments.
 
-    \deprecated Use IMP::rmf when interfacing with Chimera.
+    \deprecated_at{2.1} Use IMP::rmf when interfacing with Chimera.
  */
-class IMPDISPLAYEXPORT BildWriter: public TextWriter
-{
+class IMPDISPLAYEXPORT BildWriter : public TextWriter {
   void handle(Color color) {
     get_stream() << ".color " << SpacesIO(color) << "\n";
   }
   bool handle_point(PointGeometry *g, Color color, std::string) {
     handle(color);
-    get_stream() << ".dotat " <<  algebra::spaces_io(g->get_geometry())
-                 << "\n";
+    get_stream() << ".dotat " << algebra::spaces_io(g->get_geometry()) << "\n";
     return true;
   }
   bool handle_segment(SegmentGeometry *g, Color color, std::string) {
@@ -40,14 +39,13 @@ class IMPDISPLAYEXPORT BildWriter: public TextWriter
     get_stream() << ".move "
                  << algebra::spaces_io(g->get_geometry().get_point(0)) << "\n";
     get_stream() << ".draw "
-                 << algebra::spaces_io(g->get_geometry().get_point(1))
-                 << "\n";
+                 << algebra::spaces_io(g->get_geometry().get_point(1)) << "\n";
     return true;
   }
   bool handle_polygon(PolygonGeometry *g, Color color, std::string) {
     handle(color);
     get_stream() << ".polygon ";
-    for (unsigned int i=0; i< g->get_geometry().size(); ++i) {
+    for (unsigned int i = 0; i < g->get_geometry().size(); ++i) {
       get_stream() << " " << algebra::spaces_io(g->get_geometry().at(i));
     }
     get_stream() << "\n";
@@ -56,7 +54,7 @@ class IMPDISPLAYEXPORT BildWriter: public TextWriter
   bool handle_triangle(TriangleGeometry *g, Color color, std::string) {
     handle(color);
     get_stream() << ".polygon ";
-    for (unsigned int i=0; i< 3; ++i) {
+    for (unsigned int i = 0; i < 3; ++i) {
       get_stream() << " " << algebra::spaces_io(g->get_geometry().get_point(i));
     }
     get_stream() << "\n";
@@ -72,21 +70,19 @@ class IMPDISPLAYEXPORT BildWriter: public TextWriter
   bool handle_cylinder(CylinderGeometry *g, Color color, std::string) {
     handle(color);
     get_stream() << ".cylinder "
-                 << algebra::spaces_io(g->get_geometry()
-                                       .get_segment().get_point(0))
-                 << " "
-                 << algebra::spaces_io(g->get_geometry()
-                                       .get_segment().get_point(1)) << " "
+                 << algebra::spaces_io(
+                        g->get_geometry().get_segment().get_point(0)) << " "
+                 << algebra::spaces_io(
+                        g->get_geometry().get_segment().get_point(1)) << " "
                  << g->get_geometry().get_radius() << "\n";
     return true;
   }
-public:
 
+ public:
+  IMPDISPLAY_DEPRECATED_OBJECT_DECL(2.1)
   IMP_TEXT_WRITER(BildWriter);
 };
-#endif
-
 
 IMPDISPLAY_END_NAMESPACE
 
-#endif  /* IMPDISPLAY_BILD_WRITER_H */
+#endif /* IMPDISPLAY_BILD_WRITER_H */
