@@ -24,34 +24,31 @@ IMPDISPLAY_BEGIN_NAMESPACE
     Note, make sure the model is up to date before calling this, for reasons of
     efficiency, it does not update the model.
 */
-class IMPDISPLAYEXPORT RestraintGeometry: public Geometry {
-  IMP::base::OwnerPointer<Restraint> r_;
+class IMPDISPLAYEXPORT RestraintGeometry : public Geometry {
+  IMP::base::PointerMember<kernel::Restraint> r_;
   IMP::base::Pointer<Model> m_;
   //! Use this if the restraint is not part of the model
-  RestraintGeometry(Restraint *p, Model *m);
-public:
-  RestraintGeometry(Restraint *p);
-  Restraint *get_restraint() const {
-    return r_;
-  }
-  IMP_GEOMETRY(RestraintGeometry);
-};
+  RestraintGeometry(kernel::Restraint *p, kernel::Model *m);
 
+ public:
+  RestraintGeometry(kernel::Restraint *p);
+  kernel::Restraint *get_restraint() const { return r_; }
+  virtual IMP::display::Geometries get_components() const IMP_OVERRIDE;
+  IMP_OBJECT_METHODS(RestraintGeometry);
+};
 
 //! Geometry for a whole set of restraints
-class IMPDISPLAYEXPORT RestraintSetGeometry: public Geometry {
-  IMP::Pointer<RestraintSet> r_;
-public:
-  RestraintSetGeometry(RestraintSet *p);
-  RestraintSet *get_restraint_set() const {
-    return r_;
-  }
-  IMP_GEOMETRY(RestraintSetGeometry);
+class IMPDISPLAYEXPORT RestraintSetGeometry : public Geometry {
+  IMP::base::Pointer<kernel::RestraintSet> r_;
+
+ public:
+  RestraintSetGeometry(kernel::RestraintSet *p);
+  kernel::RestraintSet *get_restraint_set() const { return r_; }
+  virtual IMP::display::Geometries get_components() const IMP_OVERRIDE;
+  IMP_OBJECT_METHODS(RestraintSetGeometry);
 };
 
-
-
 /** @} */
 IMPDISPLAY_END_NAMESPACE
 
-#endif  /* IMPDISPLAY_RESTRAINT_GEOMETRY_H */
+#endif /* IMPDISPLAY_RESTRAINT_GEOMETRY_H */
