@@ -10,7 +10,7 @@ class Tests(IMP.test.TestCase):
         """Testing skin surface"""
         if not IMP.display.IMP_DISPLAY_HAS_IMP_CGAL:
             self.skipTest("IMP.cgal is disabled")
-        m= IMP.Model()
+        m= IMP.kernel.Model()
         print "reading"
         h= IMP.atom.read_pdb(self.get_input_file_name("1d3d-protein.pdb"), m)
         hs = IMP.atom.create_simplified_along_backbone(IMP.atom.Chain(IMP.atom.get_by_type(h, IMP.atom.CHAIN_TYPE)[0]), 10)
