@@ -15,7 +15,7 @@
 #include <IMP/core/Transform.h>
 #include <IMP/core/SteepestDescent.h>
 #include <IMP/atom/pdb.h>
-#include <IMP/random.h>
+#include <IMP/base/random.h>
 #include <IMP/algebra/geometric_alignment.h>
 #include <IMP/em/converters.h>
 #include <IMP/algebra/eigen_analysis.h>
@@ -36,14 +36,15 @@ void FittingSolutions::sort(bool reverse) {
 }
 
 namespace {
-RestraintSet * add_restraints(Model *model, DensityMap *dmap,
-                              Particle *p,Refiner *leaves_ref,
+kernel::RestraintSet * add_restraints(kernel::Model *model, DensityMap *dmap,
+                              kernel::Particle *p,kernel::Refiner *leaves_ref,
                 const FloatKey &wei_key,
                 bool fast=false) {
-  RestraintSet *rsrs = new RestraintSet();
+  kernel::RestraintSet *rsrs = new kernel::RestraintSet(model, 1.0,
+                                        "rigid fitting restraints %1%");
    model->add_restraint(rsrs);
    //add fitting restraint
-   Pointer<FitRestraint> fit_rs;
+   base::Pointer<FitRestraint> fit_rs;
    FloatPair no_norm_factors(0.,0.);
    if (fast) {
      fit_rs = new FitRestraint(leaves_ref->get_refined(p),
@@ -59,8 +60,8 @@ RestraintSet * add_restraints(Model *model, DensityMap *dmap,
    return rsrs;
 }
 
-core::MonteCarlo* set_optimizer(Model *model, OptimizerStates display_log,
-                                Particle *p,Refiner *refiner,
+core::MonteCarlo* set_optimizer(kernel::Model *model, OptimizerStates display_log,
+                                kernel::Particle *p,Refiner *refiner,
    Int number_of_cg_steps, Float max_translation, Float max_rotation) {
   core::RigidBody rb =
     core::RigidMember(refiner->get_refined(p)[0]).get_rigid_body();
@@ -70,7 +71,7 @@ core::MonteCarlo* set_optimizer(Model *model, OptimizerStates display_log,
   //preform mc search
   //  core::SteepestDescent *lopt = new core::SteepestDescent();
   IMP_NEW(core::ConjugateGradients, lopt, (model));
-  Pointer<core::MonteCarloWithLocalOptimization>
+  base::Pointer<core::MonteCarloWithLocalOptimization>
     opt(new core::MonteCarloWithLocalOptimization(lopt, number_of_cg_steps));
   opt->add_mover(rb_mover);
   opt->set_return_best(true);//return the lowest energy state visited
@@ -90,8 +91,8 @@ core::MonteCarlo* set_optimizer(Model *model, OptimizerStates display_log,
 
 void optimize(Int number_of_optimization_runs, Int number_of_mc_steps,
               const algebra::Vector3D &anchor_centroid,
-              Particle *p, Refiner *refiner, core::MonteCarlo *opt,
-              FittingSolutions &fr, Model *) {
+              kernel::Particle *p, Refiner *refiner, core::MonteCarlo *opt,
+              FittingSolutions &fr, kernel::Model *) {
   Float e;
   core::RigidBody rb =
     core::RigidMember(refiner->get_refined(p)[0]).get_rigid_body();
@@ -116,7 +117,7 @@ void optimize(Int number_of_optimization_runs, Int number_of_mc_steps,
       e = opt->optimize(number_of_mc_steps);
       fr.add_solution(rb.get_reference_frame()
                       .get_transformation_to()/starting_trans,e);
-    } catch (ModelException err) {
+    } catch (base::ModelException err) {
       IMP_WARN("Optimization run " << i << " failed to converge."
                << std::endl);
     }
@@ -127,7 +128,7 @@ void optimize(Int number_of_optimization_runs, Int number_of_mc_steps,
 }
 
 FittingSolutions local_rigid_fitting_around_point(
-   Particle *p,Refiner *refiner,
+   kernel::Particle *p,Refiner *refiner,
    const FloatKey &wei_key,
    DensityMap *dmap, const algebra::Vector3D &anchor_centroid,
    OptimizerStates display_log,
@@ -147,11 +148,11 @@ FittingSolutions local_rigid_fitting_around_point(
               <<"of the density"<<std::endl);
    }
    //add restraints
-   Model *model = p->get_model();
-   RestraintSet *rsrs = add_restraints(model, dmap, p,refiner,
+   kernel::Model *model = p->get_model();
+   kernel::RestraintSet *rsrs = add_restraints(model, dmap, p,refiner,
                                        wei_key,fast);
    //create a rigid body mover and set the optimizer
-   OwnerPointer<core::MonteCarlo> opt = set_optimizer(model,
+   base::PointerMember<core::MonteCarlo> opt = set_optimizer(model,
                                                       display_log, p,refiner,
                            number_of_cg_steps, max_translation, max_rotation);
 
@@ -177,7 +178,7 @@ FittingSolutions local_rigid_fitting_around_point(
 }
 
 FittingSolutions local_rigid_fitting_around_points(
-   Particle *p,Refiner *refiner,
+   kernel::Particle *p,Refiner *refiner,
    const FloatKey &wei_key,
    DensityMap *dmap, const algebra::Vector3Ds &anchor_centroids,
    OptimizerStates display_log,
@@ -190,11 +191,11 @@ FittingSolutions local_rigid_fitting_around_points(
            " MC optimization runs, each with " << number_of_mc_steps <<
            " Monte Carlo steps , each with " << number_of_cg_steps <<
            " Conjugate Gradients rounds. " << std::endl);
-   Model *model = p->get_model();
+   kernel::Model *model = p->get_model();
 
-   RestraintSet *rsrs = add_restraints(model, dmap, p,refiner,
+   kernel::RestraintSet *rsrs = add_restraints(model, dmap, p,refiner,
                                        wei_key);
-   OwnerPointer<core::MonteCarlo> opt = set_optimizer(model,
+   base::PointerMember<core::MonteCarlo> opt = set_optimizer(model,
                                                       display_log, p,refiner,
                            number_of_cg_steps,max_translation, max_rotation);
 
@@ -214,7 +215,7 @@ FittingSolutions local_rigid_fitting_around_points(
 }
 
 FittingSolutions local_rigid_fitting_grid_search(
-   const ParticlesTemp &ps,
+   const kernel::ParticlesTemp &ps,
    const FloatKey &wei_key,
    DensityMap *dmap,
    Int max_voxels_translation,
@@ -250,7 +251,7 @@ FittingSolutions local_rigid_fitting_grid_search(
        algebra::get_random_vector_on(
           algebra::Sphere3D(algebra::Vector3D(0.0,0.0,0.0),1.));
      ::boost::uniform_real<> rand(-max_angle_in_radians,max_angle_in_radians);
-     Float angle =rand(random_number_generator);
+     Float angle =rand(base::random_number_generator);
      algebra::Rotation3D r =
        algebra::get_rotation_about_axis(axis, angle);
      rots.push_back(r);
@@ -263,7 +264,7 @@ FittingSolutions local_rigid_fitting_grid_search(
          rot_ind<<" out of "<< rots.size()<<std::endl);
      algebra::Transformation3D t1 =algebra::get_rotation_about_point(
                                  core::get_centroid(core::XYZs(ps)),*it);
-     Pointer<DensityMap> rotated_sampled_map =
+     base::Pointer<DensityMap> rotated_sampled_map =
        get_transformed(model_dens_map,t1);
      rotated_sampled_map->calcRMS();
      algebra::Vector3D
@@ -292,7 +293,7 @@ FittingSolutions local_rigid_fitting_grid_search(
    return fr;
 }
 
-FittingSolutions compute_fitting_scores(const ParticlesTemp &ps,
+FittingSolutions compute_fitting_scores(const kernel::ParticlesTemp &ps,
   DensityMap *em_map,
   const algebra::Transformation3Ds &transformations,
   bool fast_version,
@@ -389,8 +390,8 @@ FittingSolutions compute_fitting_scores(const ParticlesTemp &ps,
               "running fast version of compute_fitting_scores"<<std::endl);
       for (algebra::Transformation3Ds::const_iterator it =
          trans_for_fit.begin(); it != trans_for_fit.end();it++) {
-        OwnerPointer<DensityMap> transformed_sampled_map = get_transformed(
-              model_dens_map,*it);
+        base::PointerMember<DensityMap> transformed_sampled_map
+          = get_transformed(model_dens_map,*it);
         IMP_INTERNAL_CHECK(
            transformed_sampled_map->same_dimensions(model_dens_map),
            "sampled density map changed dimensions after transformation"
@@ -425,7 +426,7 @@ FittingSolutions compute_fitting_scores(const ParticlesTemp &ps,
     return fr;
 }
 
-Float compute_fitting_score(const ParticlesTemp &ps,
+Float compute_fitting_score(const kernel::ParticlesTemp &ps,
                             DensityMap *em_map,
                             FloatKey wei_key) {
   //create a grid that covers both the particles and the map
@@ -434,7 +435,7 @@ Float compute_fitting_score(const ParticlesTemp &ps,
   algebra::BoundingBox3D union_bb=algebra::get_union(
                              em_bb,
                              core::get_bounding_box(core::XYZRs(ps)));
-  Pointer<em::DensityMap> union_map =
+  base::Pointer<em::DensityMap> union_map =
     create_density_map(union_bb,
                        em_map->get_spacing());
   union_map->get_header_writable()->set_resolution(
