@@ -14,8 +14,8 @@
 #include "IMP/em/header_converters.h"
 #include <IMP/algebra/utility.h>
 #include <IMP/algebra/endian.h>
-#include <IMP/exception.h>
-#include <IMP/log.h>
+#include <IMP/base/exception.h>
+#include <IMP/base/log.h>
 #include <typeinfo>
 #include <complex>
 #include <string>
@@ -153,8 +153,7 @@ public:
     out.close();
   }
 
-  IMP_OBJECT_INLINE(SpiderImageReaderWriter,
-                    { out << "SpiderImageReaderWriter"; }, {});
+  IMP_OBJECT_METHODS(SpiderImageReaderWriter);
 };
 
 
