@@ -1,6 +1,6 @@
 /**
  *  \file domino_particle_states.h
- *  \brief Particles states for a rigid body that is going to be projected
+ *  \brief kernel::Particles states for a rigid body that is going to be projected
  *
  *  Copyright 2007-2013 IMP Inventors. All rights reserved.
  *
@@ -15,7 +15,7 @@
 #include "IMP/core/rigid_bodies.h"
 #include "IMP/algebra/Vector3D.h"
 #include "IMP/algebra/Rotation3D.h"
-#include "IMP/Pointer.h"
+#include "IMP/base/Pointer.h"
 #include "IMP/base_types.h"
 #include "IMP/Particle.h"
 
@@ -23,7 +23,7 @@ IMPEM2D_BEGIN_NAMESPACE
 
 
 
-/*! States that a set of Particles can have according to their positions
+/*! States that a set of kernel::Particles can have according to their positions
     and orientations in a grid. The orientations also determine the orientation
     of the projections of the particles.
 */
@@ -42,6 +42,7 @@ public:
     \param[in] positions Set of positions that the set of particles
                can have in the grid (points of the grid).
     \param[in] orientations Orientations of the particles in in the grid
+    \param[in] name
     Note: The number of states considered is positions * orientations, as
           each position can have all orientations.
     \
@@ -49,7 +50,7 @@ public:
   GridStates(const algebra::Vector3Ds &positions,
                             const algebra::Rotation3Ds &orientations,
                             const String &name="GridStates") :
-                            ParticleStates(name),
+                            domino::ParticleStates(name),
                            positions_(positions),
                            orientations_(orientations) {
     number_of_states_ = positions_.size()*orientations_.size();
@@ -71,10 +72,9 @@ public:
 IMP_OBJECTS(GridStates, GridStatesList);
 
 
-/*! States that a set of Particles can have according to their positions
+/*! States that a set of kernel::Particles can have according to their positions
     and orientations in a grid. The orientations also determine the orientation
     of the projections of the particles.
-  \param[in]
 */
 class IMPEM2DEXPORT ProjectionStates: public GridStates {
 
@@ -89,10 +89,11 @@ public:
     \param[in] positions Set of positions that the set of particles
                can have in the grid (points of the grid).
     \param[in] orientations Orientations of the particles in in the grid
-    \param[in] Projections of the particles in the given orientations.
+    \param[in] projections of the particles in the given orientations.
                There must be correspondence between the orientations and the
                projections.
-    Note: The number of states considered is positions * orientations, as
+    \param[in] name
+    \note The number of states considered is positions * orientations, as
           each position can have all orientations.
     \
   */
