@@ -8,7 +8,7 @@
 
 
 #include "IMP/em2d/CollisionCrossSection.h"
-#include "IMP/exception.h"
+#include "IMP/base/exception.h"
 #include "IMP/atom/Mass.h"
 
 
@@ -42,13 +42,13 @@ double CollisionCrossSection::get_ccs() const {
   }
 }
 
-void CollisionCrossSection::set_model_particles(const ParticlesTemp &ps) {
+void CollisionCrossSection::set_model_particles(const kernel::ParticlesTemp &ps) {
 
-  IMP_LOG_TERSE("CollisionCrossSection: Model particles set" << std::endl);
+  IMP_LOG_TERSE("CollisionCrossSection: kernel::Model particles set" << std::endl);
 
   for (unsigned int i = 0; i < ps.size() ; ++i) {
-    IMP_USAGE_CHECK((core::XYZR::particle_is_instance(ps[i]) &&
-                     atom::Mass::particle_is_instance(ps[i])),
+    IMP_USAGE_CHECK((core::XYZR::get_is_setup(ps[i]) &&
+                     atom::Mass::get_is_setup(ps[i])),
        "Particle " << i
        << " does not have the required attributes" << std::endl);
   }
