@@ -13,7 +13,6 @@
 #include <IMP/base_types.h>
 #include <IMP/algebra/BoundingBoxD.h>
 
-
 IMPEXAMPLE_BEGIN_NAMESPACE
 
 /** Provide an example of a more involved protocol for assembly a complex. The
@@ -22,16 +21,12 @@ IMPEXAMPLE_BEGIN_NAMESPACE
     addition, the assembly is optimized. The protocol seems to work at
     assembling the residues of a protein from a truncated distance matrix.
 */
-IMPEXAMPLEEXPORT void optimize_assembly(Model *m,
-                                        const ParticlesTemp &components,
-                       const RestraintsTemp &interactions,
-                       const RestraintsTemp &other_restraints,
-                       const algebra::BoundingBox3D &bb,
-                       PairScore *ev,
-                       double cutoff,
-                                        const PairPredicates &excluded
-                                        =PairPredicates());
+IMPEXAMPLEEXPORT void optimize_assembly(
+    kernel::Model *m, const kernel::ParticlesTemp &components,
+    const kernel::RestraintsTemp &interactions, const kernel::RestraintsTemp &other_restraints,
+    const algebra::BoundingBox3D &bb, PairScore *ev, double cutoff,
+    const PairPredicates &excluded = PairPredicates());
 
 IMPEXAMPLE_END_NAMESPACE
 
-#endif  /* IMPEXAMPLE_COMPLEX_ASSEMBLY_H */
+#endif /* IMPEXAMPLE_COMPLEX_ASSEMBLY_H */
