@@ -12,24 +12,28 @@
 #include <IMP/restraint_macros.h>
 #include <IMP/isd/isd_config.h>
 #include <IMP/SingletonScore.h>
-#include <IMP/isd/ISDRestraint.h>
+#include <IMP/kernel/Restraint.h>
 
 IMPISD_BEGIN_NAMESPACE
 
 //! Score a Scale particle with log(scale)
 //! the probability is 1/scale
 
-class IMPISDEXPORT JeffreysRestraint : public ISDRestraint
+class IMPISDEXPORT JeffreysRestraint : public kernel::Restraint
 {
-  Pointer<Particle> p_;
+    base::Pointer<Particle> p_;
 
 public:
   //! Create the restraint.
-  JeffreysRestraint(Particle *p);
+  JeffreysRestraint(Model *m, Particle *p);
+
+  virtual double unprotected_evaluate(
+          IMP::kernel::DerivativeAccumulator *accum) const IMP_OVERRIDE;
+  virtual IMP::kernel::ModelObjectsTemp do_get_inputs() const IMP_OVERRIDE;
+
+  IMP_OBJECT_METHODS(JeffreysRestraint);
+
 
-  /** This macro declares the basic needed methods: evaluate and show
-   */
-  IMP_RESTRAINT(JeffreysRestraint);
 
    /* call for probability */
   virtual double get_probability() const
