@@ -9,7 +9,7 @@
 #define IMPISD_BIVARIATE_FUNCTIONS_H
 
 #include <IMP/isd/isd_config.h>
-#include <IMP/Particle.h>
+#include <IMP/kernel/Particle.h>
 #include <IMP/isd/Nuisance.h>
 #include <IMP/isd/Scale.h>
 #include <IMP/isd/Switching.h>
@@ -105,7 +105,7 @@ class IMPISDEXPORT BivariateFunction : public base::Object
      virtual unsigned get_number_of_optimized_particles() const = 0;
 
      //! particle manipulation
-     virtual ParticlesTemp get_input_particles() const = 0;
+     virtual kernel::ParticlesTemp get_input_particles() const = 0;
      virtual ContainersTemp get_input_containers() const = 0;
 
      IMP_REF_COUNTED_DESTRUCTOR(BivariateFunction);
@@ -126,7 +126,7 @@ class IMPISDEXPORT BivariateFunction : public base::Object
 class IMPISDEXPORT Covariance1DFunction : public BivariateFunction
 {
     public:
-        Covariance1DFunction(Particle* tau, Particle* ilambda,
+        Covariance1DFunction(kernel::Particle* tau, kernel::Particle* ilambda,
                 double alpha=2.0, double jitter =0.0, double cutoff=1e-7) :
             BivariateFunction("Covariance1DFunction %1%"), alpha_(alpha),
             tau_(tau), lambda_(ilambda), J_(jitter),
@@ -140,20 +140,24 @@ class IMPISDEXPORT Covariance1DFunction : public BivariateFunction
         do_jitter = (jitter>IMP_ISD_BIVARIATE_FUNCTIONS_MINIMUM);
         alpha_square_ = (std::abs(alpha-2) <
                 IMP_ISD_BIVARIATE_FUNCTIONS_MINIMUM);
+        update();
     }
 
         bool has_changed() const {
             double tmpt = Scale(tau_).get_nuisance();
             double tmpl = Scale(lambda_).get_nuisance();
+            IMP_LOG_VERBOSE( "Covariance1DFunction: has_changed(): ");
+            IMP_LOG_VERBOSE( tmpt << " " << tau_val_ << " " );
+            IMP_LOG_VERBOSE( tmpl << " " << lambda_val_ << " " );
             if ((std::abs(tmpt - tau_val_) >
                         IMP_ISD_BIVARIATE_FUNCTIONS_MINIMUM)
                 || (std::abs(tmpl - lambda_val_) >
                     IMP_ISD_BIVARIATE_FUNCTIONS_MINIMUM))
             {
-                IMP_LOG_TERSE( "Covariance1DFunction: has_changed():");
-                IMP_LOG_TERSE( "true" << std::endl);
+                IMP_LOG_VERBOSE( "true" << std::endl);
                 return true;
             } else {
+                IMP_LOG_VERBOSE( "false" << std::endl);
                 return false;
             }
         }
@@ -470,9 +474,9 @@ class IMPISDEXPORT Covariance1DFunction : public BivariateFunction
             return count;
         }
 
-        ParticlesTemp get_input_particles() const
+        kernel::ParticlesTemp get_input_particles() const
         {
-            ParticlesTemp ret;
+            kernel::ParticlesTemp ret;
             ret.push_back(tau_);
             ret.push_back(lambda_);
             return ret;
@@ -485,9 +489,10 @@ class IMPISDEXPORT Covariance1DFunction : public BivariateFunction
         }
 
 
-        IMP_OBJECT_INLINE(Covariance1DFunction,
+        /*IMP_OBJECT_INLINE(Covariance1DFunction,
                 out << "covariance function with alpha = "
-                << alpha_ << std::endl, {});
+                << alpha_ << std::endl, {});*/
+        IMP_OBJECT_METHODS(Covariance1DFunction);
 
 
     private:
@@ -505,7 +510,7 @@ class IMPISDEXPORT Covariance1DFunction : public BivariateFunction
             ret = IMP::square(tau_val_) *std::exp(-0.5*ret);
             if (do_jitter && dist<IMP_ISD_BIVARIATE_FUNCTIONS_MINIMUM)
             {
-                ret += J_;
+                ret +=IMP::square(tau_val_) * J_;
             }
             IMP_INTERNAL_CHECK(!base::isnan(ret),
                 "function value is nan. tau = "
@@ -516,7 +521,7 @@ class IMPISDEXPORT Covariance1DFunction : public BivariateFunction
 
     private:
         double alpha_;
-        Pointer<Particle> tau_,lambda_;
+        base::Pointer<kernel::Particle> tau_,lambda_;
         double tau_val_,lambda_val_,J_,cutoff_,alpha_square_;
         bool do_jitter;
 
