@@ -6,14 +6,14 @@
 
 #include <IMP/isd/GaussianProcessInterpolation.h>
 #include <IMP/macros.h>
-#include <IMP/Object.h>
+#include <IMP/base/Object.h>
 #include <IMP/constants.h>
 #include <math.h>
 #include <IMP/algebra/Vector3D.h>
 #include <IMP/algebra/internal/tnt_array2d.h>
 #include <IMP/algebra/internal/jama_lu.h>
 #include <boost/scoped_ptr.hpp>
-#include <IMP/log.h>
+#include <IMP/base/log.h>
 
 IMPISD_BEGIN_NAMESPACE
 
@@ -24,7 +24,7 @@ IMPISD_BEGIN_NAMESPACE
                                unsigned n_obs,
                                UnivariateFunction *mean_function,
                                BivariateFunction *covariance_function,
-                               Particle *sigma,
+                               kernel::Particle *sigma,
                                double sparse_cutoff) :
         Object("GaussianProcessInterpolation%1%"), x_(x), n_obs_(n_obs),
         mean_function_(mean_function),
@@ -72,6 +72,7 @@ IMPISD_BEGIN_NAMESPACE
 
   void GaussianProcessInterpolation::force_covariance_update()
 {
+    flag_ldlt_ = false;
     flag_Omi_ = false;
     flag_OmiIm_ = false;
     flag_W_ = false;
@@ -136,7 +137,7 @@ IMPISD_BEGIN_NAMESPACE
 
   double GaussianProcessInterpolation::get_posterior_mean(Floats x) const
 {
-   // std::cerr << "posterior mean at q=" << x(0) << std::endl;
+    //std::cerr << "posterior mean at q=" << x(0) << std::endl;
     VectorXd wx(get_wx_vector(x));
     VectorXd OmiIm(get_OmiIm());
     double ret = wx.transpose()*OmiIm;
@@ -147,6 +148,7 @@ IMPISD_BEGIN_NAMESPACE
     std::cerr << std::endl << "mean func: " << (*mean_function_)(x)[0]
         << std::endl;
     std::cerr << "product " << ret << std::endl;*/
+    //std::cout << "sigma val = " << sigma_val_ << std::endl;
     return ret + (*mean_function_)(x)[0]; //licit because OmiIm is up to date
 }
 
@@ -155,7 +157,6 @@ IMPISD_BEGIN_NAMESPACE
 {
     //std::cerr << "posterior covariance at q=" << x1(0) << std::endl;
     VectorXd wx2(get_wx_vector(x2));
-    MatrixXd Omi(get_Omi());
     VectorXd wx1;
     if (x1 != x2)
     {
@@ -163,7 +164,7 @@ IMPISD_BEGIN_NAMESPACE
     } else {
          wx1=wx2;
     }
-    double ret = wx1.transpose()*Omi*wx2;
+    double ret = wx1.transpose()*get_ldlt().solve(wx2);
     return (*covariance_function_)(x1,x2)[0] - ret; //licit because Omi
                                                     //is up to date
 }
@@ -174,9 +175,10 @@ IMPISD_BEGIN_NAMESPACE
     unsigned N(x.size());
     MatrixXd Wpri(M_,N);
     for (unsigned i=0; i<N; i++) Wpri.col(i) = get_wx_vector(x[i]);
-    MatrixXd Omi(get_Omi()); // we can now use covariance_function_
+    Eigen::LDLT<MatrixXd, Eigen::Upper> ldlt(get_ldlt());
+    // we can now use covariance_function_ because it is up to date
     MatrixXd Wpost((*covariance_function_)(x));
-    return Wpost - Wpri.transpose()*Omi*Wpri;
+    return Wpost - Wpri.transpose()*ldlt.solve(Wpri);
 }
 
   FloatsList GaussianProcessInterpolation::get_posterior_covariance_matrix(
@@ -340,9 +342,8 @@ MatrixXd GaussianProcessInterpolation::get_posterior_covariance_hessian(
             ret.bottomRightCorner(Onum_opt, Onum_opt)(i,j)
                 += (dOmdp[j].transpose()*tmp).trace();
     }
-    for (unsigned i=0; i<d2covdo.size(); i++)
-        for (unsigned j=0; j<d2covdo[i].size(); j++)
-            d2covdo[i][j].resize(0,0);
+    for (unsigned i=0; i<d2covdo.size(); i++) d2covdo[i].clear();
+    d2covdo.clear();
 
     //compute cross-term
     std::vector<MatrixXd> d2covdwdo;
@@ -361,12 +362,10 @@ MatrixXd GaussianProcessInterpolation::get_posterior_covariance_hessian(
     ret.bottomRightCorner(Onum_opt,Onum_opt) += tmpH+tmpH.transpose();
 
     //deallocate unused stuff
-    tmpH.resize(0,0);
-    for (unsigned i=0; i<d2covdwdo.size(); i++)
-        d2covdwdo[i].resize(0,0);
-    for (unsigned i=0; i<dOmdp.size(); i++)
-        dOmdp[i].resize(0,0);
-    dwqdp.resize(0,0);
+    //tmpH.resize(0,0);
+    d2covdwdo.clear();
+    dOmdp.clear();
+    //dwqdp.resize(0,0);
 
     //dcov/dw_k * d2w^k/(dp_i dp_j)
     VectorXd dcwq(get_dcov_dwq(x));
@@ -375,7 +374,7 @@ MatrixXd GaussianProcessInterpolation::get_posterior_covariance_hessian(
             ret.bottomRightCorner(cov_opt,cov_opt)(i,j)
                 += dcwq.transpose()*get_wx_vector_second_derivative(
                         x, mnum+1+i, mnum+1+j);
-    dcwq.resize(0,0);
+    //dcwq.resize(0,0);
 
     //dcov/dOm_kl * d2Om^kl/(dp_i dp_j), zero when p_i or p_j is sigma or mean
     MatrixXd dcOm(get_dcov_dOm(x));
@@ -384,7 +383,7 @@ MatrixXd GaussianProcessInterpolation::get_posterior_covariance_hessian(
             ret.bottomRightCorner(cov_opt,cov_opt)(i,j)
                 += (dcOm.transpose()*get_Omega_second_derivative(
                             i+1,j+1)).trace();
-    dcOm.resize(0,0);
+    //dcOm.resize(0,0);
 
     //return as symmetric matrix
     for (unsigned i=mnum_opt; i<num_opt; ++i)
@@ -426,6 +425,7 @@ MatrixXd GaussianProcessInterpolation::get_posterior_covariance_hessian(
 {
     bool ret = covariance_function_->has_changed();
     if (ret) covariance_function_->update();
+    if (flag_ldlt_) flag_ldlt_ = !ret;
     if (flag_Omi_) flag_Omi_ = !ret;
     if (flag_OmiIm_) flag_OmiIm_ = !ret;
     if (flag_W_) flag_W_ = !ret;
@@ -443,10 +443,12 @@ MatrixXd GaussianProcessInterpolation::get_posterior_covariance_hessian(
         //and mark Omega as outdated
         flag_Omega_ = false;
         flag_Omega_gpir_ = false;
+        flag_ldlt_ = false;
         flag_Omi_ = false;
         flag_OmiIm_ = false;
     }
     IMP_LOG_TERSE( "update_flags_covariance: ret " << ret
+            << " flag_ldlt_ " << flag_ldlt_
             << " flag_Omi_ " << flag_Omi_
             << " flag_OmiIm_ " << flag_OmiIm_
             << " flag_W_ " << flag_W_
@@ -458,7 +460,7 @@ MatrixXd GaussianProcessInterpolation::get_posterior_covariance_hessian(
   VectorXd GaussianProcessInterpolation::get_wx_vector(Floats xval) const
 {
     const_cast<GaussianProcessInterpolation *>(this)->update_flags_covariance();
-    IMP_LOG_TERSE("  get_wx_vector at q= " << xval[0] << " ");
+    IMP_LOG_TERSE("  get_wx_vector at q= " << xval[0] << " : ");
     VectorXd wx(M_);
     for (unsigned i=0; i<M_; i++)
     {
@@ -526,7 +528,7 @@ MatrixXd GaussianProcessInterpolation::get_posterior_covariance_hessian(
         VectorXd m(get_m());
         MatrixXd Omi(get_Omi());
         IMP_LOG_TERSE( "OmiIm ");
-        OmiIm_ = Omi*(I-m);
+        OmiIm_ = ldlt_.solve(I-m);
         IMP_LOG_TERSE( std::endl);
 }
 
@@ -539,6 +541,7 @@ MatrixXd GaussianProcessInterpolation::get_posterior_covariance_hessian(
         IMP_LOG_TERSE( "need to update m" << std::endl);
         const_cast<GaussianProcessInterpolation *>(this)->compute_m();
         const_cast<GaussianProcessInterpolation *>(this)->flag_m_ = true;
+        IMP_LOG_VERBOSE( m_ );
         IMP_LOG_TERSE( "done updating m" << std::endl);
     }
     return m_;
@@ -662,7 +665,36 @@ void GaussianProcessInterpolation::add_to_Omega_particle_derivative(
     }
 }
 
-  MatrixXd GaussianProcessInterpolation::get_Omi() const
+Eigen::LDLT<MatrixXd, Eigen::Upper>
+GaussianProcessInterpolation::get_ldlt() const
+{
+    IMP_LOG_TERSE( "get_ldlt()" << std::endl);
+    const_cast<GaussianProcessInterpolation *>(this)->update_flags_covariance();
+    if (!flag_ldlt_)
+    {
+        IMP_LOG_TERSE( "need to update ldlt" << std::endl);
+        const_cast<GaussianProcessInterpolation *>(this)->compute_ldlt();
+        const_cast<GaussianProcessInterpolation *>(this)->flag_ldlt_ = true;
+        IMP_LOG_TERSE( "done updating ldlt" << std::endl);
+    }
+    return ldlt_;
+}
+
+void GaussianProcessInterpolation::compute_ldlt()
+{
+    //get Omega=W+S/N
+    MatrixXd WpS = get_Omega();
+    IMP_LOG_TERSE("  compute_ldlt: Cholesky" << std::endl);
+    //compute Cholesky decomp
+    Eigen::LDLT<MatrixXd, Eigen::Upper> ldlt;
+    ldlt.compute(WpS);
+    if (!ldlt.isPositive())
+            IMP_THROW("Matrix is not positive semidefinite!",
+                    ModelException);
+    ldlt_ = ldlt;
+}
+
+MatrixXd GaussianProcessInterpolation::get_Omi() const
 {
     IMP_LOG_TERSE( "get_Omi()" << std::endl);
     const_cast<GaussianProcessInterpolation *>(this)->update_flags_covariance();
@@ -676,23 +708,16 @@ void GaussianProcessInterpolation::add_to_Omega_particle_derivative(
     return Omi_;
 }
 
-  void GaussianProcessInterpolation::compute_Omi()
+
+void GaussianProcessInterpolation::compute_Omi()
 {
-    //get Omega=W+S/N
-    MatrixXd WpS = get_Omega();
-    IMP_LOG_TERSE("  compute_inverse: Cholesky" << std::endl);
-    //compute Cholesky decomp
-    Eigen::LDLT<MatrixXd> ldlt;
-    ldlt.compute(WpS);
-    if (!ldlt.isPositive())
-            IMP_THROW("Matrix is not positive semidefinite!",
-                    ModelException);
     //get inverse
-    IMP_LOG_TERSE("  compute_inverse: inverse" << std::endl);
+    IMP_LOG_TERSE("  compute_Omi: inverse" << std::endl);
+    Eigen::LDLT<MatrixXd, Eigen::Upper> ldlt(get_ldlt());
     Omi_= ldlt.solve(MatrixXd::Identity(M_,M_));
 }
 
-  MatrixXd GaussianProcessInterpolation::get_W() const
+MatrixXd GaussianProcessInterpolation::get_W() const
 {
     IMP_LOG_TERSE( "get_W()" << std::endl);
     const_cast<GaussianProcessInterpolation *>(this)->update_flags_covariance();
@@ -714,15 +739,15 @@ void GaussianProcessInterpolation::add_to_Omega_particle_derivative(
 VectorXd GaussianProcessInterpolation::get_dcov_dwq(Floats q) const
 {
     VectorXd wq(get_wx_vector(q));
-    MatrixXd Omi(get_Omi());
-    return -2*Omi*wq;
+    Eigen::LDLT<MatrixXd, Eigen::Upper> ldlt(get_ldlt());
+    return -2*ldlt.solve(wq);
 }
 
 MatrixXd GaussianProcessInterpolation::get_dcov_dOm(Floats q) const
 {
     VectorXd wq(get_wx_vector(q));
-    MatrixXd Omi(get_Omi());
-    VectorXd ret(Omi*wq);
+    Eigen::LDLT<MatrixXd, Eigen::Upper> ldlt(get_ldlt());
+    VectorXd ret(ldlt.solve(wq));
     return ret*ret.transpose();
 }
 
@@ -734,9 +759,9 @@ MatrixXd GaussianProcessInterpolation::get_d2cov_dwq_dwq() const
 MatrixXd GaussianProcessInterpolation::get_d2cov_dwq_dOm(Floats q, unsigned m)
     const
 {
-    MatrixXd Omi(get_Omi());
     VectorXd wq(get_wx_vector(q));
-    VectorXd L(Omi*wq);
+    VectorXd L(get_ldlt().solve(wq));
+    MatrixXd Omi(get_Omi());
     MatrixXd ret(L*Omi.col(m).transpose());
     return ret + ret.transpose();
 }
@@ -744,9 +769,9 @@ MatrixXd GaussianProcessInterpolation::get_d2cov_dwq_dOm(Floats q, unsigned m)
 MatrixXd GaussianProcessInterpolation::get_d2cov_dOm_dOm(Floats q,
         unsigned m, unsigned n) const
 {
-    MatrixXd Omi(get_Omi());
     VectorXd wq(get_wx_vector(q));
-    VectorXd L(Omi*wq);
+    VectorXd L(get_ldlt().solve(wq));
+    MatrixXd Omi(get_Omi());
     MatrixXd tmp(Omi.col(m)*L.transpose());
     return -L(n)*(tmp + tmp.transpose());
 }
@@ -764,18 +789,14 @@ MatrixXd GaussianProcessInterpolation::get_d2cov_dOm_dOm(Floats q,
     return MatrixXd::Zero(1,1);
 }
 */
-  void GaussianProcessInterpolation::do_show(std::ostream &out) const
-{
-    out << "Interpolation via gaussian process" << std::endl;
-}
 
-  ParticlesTemp GaussianProcessInterpolation::get_input_particles() const
+kernel::ParticlesTemp GaussianProcessInterpolation::get_input_particles() const
 {
-    ParticlesTemp ret;
-    ParticlesTemp ret1 = mean_function_->get_input_particles();
+    kernel::ParticlesTemp ret;
+    kernel::ParticlesTemp ret1 = mean_function_->get_input_particles();
     ret.insert(ret.end(),ret1.begin(),ret1.end());
     ret.push_back(sigma_);
-    ParticlesTemp ret2 = covariance_function_->get_input_particles();
+    kernel::ParticlesTemp ret2 = covariance_function_->get_input_particles();
     ret.insert(ret.end(),ret2.begin(),ret2.end());
     return ret;
 }
@@ -789,4 +810,5 @@ MatrixXd GaussianProcessInterpolation::get_d2cov_dOm_dOm(Floats q,
     ret.insert(ret.end(),ret2.begin(),ret2.end());
     return ret;
 }
+
 IMPISD_END_NAMESPACE
