@@ -10,8 +10,8 @@
 
 IMPISD_BEGIN_NAMESPACE
 
-HybridMonteCarlo::HybridMonteCarlo(Model *m, Float kT, unsigned steps, Float
-        timestep, unsigned persistence) : MonteCarlo(m)
+HybridMonteCarlo::HybridMonteCarlo(kernel::Model *m, Float kT, unsigned steps,
+        Float timestep, unsigned persistence) : MonteCarlo(m)
 {
 
     mv_ = new MolecularDynamicsMover(m, steps, timestep);
@@ -25,10 +25,19 @@ HybridMonteCarlo::HybridMonteCarlo(Model *m, Float kT, unsigned steps, Float
     persistence_counter_=0;
 }
 
+double HybridMonteCarlo::do_evaluate(const kernel::ParticleIndexes &) const
+{
+    if (get_use_incremental_scoring_function())
+        IMP_THROW("Incremental scoring not supported", ModelException);
+    double ekin = md_->get_kinetic_energy();
+    double epot = get_scoring_function()->evaluate(false);
+    return ekin + epot;
+}
+
 void HybridMonteCarlo::do_step()
 {
     //gibbs sampler on x and v
-    //persistence=p samples p times x and once v
+    //persistence=p : sample p times x and once v
     //However because it's constant E, a rejected move
     //will result in recalculating the same move up to p times
     //until it is either accepted or the velocities are redrawn
@@ -43,18 +52,11 @@ void HybridMonteCarlo::do_step()
         static const double kB = 8.31441 / 4186.6;
         md_->assign_velocities(get_kt() / kB);
     }
-    ParticleIndexes all_optimized_particles;
-    {
-      ModelObjectsTemp op = get_model()->get_optimized_particles();
-      for (unsigned int i = 0; i< op.size(); ++i) {
-        all_optimized_particles.push_back(dynamic_cast<Particle*>(op[i].get())
-                                          ->get_index());
-      }
-    }
-    double last = do_evaluate(all_optimized_particles);
+    kernel::ParticleIndexes unused;
+    double last = do_evaluate(unused);
     core::MonteCarloMoverResult moved = do_move();
 
-    double energy = do_evaluate(all_optimized_particles);
+    double energy = do_evaluate(unused);
     bool accepted = do_accept_or_reject_move(energy, last,
                                              moved.get_proposal_ratio());
     while ((!accepted) && (persistence_counter_ < persistence_-1))
