@@ -19,10 +19,10 @@ class TestGaussianRestraintSimple3(IMP.test.TestCase):
         IMP.test.TestCase.setUp(self)
         #IMP.base.set_log_level(IMP.MEMORY)
         IMP.base.set_log_level(0)
-        self.m = IMP.Model()
-        self.sigma = Scale.setup_particle(IMP.Particle(self.m), 2.0)
-        self.mu = Nuisance.setup_particle(IMP.Particle(self.m), 1.0)
-        self.x = Nuisance.setup_particle(IMP.Particle(self.m), 2.0)
+        self.m = IMP.kernel.Model()
+        self.sigma = Scale.setup_particle(IMP.kernel.Particle(self.m), 2.0)
+        self.mu = Nuisance.setup_particle(IMP.kernel.Particle(self.m), 1.0)
+        self.x = Nuisance.setup_particle(IMP.kernel.Particle(self.m), 2.0)
         self.locations=[self.x, self.mu]
         self.all = self.locations+[self.sigma]
         self.DA = IMP.DerivativeAccumulator()
@@ -138,7 +138,7 @@ class TestGaussianRestraintSimple3(IMP.test.TestCase):
     def testFail(self):
         "Test failures of GaussianRestraint(3)"
         if IMP.base.get_check_level() >= IMP.base.USAGE:
-            dummy=IMP.Particle(self.m)
+            dummy=IMP.kernel.Particle(self.m)
             self.assertRaises(IMP.base.UsageException, GaussianRestraint, dummy,
                               self.all[1], self.all[2])
             self.assertRaises(IMP.base.UsageException, GaussianRestraint,
@@ -152,10 +152,10 @@ class TestGaussianRestraintSimple21(IMP.test.TestCase):
         IMP.test.TestCase.setUp(self)
         #IMP.base.set_log_level(IMP.MEMORY)
         IMP.base.set_log_level(0)
-        self.m = IMP.Model()
+        self.m = IMP.kernel.Model()
         self.sigma = 2.0
-        self.mu = Nuisance.setup_particle(IMP.Particle(self.m), 1.0)
-        self.x = Nuisance.setup_particle(IMP.Particle(self.m), 2.0)
+        self.mu = Nuisance.setup_particle(IMP.kernel.Particle(self.m), 1.0)
+        self.x = Nuisance.setup_particle(IMP.kernel.Particle(self.m), 2.0)
         self.locations=[self.x, self.mu]
         self.all = self.locations+[self.sigma]
         self.DA = IMP.DerivativeAccumulator()
@@ -258,10 +258,10 @@ class TestGaussianRestraintSimple22(IMP.test.TestCase):
         IMP.test.TestCase.setUp(self)
         #IMP.base.set_log_level(IMP.MEMORY)
         IMP.base.set_log_level(0)
-        self.m = IMP.Model()
-        self.sigma = Scale.setup_particle(IMP.Particle(self.m), 2.0)
+        self.m = IMP.kernel.Model()
+        self.sigma = Scale.setup_particle(IMP.kernel.Particle(self.m), 2.0)
         self.mu = 1.0
-        self.x = Nuisance.setup_particle(IMP.Particle(self.m), 2.0)
+        self.x = Nuisance.setup_particle(IMP.kernel.Particle(self.m), 2.0)
         self.locations=[self.x, self.mu]
         self.all = self.locations+[self.sigma]
         self.DA = IMP.DerivativeAccumulator()
@@ -365,9 +365,9 @@ class TestGaussianRestraintSimple23(IMP.test.TestCase):
         IMP.test.TestCase.setUp(self)
         #IMP.base.set_log_level(IMP.MEMORY)
         IMP.base.set_log_level(0)
-        self.m = IMP.Model()
-        self.sigma = Scale.setup_particle(IMP.Particle(self.m), 2.0)
-        self.mu = Nuisance.setup_particle(IMP.Particle(self.m), 1.0)
+        self.m = IMP.kernel.Model()
+        self.sigma = Scale.setup_particle(IMP.kernel.Particle(self.m), 2.0)
+        self.mu = Nuisance.setup_particle(IMP.kernel.Particle(self.m), 1.0)
         self.x = 2.0
         self.locations=[self.x, self.mu]
         self.all = self.locations+[self.sigma]
@@ -472,8 +472,8 @@ class TestGaussianRestraintSimple11(IMP.test.TestCase):
         IMP.test.TestCase.setUp(self)
         #IMP.base.set_log_level(IMP.MEMORY)
         IMP.base.set_log_level(0)
-        self.m = IMP.Model()
-        self.sigma = Scale.setup_particle(IMP.Particle(self.m), 2.0)
+        self.m = IMP.kernel.Model()
+        self.sigma = Scale.setup_particle(IMP.kernel.Particle(self.m), 2.0)
         self.mu = 1.0
         self.x = 2.0
         self.locations=[self.x, self.mu]
@@ -564,9 +564,9 @@ class TestGaussianRestraintSimple12(IMP.test.TestCase):
         IMP.test.TestCase.setUp(self)
         #IMP.base.set_log_level(IMP.MEMORY)
         IMP.base.set_log_level(0)
-        self.m = IMP.Model()
+        self.m = IMP.kernel.Model()
         self.sigma = 2.0
-        self.mu = Nuisance.setup_particle(IMP.Particle(self.m), 1.0)
+        self.mu = Nuisance.setup_particle(IMP.kernel.Particle(self.m), 1.0)
         self.x = 2.0
         self.locations=[self.x, self.mu]
         self.all = self.locations+[self.sigma]
@@ -655,10 +655,10 @@ class TestGaussianRestraintSimple13(IMP.test.TestCase):
         IMP.test.TestCase.setUp(self)
         #IMP.base.set_log_level(IMP.MEMORY)
         IMP.base.set_log_level(0)
-        self.m = IMP.Model()
+        self.m = IMP.kernel.Model()
         self.sigma = 2.0
         self.mu = 1.0
-        self.x = Nuisance.setup_particle(IMP.Particle(self.m), 2.0)
+        self.x = Nuisance.setup_particle(IMP.kernel.Particle(self.m), 2.0)
         self.locations=[self.x, self.mu]
         self.all = self.locations+[self.sigma]
         self.DA = IMP.DerivativeAccumulator()
