@@ -36,12 +36,12 @@ class Tests(IMP.test.TestCase):
         IMP.test.TestCase.setUp(self)
         #IMP.base.set_log_level(IMP.MEMORY)
         IMP.base.set_log_level(0)
-        self.m = IMP.Model()
-        self.G = Scale.setup_particle(IMP.Particle(self.m), 10.0)
-        self.Rg = Scale.setup_particle(IMP.Particle(self.m), 10.0)
-        self.d = Scale.setup_particle(IMP.Particle(self.m), 4.0)
-        self.s = Scale.setup_particle(IMP.Particle(self.m), 1.0)
-        self.A = Scale.setup_particle(IMP.Particle(self.m), 2.0)
+        self.m = IMP.kernel.Model()
+        self.G = Scale.setup_particle(IMP.kernel.Particle(self.m), 10.0)
+        self.Rg = Scale.setup_particle(IMP.kernel.Particle(self.m), 10.0)
+        self.d = Scale.setup_particle(IMP.kernel.Particle(self.m), 4.0)
+        self.s = Scale.setup_particle(IMP.kernel.Particle(self.m), 1.0)
+        self.A = Scale.setup_particle(IMP.kernel.Particle(self.m), 2.0)
         self.particles = [self.G, self.Rg, self.d, self.s, self.A]
         self.mean = GeneralizedGuinierPorodFunction(*self.particles)
         self.DA=IMP.DerivativeAccumulator()
