@@ -19,10 +19,10 @@ class TestLognormalRestraintSimple3(IMP.test.TestCase):
         IMP.test.TestCase.setUp(self)
         #IMP.base.set_log_level(IMP.MEMORY)
         IMP.base.set_log_level(0)
-        self.m = IMP.Model()
-        self.sigma = Scale.setup_particle(IMP.Particle(self.m), 2.0)
-        self.mu = Nuisance.setup_particle(IMP.Particle(self.m), 1.0)
-        self.x = Nuisance.setup_particle(IMP.Particle(self.m), 2.0)
+        self.m = IMP.kernel.Model()
+        self.sigma = Scale.setup_particle(IMP.kernel.Particle(self.m), 2.0)
+        self.mu = Nuisance.setup_particle(IMP.kernel.Particle(self.m), 1.0)
+        self.x = Nuisance.setup_particle(IMP.kernel.Particle(self.m), 2.0)
         self.locations=[self.x, self.mu]
         self.all = self.locations+[self.sigma]
         self.DA = IMP.DerivativeAccumulator()
@@ -125,7 +125,7 @@ class TestLognormalRestraintSimple3(IMP.test.TestCase):
     def testFail(self):
         "Test failures of LognormalRestraint(3)"
         if IMP.base.get_check_level() >= IMP.base.USAGE:
-            dummy=IMP.Particle(self.m)
+            dummy=IMP.kernel.Particle(self.m)
             self.assertRaises(IMP.base.UsageException, LognormalRestraint, dummy,
                               self.all[1], self.all[2])
             self.assertRaises(IMP.base.UsageException, LognormalRestraint,
@@ -139,10 +139,10 @@ class TestLognormalRestraintSimple21(IMP.test.TestCase):
         IMP.test.TestCase.setUp(self)
         #IMP.base.set_log_level(IMP.MEMORY)
         IMP.base.set_log_level(0)
-        self.m = IMP.Model()
+        self.m = IMP.kernel.Model()
         self.sigma = 2.0
-        self.mu = Nuisance.setup_particle(IMP.Particle(self.m), 1.0)
-        self.x = Nuisance.setup_particle(IMP.Particle(self.m), 2.0)
+        self.mu = Nuisance.setup_particle(IMP.kernel.Particle(self.m), 1.0)
+        self.x = Nuisance.setup_particle(IMP.kernel.Particle(self.m), 2.0)
         self.locations=[self.x, self.mu]
         self.all = self.locations+[self.sigma]
         self.DA = IMP.DerivativeAccumulator()
@@ -237,10 +237,10 @@ class TestLognormalRestraintSimple22(IMP.test.TestCase):
         IMP.test.TestCase.setUp(self)
         #IMP.base.set_log_level(IMP.MEMORY)
         IMP.base.set_log_level(0)
-        self.m = IMP.Model()
-        self.sigma = Scale.setup_particle(IMP.Particle(self.m), 2.0)
+        self.m = IMP.kernel.Model()
+        self.sigma = Scale.setup_particle(IMP.kernel.Particle(self.m), 2.0)
         self.mu = 1.0
-        self.x = Nuisance.setup_particle(IMP.Particle(self.m), 2.0)
+        self.x = Nuisance.setup_particle(IMP.kernel.Particle(self.m), 2.0)
         self.locations=[self.x, self.mu]
         self.all = self.locations+[self.sigma]
         self.DA = IMP.DerivativeAccumulator()
@@ -336,9 +336,9 @@ class TestLognormalRestraintSimple23(IMP.test.TestCase):
         IMP.test.TestCase.setUp(self)
         #IMP.base.set_log_level(IMP.MEMORY)
         IMP.base.set_log_level(0)
-        self.m = IMP.Model()
-        self.sigma = Scale.setup_particle(IMP.Particle(self.m), 2.0)
-        self.mu = Nuisance.setup_particle(IMP.Particle(self.m), 1.0)
+        self.m = IMP.kernel.Model()
+        self.sigma = Scale.setup_particle(IMP.kernel.Particle(self.m), 2.0)
+        self.mu = Nuisance.setup_particle(IMP.kernel.Particle(self.m), 1.0)
         self.x = 2.0
         self.locations=[self.x, self.mu]
         self.all = self.locations+[self.sigma]
@@ -435,8 +435,8 @@ class TestLognormalRestraintSimple11(IMP.test.TestCase):
         IMP.test.TestCase.setUp(self)
         #IMP.base.set_log_level(IMP.MEMORY)
         IMP.base.set_log_level(0)
-        self.m = IMP.Model()
-        self.sigma = Scale.setup_particle(IMP.Particle(self.m), 2.0)
+        self.m = IMP.kernel.Model()
+        self.sigma = Scale.setup_particle(IMP.kernel.Particle(self.m), 2.0)
         self.mu = 1.0
         self.x = 2.0
         self.locations=[self.x, self.mu]
@@ -524,9 +524,9 @@ class TestLognormalRestraintSimple12(IMP.test.TestCase):
         IMP.test.TestCase.setUp(self)
         #IMP.base.set_log_level(IMP.MEMORY)
         IMP.base.set_log_level(0)
-        self.m = IMP.Model()
+        self.m = IMP.kernel.Model()
         self.sigma = 2.0
-        self.mu = Nuisance.setup_particle(IMP.Particle(self.m), 1.0)
+        self.mu = Nuisance.setup_particle(IMP.kernel.Particle(self.m), 1.0)
         self.x = 2.0
         self.locations=[self.x, self.mu]
         self.all = self.locations+[self.sigma]
@@ -604,10 +604,10 @@ class TestLognormalRestraintSimple13(IMP.test.TestCase):
         IMP.test.TestCase.setUp(self)
         #IMP.base.set_log_level(IMP.MEMORY)
         IMP.base.set_log_level(0)
-        self.m = IMP.Model()
+        self.m = IMP.kernel.Model()
         self.sigma = 2.0
         self.mu = 1.0
-        self.x = Nuisance.setup_particle(IMP.Particle(self.m), 2.0)
+        self.x = Nuisance.setup_particle(IMP.kernel.Particle(self.m), 2.0)
         self.locations=[self.x, self.mu]
         self.all = self.locations+[self.sigma]
         self.DA = IMP.DerivativeAccumulator()
