@@ -13,10 +13,14 @@
 #include <IMP/base/Pointer.h>
 
 IMPKERNEL_BEGIN_NAMESPACE
+
+IMPKERNEL_DEPRECATED_HEADER(2.1, "Please use IMP/base/Pointer.h instead.");
+
 #ifndef IMP_DOXYGEN
 using IMP::base::Pointer;
-using IMP::base::OwnerPointer;
+using IMP::base::PointerMember;
+using IMP::base::PointerMember;
 #endif
 IMPKERNEL_END_NAMESPACE
 
-#endif  /* IMPKERNEL_POINTER_H */
+#endif /* IMPKERNEL_POINTER_H */
