@@ -10,8 +10,11 @@
 #define IMPKERNEL_REF_COUNTED_H
 
 #include <IMP/kernel/kernel_config.h>
+// skip deprecated header in kernel.h
+#ifndef IMPKERNEL_ALL
 #include <IMP/base/RefCounted.h>
 
+IMPKERNEL_DEPRECATED_HEADER(2.1, "Use base/RefCounted.h");
 
 IMPKERNEL_BEGIN_NAMESPACE
 #if !defined(IMP_DOXYGEN)
@@ -19,5 +22,6 @@ using IMP::base::RefCounted;
 #endif
 
 IMPKERNEL_END_NAMESPACE
+#endif
 
-#endif  /* IMPKERNEL_REF_COUNTED_H */
+#endif /* IMPKERNEL_REF_COUNTED_H */
