@@ -26,17 +26,16 @@ IMPKERNELEXPORT ParticlesTemp get_input_particles(const ModelObjectsTemp &mos);
 
 /** Return all the input particles for a given ModelObject.*/
 IMPKERNELEXPORT ContainersTemp
-get_input_containers(const ModelObjectsTemp &mos);
+    get_input_containers(const ModelObjectsTemp &mos);
 
 /** Return all the output particles for a given ModelObject.*/
-IMPKERNELEXPORT ParticlesTemp
-get_output_particles(const ModelObjectsTemp &mos);
+IMPKERNELEXPORT ParticlesTemp get_output_particles(const ModelObjectsTemp &mos);
 
 /** Return all the output particles for a given ModelObject.*/
 IMPKERNELEXPORT ContainersTemp
-get_output_containers(const ModelObjectsTemp &mos);
+    get_output_containers(const ModelObjectsTemp &mos);
 /** @} */
 
 IMPKERNEL_END_NAMESPACE
 
-#endif  /* IMPKERNEL_INPUT_OUTPUT_H */
+#endif /* IMPKERNEL_INPUT_OUTPUT_H */
