@@ -20,10 +20,9 @@ IMPKERNEL_BEGIN_INTERNAL_NAMESPACE
     benchmarks that don't require the atom module for input, yet can use
     pdb files to make shapes.
 */
-IMPKERNELEXPORT ParticlesTemp create_particles_from_pdb(base::TextInput fname,
-                                                  Model *m);
-
+IMPKERNELEXPORT ParticlesTemp
+    create_particles_from_pdb(base::TextInput fname, Model *m);
 
 IMPKERNEL_END_INTERNAL_NAMESPACE
 
-#endif  /* IMPKERNEL_INTERNAL_PDB_H */
+#endif /* IMPKERNEL_INTERNAL_PDB_H */
