@@ -7,13 +7,13 @@
 
 #include "IMP/kernel/internal/static.h"
 #include "IMP/kernel/Particle.h"
+#include "IMP/kernel/internal/utility.h"
 #include "IMP/base//set.h"
 
 IMPKERNEL_BEGIN_INTERNAL_NAMESPACE
 
 // particle validation
-typedef bool (*ParticleFunction)(Particle*);
 base::Vector<std::pair<ParticleFunction, ParticleFunction> >
-particle_validators;
+    particle_validators;
 
 IMPKERNEL_END_INTERNAL_NAMESPACE
