@@ -13,15 +13,15 @@ class Tests(IMP.test.TestCase):
 
     def test_no_model(self):
         """Check access of attributes from python"""
-        m= IMP.Model()
-        p= IMP.Particle(m)
+        m= IMP.kernel.Model()
+        p= IMP.kernel.Particle(m)
         ik= IMP.IntKey("hi")
         m.add_attribute(ik, p.get_index(), 1)
         self.assertEqual(m.get_attribute(ik, p.get_index()), 1)
-        pisk= IMP.ParticleIndexesKey("hi")
+        pisk= IMP.kernel.ParticleIndexesKey("hi")
         m.add_attribute(pisk, p.get_index(), [p.get_index()])
         self.assertEqual(m.get_attribute(pisk, p.get_index()), [p.get_index()])
-        pik= IMP.ParticleIndexKey("hi")
+        pik= IMP.kernel.ParticleIndexKey("hi")
         m.add_attribute(pik, p.get_index(), p.get_index())
         self.assertEqual(m.get_attribute(pik, p.get_index()), p.get_index())
 if __name__ == '__main__':
