@@ -5,7 +5,7 @@ class Tests(IMP.test.TestCase):
     """Test RestraintSets"""
     def test_printing(self):
         """Test ref counting works with restraints and scoring functions"""
-        m = IMP.Model()
+        m = IMP.kernel.Model()
         # make sure that sf keeps the restraint alive
         sf =  IMP.kernel._ConstRestraint(m, [], 1).create_scoring_function()
         IMP.base.set_log_level(IMP.base.MEMORY)
