@@ -8,10 +8,10 @@ class Tests(IMP.test.TestCase):
 
     def test_no_model(self):
         """Check particle typemaps"""
-        m= IMP.Model("particle typemaps")
+        m= IMP.kernel.Model("particle typemaps")
         ps= []
         for i in range(0,10):
-            ps.append(IMP.Particle(m))
+            ps.append(IMP.kernel.Particle(m))
         num=IMP.kernel._take_particles(ps)
         self.assertEqual(num, len(ps))
         num=IMP.kernel._take_particles(m, ps)
@@ -30,10 +30,10 @@ class Tests(IMP.test.TestCase):
         rps= IMP.kernel._take_particles(di.values())
     def test_particles_temps(self):
         """Test passing of ParticlesTemp"""
-        m= IMP.Model("particle temps")
+        m= IMP.kernel.Model("particle temps")
         ps= []
         for i in range(0,10):
-            ps.append(IMP.Particle(m))
+            ps.append(IMP.kernel.Particle(m))
         inlist=[[ps[0], ps[2]],[ps[3], ps[4]]]
         outlist= IMP.kernel._pass_particles_temps(inlist)
         self.assertEqual(inlist, outlist)
@@ -53,43 +53,43 @@ class Tests(IMP.test.TestCase):
             self.assertAlmostEqual(va[i], vb[i], delta=.01)
     def _test_o(self):
         """Check overloaded"""
-        m= IMP.Model("overloaded")
+        m= IMP.kernel.Model("overloaded")
         ps= []
         for i in range(10):
-            ps.append(IMP.Particle(m))
+            ps.append(IMP.kernel.Particle(m))
         pso=self._pass(ps)
         self._equal_lists(ps, pso)
     def test_dec(self):
         """Check decorators"""
-        m= IMP.Model("decorators")
+        m= IMP.kernel.Model("decorators")
         ps= IMP.kernel._TrivialDecorators()
         for i in range(10):
-            ps.append(IMP.kernel._TrivialDecorator.setup_particle(IMP.Particle(m)))
+            ps.append(IMP.kernel._TrivialDecorator.setup_particle(IMP.kernel.Particle(m)))
         pso=IMP.kernel._pass_decorators(ps)
         self._equal_lists(ps, pso)
     def test_dect(self):
         """Check decorators traits"""
-        m= IMP.Model("traits decorator")
+        m= IMP.kernel.Model("traits decorator")
         ps= IMP.kernel._TrivialTraitsDecorators()
         tr= IMP.StringKey("ttd")
         for i in range(10):
-            ps.append(IMP.kernel._TrivialTraitsDecorator.setup_particle(IMP.Particle(m), tr))
+            ps.append(IMP.kernel._TrivialTraitsDecorator.setup_particle(IMP.kernel.Particle(m), tr))
         pso=IMP.kernel._pass_decorator_traits(ps)
         self._equal_lists(ps, pso)
 
     def test_pairs(self):
         """Check pairs"""
-        m= IMP.Model("pairs")
+        m= IMP.kernel.Model("pairs")
         ps= []
         for i in range(10):
-            pp = (IMP.Particle(m), IMP.Particle(m));
+            pp = (IMP.kernel.Particle(m), IMP.kernel.Particle(m));
         pso=IMP.kernel._pass_particle_pairs(ps)
         self._equal_lists(ps, pso)
     def test_index_pairs(self):
         """Check particle index pairs"""
         ps= []
         for i in range(10):
-            pp = (IMP.ParticleIndex(i), IMP.ParticleIndex(i+1));
+            pp = (IMP.kernel.ParticleIndex(i), IMP.kernel.ParticleIndex(i+1));
         pso=IMP.kernel._pass_particle_index_pairs(ps)
         self._equal_lists(ps, pso)
     def test_failure(self):
@@ -97,25 +97,25 @@ class Tests(IMP.test.TestCase):
         self.assertRaises(TypeError, IMP.kernel._pass_particle_pairs, [1])
     def test_dec_to_part(self):
         """Checking conversion of decorators to particles"""
-        m= IMP.Model("particle decorator conversion")
+        m= IMP.kernel.Model("particle decorator conversion")
         ps= IMP.kernel._TrivialDecorators()
         rps= []
         for i in range(10):
-            ps.append(IMP.kernel._TrivialDecorator.setup_particle(IMP.Particle(m)))
+            ps.append(IMP.kernel._TrivialDecorator.setup_particle(IMP.kernel.Particle(m)))
             rps.append(ps[-1].get_particle())
         pso=IMP.kernel._pass_particles(ps)
         self._equal_lists(rps, pso)
     def test_dec_to_part_2(self):
         """Checking conversion of decorator to particle"""
-        m= IMP.Model("decorator particle conversion")
-        d=IMP.kernel._TrivialDecorator.setup_particle(IMP.Particle(m))
+        m= IMP.kernel.Model("decorator particle conversion")
+        d=IMP.kernel._TrivialDecorator.setup_particle(IMP.kernel.Particle(m))
         pso=IMP.kernel._pass_particle(d)
         self.assertEqual(d.get_particle(), pso)
 
     def test_overload(self):
         """Checking that overloading works"""
-        m= IMP.Model("overloading")
-        p = IMP.Particle(m)
+        m= IMP.kernel.Model("overloading")
+        p = IMP.kernel.Particle(m)
         r = IMP.kernel._ConstRestraint(1)
         pi= IMP.kernel._test_overload([p])
         ri= IMP.kernel._test_overload([r])
@@ -123,9 +123,9 @@ class Tests(IMP.test.TestCase):
         self.assertEqual(ri, 1)
     def test_dec_conv(self):
         """Checking decorator conversions work"""
-        m= IMP.Model("decorator conversion")
-        p0= IMP.Particle(m)
-        p1= IMP.Particle(m)
+        m= IMP.kernel.Model("decorator conversion")
+        p0= IMP.kernel.Particle(m)
+        p1= IMP.kernel.Particle(m)
         print p0
         print p1
         d0= IMP.kernel._TrivialDecorator.setup_particle(p0)
@@ -142,9 +142,9 @@ class Tests(IMP.test.TestCase):
         self.assertEqual(pso[1], d1p)
     def test_tuple_conv(self):
         """Checking tuple conversions work"""
-        m= IMP.Model("tuple conversion")
-        p0= IMP.Particle(m)
-        p1= IMP.Particle(m)
+        m= IMP.kernel.Model("tuple conversion")
+        p0= IMP.kernel.Particle(m)
+        p1= IMP.kernel.Particle(m)
         pp= (p0, p1)
         ppo= IMP.kernel._pass_particle_pair(pp)
         print [x.get_name() for x in pp]
@@ -153,16 +153,16 @@ class Tests(IMP.test.TestCase):
         self.assertEqual(ppo[1], pp[1])
     def test_overload_dec(self):
         """Check overloaded functions with decorators"""
-        m= IMP.Model("overloaded decorators")
-        d0= IMP.kernel._TrivialDecorator.setup_particle(IMP.Particle(m))
-        d1= IMP.kernel._TrivialDerivedDecorator.setup_particle(IMP.Particle(m))
+        m= IMP.kernel.Model("overloaded decorators")
+        d0= IMP.kernel._TrivialDecorator.setup_particle(IMP.kernel.Particle(m))
+        d1= IMP.kernel._TrivialDerivedDecorator.setup_particle(IMP.kernel.Particle(m))
         self.assertEqual(IMP.kernel._overloaded_decorator(d1), 1)
         self.assertEqual(IMP.kernel._overloaded_decorator(d0), 0)
 
 
-    class _TestRestraint(IMP.Restraint):
+    class _TestRestraint(IMP.kernel.Restraint):
         def __init__(self, ps):
-            IMP.Restraint.__init__(self, ps[0].get_model())
+            IMP.kernel.Restraint.__init__(self, ps[0].get_model(), "TestRestraint %1%")
             self.ps=ps
         def do_show(self, fh):
             fh.write("Test Particle")
@@ -170,30 +170,28 @@ class Tests(IMP.test.TestCase):
             return 0
         def get_version_info(self):
             return IMP.VersionInfo()
-        def get_input_particles(self):
+        def do_get_inputs(self):
             return [self.ps[0], self.ps[1]]
-        def get_input_containers(self):
-            return []
         def get_interacting_particles(self):
             return [[self.ps[0], self.ps[1]]]
     def test_dir_tms_0(self):
         """Test director methods in restraint"""
-        m= IMP.Model("directors in restraints")
-        p0= IMP.Particle(m)
-        p1= IMP.Particle(m)
+        m= IMP.kernel.Model("directors in restraints")
+        p0= IMP.kernel.Particle(m)
+        p1= IMP.kernel.Particle(m)
         r= self._TestRestraint([p0, p1])
         m.add_restraint(r)
         m.evaluate(False)
         r.evaluate(False)
     def test_dir_tms(self):
         """Test that decorator particle methods can be called"""
-        m= IMP.Model("decorator particle methos")
-        p0= IMP.Particle(m)
+        m= IMP.kernel.Model("decorator particle methos")
+        p0= IMP.kernel.Particle(m)
         d= IMP.kernel._TrivialDecorator.setup_particle(p0)
         d.add_attribute(IMP.IntKey("Hi"), 1)
     def test_cast(self):
         """Test that casting objects works"""
-        m=IMP.Model("object cast")
+        m=IMP.kernel.Model("object cast")
         r= IMP.kernel._ConstRestraint(1)
         m.add_restraint(r)
         rb= m.get_restraints()[0]
@@ -202,14 +200,14 @@ class Tests(IMP.test.TestCase):
         print rc.get_value()
     def test_model_objects(self):
         """Test that model objects can get passed from python"""
-        m= IMP.Model("model objets")
+        m= IMP.kernel.Model("model objets")
         r= IMP.kernel._ConstRestraint(1)
-        p= IMP.Particle(m)
+        p= IMP.kernel.Particle(m)
         self.assertEqual([p],IMP.kernel._pass_model_objects([p]))
         self.assertEqual([r,p],IMP.kernel._pass_model_objects([r, p]))
     def test_restraint_cast(self):
         """Test that restraints can be cast"""
-        m= IMP.Model("model objets")
+        m= IMP.kernel.Model("model objets")
         r= IMP.kernel._ConstRestraint(1)
         m.add_restraint(r)
         rb= m.get_restraints()[0]
@@ -255,16 +253,19 @@ class Tests(IMP.test.TestCase):
                     'set_model',
                     'get_inputs',
                     'get_outputs',
-                    'do_get_inputs',
-                    'do_get_outputs',
                     'get_interactions',
-                    'do_get_interactions',
-                    'update_dependencies'
+                    'get_required_score_states',
+                    'update_dependencies',
+                    'get_has_dependencies',
+                    'set_has_dependencies',
+                    'get_has_required_score_states',
+                    'handle_set_has_required_score_states',
+                    'set_has_required_score_states',
                     ]
         md= dir(IMP.kernel._TrivialDecorator)
         missing=[]
-        for m in dir(IMP.Particle):
-            if not m in md and m not in exclusions and not m.startswith("_"):
+        for m in dir(IMP.kernel.Particle):
+            if not m in md and m not in exclusions and not m.startswith("_") and not m.startswith("do_"):
                 print m
                 missing.append(m)
         self.assertEqual(len(missing),0,
