@@ -9,11 +9,9 @@
 
 IMPMISC_BEGIN_NAMESPACE
 
-void CustomXYZR::show(std::ostream &out) const
-{
-  out << "(" << get_x()<< ", "
-      << get_y() << ", " << get_z() << ": " << get_radius() << ")";
-
+void CustomXYZR::show(std::ostream &out) const {
+  out << "(" << get_x() << ", " << get_y() << ", " << get_z() << ": "
+      << get_radius() << ")";
 }
 
 IMPMISC_END_NAMESPACE
