@@ -1,6 +1,6 @@
 /**
  *  \file MultipleBinormalRestraint.h
- *  \brief Modeller-style multiple binormal (phi/psi) restraint.
+ *  \brief kernel::Modeller-style multiple binormal (phi/psi) restraint.
  *
  *  Copyright 2007-2013 IMP Inventors. All rights reserved.
  *
@@ -11,26 +11,26 @@
 
 #include <IMP/modeller/modeller_config.h>
 
-#include <IMP/Restraint.h>
-#include <IMP/Particle.h>
-#include <IMP/ParticleTuple.h>
+#include <IMP/kernel/Restraint.h>
+#include <IMP/kernel/Particle.h>
+#include <IMP/kernel/ParticleTuple.h>
 #include <IMP/generic.h>
 
 IMPMODELLER_BEGIN_NAMESPACE
 
 class BinormalTerm;
 
-//! Modeller-style multiple binormal (phi/psi) restraint.
+//! kernel::Modeller-style multiple binormal (phi/psi) restraint.
 /** This implements a multiple binormal restraint on the two dihedral angles
-    between the two quads of Particles passed to the restraint, by implementing
+    between the two quads of kernel::Particles passed to the restraint, by implementing
     equation A.76 in the
-    \external{http://salilab.org/modeller/9v7/manual/node441.html, Modeller manual}.
+    \external{http://salilab.org/modeller/9v7/manual/node441.html, kernel::Modeller manual}.
     The two angles are typically the phi and psi dihedrals of a residue.
  */
-class IMPMODELLEREXPORT MultipleBinormalRestraint : public Restraint
+class IMPMODELLEREXPORT MultipleBinormalRestraint : public kernel::Restraint
 {
   std::vector<BinormalTerm> terms_;
-  ParticleQuad q1_, q2_;
+  kernel::ParticleQuad q1_, q2_;
 public:
   //! Create the multiple binormal restraint.
   /** After creating the restraint, call add_term one or more times to add
@@ -38,14 +38,18 @@ public:
       \param[in] q1 First quad of particles.
       \param[in] q2 Second quad of particles.
    */
-  MultipleBinormalRestraint(const ParticleQuad &q1, const ParticleQuad &q2);
+  MultipleBinormalRestraint(const kernel::ParticleQuad &q1, const kernel::ParticleQuad &q2);
 
   //! Add a single BinormalTerm to the restraint.
   void add_term(const BinormalTerm &term) {
     terms_.push_back(term);
   }
 
-  IMP_RESTRAINT(MultipleBinormalRestraint);
+  virtual double
+  unprotected_evaluate(IMP::kernel::DerivativeAccumulator *accum)
+     const IMP_OVERRIDE;
+  virtual IMP::kernel::ModelObjectsTemp do_get_inputs() const IMP_OVERRIDE;
+  IMP_OBJECT_METHODS(MultipleBinormalRestraint);
 };
 
 //! A single binormal term in a MultipleBinormalRestraint.
