@@ -1,6 +1,6 @@
 /**
  *  \file MultipleBinormalRestraint.cpp
- *  \brief Modeller-style multiple binormal (phi/psi) restraint.
+ *  \brief kernel::Modeller-style multiple binormal (phi/psi) restraint.
  *
  *  Copyright 2007-2013 IMP Inventors. All rights reserved.
  *
@@ -44,8 +44,10 @@ double BinormalTerm::evaluate(const double dihedral[2], double &sin1,
 }
 
 MultipleBinormalRestraint::MultipleBinormalRestraint(
-    const ParticleQuad &q1, const ParticleQuad &q2) : terms_(), q1_(q1),
-                                                      q2_(q2)
+    const kernel::ParticleQuad &q1, const kernel::ParticleQuad &q2) :
+    kernel::Restraint(q1[0]->get_model(), "MultipleBinormalRestraint%1%"),
+    terms_(), q1_(q1),
+    q2_(q2)
 {
 }
 
@@ -109,25 +111,11 @@ double MultipleBinormalRestraint::unprotected_evaluate(
   return -RT * std::log(all_terms);
 }
 
-ParticlesTemp MultipleBinormalRestraint::get_input_particles() const {
-  ParticlesTemp r(8);
+ModelObjectsTemp MultipleBinormalRestraint::do_get_inputs() const {
+  kernel::ModelObjectsTemp r(8);
   r[0] = q1_[0]; r[1] = q1_[1]; r[2] = q1_[2]; r[3] = q1_[3];
   r[4] = q2_[0]; r[5] = q2_[1]; r[6] = q2_[2]; r[7] = q2_[3];
   return r;
 }
 
-
-ContainersTemp MultipleBinormalRestraint::get_input_containers() const {
-  return ContainersTemp();
-}
-
-void MultipleBinormalRestraint::do_show(std::ostream& out) const
-{
-  out << "particle quads: ";
-  q1_.show();
-  out << " and ";
-  q2_.show();
-  out << std::endl;
-}
-
 IMPMODELLER_END_NAMESPACE
