@@ -11,7 +11,7 @@
 
 #include <IMP/algebra/Transformation3D.h>
 #include <IMP/domino/DominoSampler.h>
-#include <IMP/Model.h>
+#include <IMP/kernel/Model.h>
 #include <IMP/core/Hierarchy.h>
 #include <IMP/file.h>
 #include <IMP/multifit/multifit_config.h>
@@ -68,6 +68,7 @@ public:
 
 IMP_VALUES(ProteinRecordData, ProteinRecordDataList);
 
+//! Storage of proteomics data.
 class IMPMULTIFITEXPORT ProteomicsData : public base::Object {
  protected:
  public:
@@ -188,7 +189,8 @@ class IMPMULTIFITEXPORT ProteomicsData : public base::Object {
     IMP_USAGE_CHECK(protein_ind<(int)prot_data_.size(),"index out of range\n");
     return prot_data_[protein_ind];}
 
-  IMP_OBJECT_INLINE(ProteomicsData, {
+  IMP_OBJECT_METHODS(ProteomicsData);
+  /*IMP_OBJECT_INLINE(ProteomicsData, {
     out<<"Proteins:";
     for(std::vector<ProteinRecordData>::const_iterator
           it = prot_data_.begin(); it != prot_data_.end();it++){
@@ -203,7 +205,7 @@ class IMPMULTIFITEXPORT ProteomicsData : public base::Object {
         out<<prot_data_[*it1].name_<<",";
       }
       out<<std::endl;
-    } }, {});
+      } }, {});*/
   int get_num_allowed_violated_interactions() const {
     return num_allowed_violated_interactions_;}
   void set_num_allowed_violated_interactions(int n) {
