@@ -13,7 +13,7 @@ IMPMULTIFIT_BEGIN_NAMESPACE
 unsigned int FittingStates::get_number_of_particle_states() const {
   return states_.size();
 }
-void FittingStates::load_particle_state(unsigned int i, Particle *p) const {
+void FittingStates::load_particle_state(unsigned int i, kernel::Particle *p) const {
   IMP_USAGE_CHECK(i < states_.size(), "Out of range " << i);
   core::RigidBody(p).set_reference_frame(states_[i]);
   p->set_value(fit_state_key_,i);
