@@ -74,7 +74,7 @@ EulerAnglesList get_uniformly_sampled_rotations(
 
 void convolve_kernel_inside_erode (em::DensityMap *dmap,
                                    double *kernel, unsigned kernel_size) {
-  Pointer<em::DensityMap> copy_map=em::create_density_map(dmap);
+  base::Pointer<em::DensityMap> copy_map=em::create_density_map(dmap);
   copy_map->set_was_used(true);
   int nx=dmap->get_header()->get_nx();
   int ny=dmap->get_header()->get_ny();
@@ -159,7 +159,7 @@ void relax_laplacian (em::DensityMap *dmap,
   norm /= (double)threscount;// average density for thresholded volume
   norm *= maskcount;
   // iterate on original lattice, no focusing
-  Pointer<em::DensityMap> copy_map=em::create_density_map(dmap);
+  base::Pointer<em::DensityMap> copy_map=em::create_density_map(dmap);
   copy_map->set_was_used(true);
   double diff;
   em::emreal *copy_data=copy_map->get_data();
