@@ -1,10 +1,9 @@
-import unittest
 import IMP
 import IMP.test
 import IMP.restrainer
 import IMP.display
 
-class RestraintTest(IMP.test.TestCase):
+class Tests(IMP.test.TestCase):
     def setUp(self):
         IMP.test.TestCase.setUp(self)
 
@@ -14,7 +13,7 @@ class RestraintTest(IMP.test.TestCase):
         self.representation = RepParser.run()
         self.display = DisplayParser.run()
 
-        self.Model = self.representation.to_model()
+        self.Model = self.representation.get_model()
 
         self.log = self.display.create_log(self.representation, 'pdb_log_%03d.py')
         self.log.write('initial_display_in_chimera.py')
@@ -26,4 +25,4 @@ class RestraintTest(IMP.test.TestCase):
         self.Model.evaluate(False)
 
 if __name__ == '__main__':
-    unittest.main()
+    IMP.test.main()
