@@ -1,11 +1,10 @@
-import unittest
 import IMP
 import IMP.test
 import IMP.restrainer
 
-class RestraintTest(IMP.test.TestCase):
+class Tests(IMP.test.TestCase):
     def setUp(self):
-        IMP.set_log_level(IMP.VERBOSE)
+        IMP.base.set_log_level(IMP.base.VERBOSE)
         IMP.test.TestCase.setUp(self)
 
         RepParser = IMP.restrainer.XMLRepresentation(self.get_input_file_name('sphere_representation.xml'))
@@ -13,7 +12,7 @@ class RestraintTest(IMP.test.TestCase):
         self.representation = RepParser.run()
         self.restraint = RestraintParser.run()
 
-        self.Model = self.representation.to_model()
+        self.Model = self.representation.get_model()
         self.restraint.add_to_representation(self.representation)
 
 
@@ -24,4 +23,4 @@ class RestraintTest(IMP.test.TestCase):
         self.Model.evaluate(False)
 
 if __name__ == '__main__':
-    unittest.main()
+    IMP.test.main()
