@@ -8,12 +8,12 @@ class Tests(IMP.test.TestCase):
     def test_navigation(self):
         """Test loading and saving of rigid bodies"""
         for suffix in RMF.suffixes:
-            m= IMP.Model()
-            r= IMP.atom.Hierarchy.setup_particle(IMP.Particle(m))
+            m= IMP.kernel.Model()
+            r= IMP.atom.Hierarchy.setup_particle(IMP.kernel.Particle(m))
             r.set_name("rb")
             rbd= IMP.core.RigidBody.setup_particle(r, IMP.algebra.ReferenceFrame3D())
             for i in range(0,3):
-                p = IMP.Particle(m)
+                p = IMP.kernel.Particle(m)
                 v= IMP.algebra.Vector3D(0,0,0)
                 v[i]=1
                 d=IMP.core.XYZR.setup_particle(p)
@@ -22,6 +22,16 @@ class Tests(IMP.test.TestCase):
                 IMP.atom.Mass.setup_particle(p, .1)
                 r.add_child(IMP.atom.Hierarchy.setup_particle(p))
                 rbd.add_member(p)
+            for i in range(0,2):
+                p = IMP.kernel.Particle(m)
+                v= IMP.algebra.Vector3D(0,0,0)
+                v[i]=1
+                d=IMP.core.XYZR.setup_particle(p)
+                d.set_coordinates(v)
+                d.set_radius(.5)
+                IMP.atom.Mass.setup_particle(p, .1)
+                r.add_child(IMP.atom.Hierarchy.setup_particle(p))
+                rbd.add_non_rigid_member(p.get_index())
             fn= self.get_tmp_file_name("rigid."+suffix)
             f= RMF.create_rmf_file(fn)
             IMP.rmf.add_hierarchies(f, [r])
@@ -49,8 +59,12 @@ class Tests(IMP.test.TestCase):
                     nc= IMP.core.XYZ(c).get_coordinates()
                     self.assertAlmostEqual((oc-nc).get_magnitude(), 0,
                                            delta=.1)
-                    ic= IMP.core.RigidMember(c).get_internal_coordinates()
-                    self.assertAlmostEqual(ic[j], 1, delta=.01)
+                    if IMP.core.RigidMember.get_is_setup(c):
+                        ic= IMP.core.RigidMember(c).get_internal_coordinates()
+                        self.assertAlmostEqual(ic[j%3], 1, delta=.01)
+                    else:
+                        ic= IMP.core.NonRigidMember(c).get_internal_coordinates()
+                        self.assertAlmostEqual(ic[j%3], 1, delta=.01)
 
 if __name__ == '__main__':
     unittest.main()
