@@ -11,7 +11,7 @@
 
 #include <IMP/saxs/saxs_config.h>
 
-#include <IMP/Particle.h>
+#include <IMP/kernel/Particle.h>
 #include <IMP/base_types.h>
 #include <IMP/atom/Residue.h>
 #include <IMP/atom/Atom.h>
@@ -53,14 +53,14 @@ public:
   // 1. Zero form factors
 
   //! get f(0), ie q=0 for real space profile calculation
-  Float get_form_factor(Particle* p, FormFactorType ff_type=HEAVY_ATOMS) const;
+  Float get_form_factor(kernel::Particle* p, FormFactorType ff_type=HEAVY_ATOMS) const;
 
   //! f(0) in vacuum
-  Float get_vacuum_form_factor(Particle* p,
+  Float get_vacuum_form_factor(kernel::Particle* p,
                                FormFactorType ff_type=HEAVY_ATOMS) const;
 
   //! f(0) for solvent
-  Float get_dummy_form_factor(Particle* p,
+  Float get_dummy_form_factor(kernel::Particle* p,
                               FormFactorType ff_type=HEAVY_ATOMS) const;
 
   //! f(0) for water
@@ -79,15 +79,15 @@ public:
   // 2. Full form factors
 
   //! full form factor for reciprocal space profile calculation
-  const Floats& get_form_factors(Particle* p,
+  const Floats& get_form_factors(kernel::Particle* p,
                                  FormFactorType ff_type = HEAVY_ATOMS) const;
 
   //! for reciprocal space profile calculation
-  const Floats& get_vacuum_form_factors(Particle* p,
+  const Floats& get_vacuum_form_factors(kernel::Particle* p,
                                  FormFactorType ff_type = HEAVY_ATOMS) const;
 
   //! for reciprocal space profile calculation
-  const Floats& get_dummy_form_factors(Particle* p,
+  const Floats& get_dummy_form_factors(kernel::Particle* p,
                                  FormFactorType ff_type = HEAVY_ATOMS) const;
 
   //! full water form factor
@@ -104,10 +104,10 @@ public:
   }
 
   //! radius
-  Float get_radius(Particle* p, FormFactorType ff_type=HEAVY_ATOMS) const;
+  Float get_radius(kernel::Particle* p, FormFactorType ff_type=HEAVY_ATOMS) const;
 
   //! volume
-  Float get_volume(Particle* p, FormFactorType ff_type=HEAVY_ATOMS) const;
+  Float get_volume(kernel::Particle* p, FormFactorType ff_type=HEAVY_ATOMS) const;
 
   //! print tables
   void show(std::ostream &out=std::cout, std::string prefix="") const;
@@ -148,7 +148,7 @@ private:
   // those represent excluded volume
   static Float dummy_zero_form_factors_[];
 
-  // a key for storing zero form factor in Particle as attribute
+  // a key for storing zero form factor in kernel::Particle as attribute
   static IntKey form_factor_type_key_;
 
   // class for storing form factors solvation table
@@ -188,7 +188,7 @@ private:
 
   FormFactorAtomType get_form_factor_atom_type(atom::Element e) const;
 
-  FormFactorAtomType get_form_factor_atom_type(Particle* p,
+  FormFactorAtomType get_form_factor_atom_type(kernel::Particle* p,
                                                FormFactorType ff_type) const;
 
   FormFactorAtomType get_carbon_atom_type(const atom::AtomType& atom_type,
@@ -219,9 +219,10 @@ private:
   // min/max q and sampling resolution for form factor computation
   Float min_q_, max_q_, delta_q_;
 
-  WarningContext warn_context_;
+  base::WarningContext warn_context_;
 };
 
+/** Get the default table.*/
 IMPSAXSEXPORT FormFactorTable* default_form_factor_table();
 
 IMPSAXS_END_NAMESPACE
