@@ -10,6 +10,9 @@
 #define IMPSAXS_PROFILE_H
 
 #include <IMP/saxs/saxs_config.h>
+#include <IMP/base/Object.h>
+#include <IMP/base/warning_macros.h>
+
 #include "FormFactorTable.h"
 #include "Distribution.h"
 
@@ -22,38 +25,25 @@ class RadialDistributionFunction;
 
 /**
    Basic profile class, can be initialized from the input file
-   (experimental or theoretical) or computed from a set of Model
-   Particles (theoretical)
+   (experimental or theoretical) or computed from a set of kernel::Model
+   kernel::Particles (theoretical)
 */
-class IMPSAXSEXPORT Profile {
+class IMPSAXSEXPORT Profile : public base::Object {
 public:
+  // Constructors
+
   //! init from file
-  Profile(const String& file_name);
+  Profile(const String& file_name, bool fit_file = false);
 
   //! init for theoretical profile
   Profile(Float qmin = 0.0, Float qmax = 0.5, Float delta = 0.005);
 
-private:
-  class IntensityEntry {
-  public:
-    IntensityEntry() : q_(0.0), intensity_(0.0), error_(1.0), weight_(1.0) {}
-    IntensityEntry(Float q) : q_(q),intensity_(0.0),error_(1.0),weight_(1.0) {}
-    IntensityEntry(Float q, Float intensity, Float error)
-      : q_(q), intensity_(intensity), error_(error), weight_(1.0) {}
+  IMP_OBJECT_METHODS(Profile);
 
-    Float q_;
-    Float intensity_;
-    Float error_;
-    Float weight_;
-  };
+  // Various ways to compute a profile
 
-  friend std::ostream& operator<<(std::ostream& q, const IntensityEntry& e);
-
-  friend std::istream& operator>>(std::istream& q, IntensityEntry& e);
-
-public:
   //! computes theoretical profile
-  void calculate_profile(const Particles& particles,
+  void calculate_profile(const kernel::Particles& particles,
                          FormFactorType ff_type = HEAVY_ATOMS,
                          bool reciprocal=false,
                          bool variance=false,
@@ -66,25 +56,31 @@ public:
   }
 
   //! compute profile for fitting with hydration layer and excluded volume
-  void calculate_profile_partial(const Particles& particles,
+  /**
+    A partial profile is a pre-computed profile, where intensities are
+    split into 6 parts that can be summed up into a regular profile
+    given a pair of c1/c2 values by sum_partial_profiles function.
+    see FoXS paper for details.
+  */
+  void calculate_profile_partial(const kernel::Particles& particles,
                                  const Floats& surface = Floats(),
                                  FormFactorType ff_type = HEAVY_ATOMS);
 
   //! compute profile for fitting with hydration layer and excluded volume
-  void calculate_profile_partial(const Particles& particles1,
-                                 const Particles& particles2,
+  void calculate_profile_partial(const kernel::Particles& particles1,
+                                 const kernel::Particles& particles2,
                                  const Floats& surface1 = Floats(),
                                  const Floats& surface2 = Floats(),
                                  FormFactorType ff_type = HEAVY_ATOMS);
 
-  void calculate_profile_reciprocal_partial(const Particles& particles,
+  void calculate_profile_reciprocal_partial(const kernel::Particles& particles,
                                             const Floats& surface = Floats(),
                                           FormFactorType ff_type = HEAVY_ATOMS);
 
   //! computes theoretical profile contribution from iter-molecular
   //! interactions between the particles
-  void calculate_profile(const Particles& particles1,
-                         const Particles& particles2,
+  void calculate_profile(const kernel::Particles& particles1,
+                         const kernel::Particles& particles2,
                          FormFactorType ff_type = HEAVY_ATOMS,
                          bool variance=false,
                          double variance_tau=0.1) {
@@ -93,17 +89,17 @@ public:
   }
 
   //! calculate Intensity at zero (= squared number of electrons)
-  Float calculate_I0(const Particles& particles,
+  Float calculate_I0(const kernel::Particles& particles,
                      FormFactorType ff_type = HEAVY_ATOMS);
 
-  //! calculate profile for any type of Particles that have coordinates
-  void calculate_profile_constant_form_factor(const Particles& particles,
+  //! calculate profile for any type of kernel::Particles that have coordinates
+  void calculate_profile_constant_form_factor(const kernel::Particles& particles,
                                               Float form_factor = 1.0);
 
   // computes theoretical profile faster for cyclically symmetric particles
   // assumes that the units particles are ordered one after another in the
   // input particles vector (n - symmetry order)
-  void calculate_profile_symmetric(const Particles& particles, unsigned int n,
+  void calculate_profile_symmetric(const kernel::Particles& particles, unsigned int n,
                                    FormFactorType ff_type = HEAVY_ATOMS);
 
   //! convert to real space P(r) function P(r) = 1/2PI^2 Sum(I(q)*qr*sin(qr))
@@ -113,23 +109,32 @@ public:
   //! convert to reciprocal space I(q) = Sum(P(r)*sin(qr)/qr)
   void distribution_2_profile(const RadialDistributionFunction& r_dist);
 
-  //! add another profile - useful for rigid bodies
-  void add(const Profile& other_profile, Float weight = 1.0);
 
-  //! add partial profiles
-  void add_partial_profiles(const Profile& other_profile, Float weight = 1.0);
+  //! return a profile that is sampled on the q values of the exp_profile
+  void resample(const Profile* exp_profile,
+                Profile* resampled_profile,
+                bool partial_profiles=false) const;
 
-  //! background adjustment option
-  void background_adjust(double start_q);
 
-  //! scale
-  void scale(Float c);
+  //! downsample the profile to a given number of points
+  void downsample(Profile* downsampled_profile,unsigned int point_number) const;
 
-  //! offset profile by c, I(q) = I(q) - c
-  void offset(Float c);
+  //! compute radius of gyration with Guinier approximation
+  /** ln[I(q)]=ln[I(0)] - (q^2*rg^2)/3
+     \param[in] end_q_rg determines the range of profile used for approximation:
+      i.e. q*rg < end_q_rg. Use 1.3 for globular proteins, 0.8 for elongated
+  */
+  double radius_of_gyration(double end_q_rg = 1.3) const;
+
+
+  // IO functions
 
   //! reads SAXS profile from file
-  void read_SAXS_file(const String& file_name);
+  /**
+     \param[in] file_name profile file name
+     \param[in] fit_file if true, intensities are read from column 3
+   */
+  void read_SAXS_file(const String& file_name, bool fit_file = false);
 
   //! print to file
   /** \param[in] file_name output file name
@@ -137,13 +142,14 @@ public:
   */
   void write_SAXS_file(const String& file_name, Float max_q=0.0) const;
 
+  //! read a partial profile from file (7 columns)
+  void read_partial_profiles(const String& file_name);
+
+  //! write a partial profile to file
   void write_partial_profiles(const String& file_name) const;
 
-  // compute radius of gyration with Guinier approximation
-  // ln[I(q)]=ln[I(0)] - (q^2*rg^2)/3
-  // end_q_rg determines the range of profile used for approximation:
-  // i.e. q*rg < end_q_rg. Use 1.3 for globular proteins, 0.8 for elongated
-  double radius_of_gyration(double end_q_rg = 1.3) const;
+
+  // Access functions
 
   //! return sampling resolution
   Float get_delta_q() const { return delta_q_; }
@@ -154,21 +160,28 @@ public:
   //! return maximal sampling point
   Float get_max_q() const { return max_q_; }
 
-  //! return number of entries in SAXS profile
-  unsigned int size() const { return profile_.size(); }
-
-  // Profile access functions
-  Float get_intensity(unsigned int i) const { return profile_[i].intensity_; }
-  Float get_q(unsigned int i) const { return profile_[i].q_; }
-  Float get_error(unsigned int i) const { return profile_[i].error_; }
-  Float get_weight(unsigned int i) const { return profile_[i].weight_; }
+  Float get_intensity(unsigned int i) const { return intensity_[i]; }
+  Float get_q(unsigned int i) const { return q_[i]; }
+  Float get_error(unsigned int i) const { return error_[i]; }
+  Float get_weight(unsigned int i) const { IMP_UNUSED(i); return 1.0; }
   Float get_variance(unsigned int i, unsigned int j) const
   { unsigned a=std::min(i,j); unsigned b=std::max(i,j);
       return variances_[a][b-a]; }
-
   Float get_average_radius() const { return average_radius_; }
 
-  void set_intensity(unsigned int i, Float iq) { profile_[i].intensity_ = iq; }
+  //! return number of entries in SAXS profile
+  unsigned int size() const { return q_.size(); }
+
+  //! checks the sampling of experimental profile
+  bool is_uniform_sampling() const;
+
+  std::string get_name() const { return name_; }
+
+  unsigned int get_id() const { return id_; }
+
+  // Modifiers
+
+  void set_intensity(unsigned int i, Float iq) { intensity_[i] = iq; }
 
   //! required for reciprocal space calculation
   void set_ff_table(FormFactorTable* ff_table) { ff_table_ = ff_table; }
@@ -177,13 +190,16 @@ public:
 
   void set_average_volume(Float v) { average_volume_ = v; }
 
-  //! add intensity entry to profile
-  void add_entry(Float q, Float intensity, Float error=1.0) {
-    profile_.push_back(IntensityEntry(q, intensity, error));
-  }
+  void set_name(std::string name) { name_ = name; }
 
-  //! checks the sampling of experimental profile
-  bool is_uniform_sampling() const;
+  void set_id(unsigned int id) { id_ = id; }
+
+  //! add intensity entry to profile
+  void add_entry(Float q, Float intensity, Float error = 1.0) {
+    q_.push_back(q);
+    intensity_.push_back(intensity);
+    error_.push_back(error);
+  }
 
   //! add simulated error
   void add_errors();
@@ -192,7 +208,33 @@ public:
   void add_noise(Float percentage = 0.03);
 
   //! computes full profile for given fitting parameters
-  void sum_partial_profiles(Float c1, Float c2, Profile& out_profile);
+  void sum_partial_profiles(Float c1, Float c2);
+
+  //! add another profile - useful for rigid bodies
+  void add(const Profile* other_profile, Float weight = 1.0);
+
+  //! add partial profiles
+  void add_partial_profiles(const Profile* other_profile, Float weight = 1.0);
+
+  //! add other profiles - useful for weighted ensembles
+  void add(const std::vector<Profile*>& profiles,
+           const std::vector<Float>& weights = std::vector<Float>());
+
+  //! add other partial profiles
+  void add_partial_profiles(const std::vector<Profile*>& profiles,
+                     const std::vector<Float>& weights = std::vector<Float>());
+
+  //! background adjustment option
+  void background_adjust(double start_q);
+
+  //! scale
+  void scale(Float c);
+
+  //! offset profile by c, I(q) = I(q) - c
+  void offset(Float c);
+
+  // copy error bars from the matching experimental profile
+  void copy_errors(const Profile* exp_profile);
 
   // parameter for E^2(q), used in faster calculation
   static const Float modulation_function_parameter_;
@@ -200,27 +242,29 @@ public:
  private:
   void init(bool variance = false);
 
-  void calculate_profile_reciprocal(const Particles& particles,
+  void calculate_profile_reciprocal(const kernel::Particles& particles,
                                     FormFactorType ff_type = HEAVY_ATOMS);
 
-  void calculate_profile_reciprocal(const Particles& particles1,
-                                    const Particles& particles2,
+  void calculate_profile_reciprocal(const kernel::Particles& particles1,
+                                    const kernel::Particles& particles2,
                                     FormFactorType ff_type = HEAVY_ATOMS);
 
-  void calculate_profile_real(const Particles& particles,
+  void calculate_profile_real(const kernel::Particles& particles,
                               FormFactorType ff_type = HEAVY_ATOMS,
                               bool variance = false,
                               double variance_tau = 0.1);
 
-  void calculate_profile_real(const Particles& particles1,
-                              const Particles& particles2,
+  void calculate_profile_real(const kernel::Particles& particles1,
+                              const kernel::Particles& particles2,
                               FormFactorType ff_type = HEAVY_ATOMS,
                               bool variance = false,
                               double variance_tau = 0.1);
 
+  void squared_distribution_2_profile(const RadialDistributionFunction& r_dist);
+
   void squared_distribution_2_profile(const RadialDistributionFunction& r_dist,
-          const RadialDistributionFunction& r_dist2,
-          bool variance=false, double variance_tau=0.1);
+                                      const RadialDistributionFunction& r_dist2,
+                                      double variance_tau=0.1);
 
   void squared_distributions_2_partial_profiles(
                          const std::vector<RadialDistributionFunction>& r_dist);
@@ -228,17 +272,32 @@ public:
   double radius_of_gyration_fixed_q(double end_q) const;
 
  protected:
-  std::vector<IntensityEntry> profile_; // the profile
-  std::vector<std::vector<double> > variances_; //profile variances
+  std::vector<double> q_; // q sampling points
+  std::vector<double> intensity_;
+  std::vector<double> error_; // error bar of each point
+
   Float min_q_, max_q_; // minimal and maximal s values  in the profile
   Float delta_q_; // profile sampling resolution
   FormFactorTable* ff_table_; // pointer to form factors table
-  std::vector<Profile> partial_profiles_;
+
+  std::vector<std::vector<double> > variances_; //profile variances
+
+  // stores the intensity split into 6 for c1/c2 enumeration
+  std::vector<std::vector<double> > partial_profiles_;
+
   bool experimental_; // experimental profile read from file
   Float average_radius_; // average radius of the particles
   Float average_volume_; // average volume
+
+  // mapping from q values to vector index for fast profile resampling
+  std::map<float, unsigned int> q_mapping_;
+
+  std::string name_; // file name
+  unsigned int id_;  // identifier
 };
 
+IMP_OBJECTS(Profile, Profiles);
+
 IMPSAXS_END_NAMESPACE
 
 #endif /* IMPSAXS_PROFILE_H */
