@@ -1,12 +1,13 @@
 /**
  * \file SolventAccessibleSurface \brief
  *
- * Copyright 2007-2010 IMP Inventors. All rights reserved.
+ * Copyright 2007-2013 IMP Inventors. All rights reserved.
  *
  */
 
 #include <IMP/saxs/SolventAccessibleSurface.h>
-#include <IMP/algebra/Grid3D.h>
+#include <IMP/constants.h>
+#include <IMP/algebra/standard_grids.h>
 
 IMPSAXS_BEGIN_NAMESPACE
 
@@ -16,7 +17,7 @@ IMP::Floats SolventAccessibleSurface::get_solvent_accessibility(
                                           float density)
 {
   IMP::Floats res;
-  std::vector<algebra::Vector3D> coordinates(ps.size());
+  algebra::Vector3Ds coordinates(ps.size());
   IMP::Floats radii(ps.size());
   for(unsigned int i=0; i<ps.size(); i++) {
     coordinates[i] = ps[i].get_coordinates();
@@ -24,11 +25,11 @@ IMP::Floats SolventAccessibleSurface::get_solvent_accessibility(
   }
 
   // init grid
-  typedef IMP::algebra::Grid3D<IMP::Ints> Grid;
+  typedef IMP::algebra::DenseGrid3D<IMP::Ints> Grid;
   IMP::algebra::BoundingBox3D bb(coordinates);
   Grid grid(2.0, bb);
   for(unsigned int i=0; i<coordinates.size(); i++) {
-    Grid::Index grid_index = grid.get_index(coordinates[i]);
+    Grid::Index grid_index = grid.get_nearest_index(coordinates[i]);
     grid[grid_index].push_back(i);
   }
 
