@@ -11,7 +11,7 @@ class Tests(IMP.test.TestCase):
 
     def test_saxs_profile(self):
         """Check protein profile computation"""
-        m = IMP.Model()
+        m = IMP.kernel.Model()
 
         #! read PDB
         mp= IMP.atom.read_pdb(self.get_input_file_name('6lyz.pdb'), m,
@@ -81,7 +81,7 @@ class Tests(IMP.test.TestCase):
 
     def test_saxs_restraint(self):
         """Check saxs restraint"""
-        m = IMP.Model()
+        m = IMP.kernel.Model()
 
         #! read PDB
         mp= IMP.atom.read_pdb(self.get_input_file_name('6lyz.pdb'), m,
@@ -112,7 +112,7 @@ class Tests(IMP.test.TestCase):
 
     def test_saxs_residue_level_restraint(self):
         """Check residue level saxs restraint"""
-        m = IMP.Model()
+        m = IMP.kernel.Model()
 
         #! read PDB
         mp= IMP.atom.read_pdb(self.get_input_file_name('6lyz.pdb'), m,
