@@ -16,23 +16,25 @@
 IMPSCOREFUNCTOR_BEGIN_NAMESPACE
 
 /** A DistanceScore that uses a UnaryFunction.*/
-class UnaryFunctionEvaluate: public Score {
-  IMP::base::OwnerPointer<IMP::UnaryFunction> uf_;
-public:
-  UnaryFunctionEvaluate(IMP::UnaryFunction *uf): uf_(uf){}
-  template < unsigned int D>
-  double get_score(Model *, const base::Array<D, ParticleIndex>&,
+class UnaryFunctionEvaluate : public Score {
+  IMP::base::PointerMember<IMP::UnaryFunction> uf_;
+
+ public:
+  UnaryFunctionEvaluate(IMP::UnaryFunction *uf) : uf_(uf) {}
+  template <unsigned int D>
+  double get_score(kernel::Model *,
+                   const base::Array<D, kernel::ParticleIndex> &,
                    double distance) const {
     return uf_->evaluate(distance);
   }
-  template < unsigned int D>
-  DerivativePair get_score_and_derivative(Model *,
-                                          const base::Array<D, ParticleIndex>&,
-                                          double distance) const {
+  template <unsigned int D>
+  DerivativePair get_score_and_derivative(
+      kernel::Model *, const base::Array<D, kernel::ParticleIndex> &,
+      double distance) const {
     return uf_->evaluate_with_derivative(distance);
   }
 };
 
 IMPSCOREFUNCTOR_END_NAMESPACE
 
-#endif  /* IMPSCORE_FUNCTOR_UNARY_FUNCTION_EVALUATE_H */
+#endif /* IMPSCORE_FUNCTOR_UNARY_FUNCTION_EVALUATE_H */
