@@ -12,32 +12,32 @@
 #include <IMP/algebra/utility.h>
 IMPSCOREFUNCTOR_BEGIN_NAMESPACE
 
-
 /** A shift the distance by subtracting x0 and pass it to the base
     class.*/
 template <class BaseDistanceScore>
-class WeightScore: public BaseDistanceScore {
+class WeightScore : public BaseDistanceScore {
   typedef BaseDistanceScore P;
   double w_;
-public:
-  WeightScore(double w, BaseDistanceScore base): P(base),
-                                            w_(w){}
+
+ public:
+  WeightScore(double w, BaseDistanceScore base) : P(base), w_(w) {}
   template <unsigned int D>
-  double get_score(Model *m, const base::Array<D, ParticleIndex>&pi,
+  double get_score(kernel::Model *m,
+                   const base::Array<D, kernel::ParticleIndex> &pi,
                    double distance) const {
-    return w_*P::get_score(m,pi, distance);
+    return w_ * P::get_score(m, pi, distance);
   }
   template <unsigned int D>
-  DerivativePair get_score_and_derivative(Model *m,
-                                          const base::Array<D, ParticleIndex>&p,
-                                          double distance) const {
-    DerivativePair ret=P::get_score_and_derivative(m, p, distance);
-    ret.first*=w_;
-    ret.second*=w_;
+  DerivativePair get_score_and_derivative(
+      kernel::Model *m, const base::Array<D, kernel::ParticleIndex> &p,
+      double distance) const {
+    DerivativePair ret = P::get_score_and_derivative(m, p, distance);
+    ret.first *= w_;
+    ret.second *= w_;
     return ret;
   }
 };
 
 IMPSCOREFUNCTOR_END_NAMESPACE
 
-#endif  /* IMPSCORE_FUNCTOR_WEIGHT_SCORE_H */
+#endif /* IMPSCORE_FUNCTOR_WEIGHT_SCORE_H */
