@@ -15,14 +15,12 @@
 #include "point_clustering.h"
 #include <IMP/algebra/VectorD.h>
 #include <IMP/macros.h>
-#include <IMP/Object.h>
+#include <IMP/base/Object.h>
 #include <IMP/ConfigurationSet.h>
 #include <IMP/SingletonContainer.h>
-#include <IMP/internal/OwnerPointer.h>
 
 IMPSTATISTICS_BEGIN_NAMESPACE
 
-
 /** Cluster by repeatedly removing edges which have lots
     of shortest paths passing through them. The process is
     terminated when there are a set number of
@@ -31,26 +29,27 @@ IMPSTATISTICS_BEGIN_NAMESPACE
 
     Only items closer than far are connected.
  */
-IMPSTATISTICSEXPORT
-PartitionalClustering *create_centrality_clustering(Metric *d,
-                                                    double far,
-                                                    int k);
-
+IMPSTATISTICSEXPORT PartitionalClustering *create_centrality_clustering(
+    Metric *d, double far, int k);
 
 /** Cluster the elements into clusters with at most the specified
     diameter.
  */
-IMPSTATISTICSEXPORT
-PartitionalClustering *create_diameter_clustering(Metric *d,
-                                                  double maximum_diameter);
+IMPSTATISTICSEXPORT PartitionalClustering *create_diameter_clustering(
+    Metric *d, double maximum_diameter);
 
 /**Two points, \f$p_i\f$, \f$p_j\f$ are in the same cluster if
     there is a sequence of points \f$\left(p^{ij}_{0}\dots p^{ij}_k\right)\f$
     such that \f$\forall l ||p^{ij}_l-p^{ij}_{l+1}|| < d\f$.
  */
-IMPSTATISTICSEXPORT PartitionalClustering*
-create_connectivity_clustering(Metric *metric,
-                               double dist);
+IMPSTATISTICSEXPORT PartitionalClustering *create_connectivity_clustering(
+    Metric *metric, double dist);
+
+/** Cutoff-based clustering as defined in
+    Daura et al. Angew. Chem. Int. Ed. 1999. 38(1‐2): p. 236-240.
+ */
+IMPSTATISTICSEXPORT PartitionalClustering *create_gromos_clustering(
+    Metric *d, double cutoff);
 
 IMPSTATISTICS_END_NAMESPACE
 
